package androidx.constraintlayout.core.widgets.analyzer;

import androidx.constraintlayout.core.widgets.ConstraintAnchor;
import androidx.constraintlayout.core.widgets.ConstraintWidget;
import androidx.constraintlayout.core.widgets.ConstraintWidgetContainer;
import java.util.ArrayList;
import java.util.Iterator;

public class ChainRun extends WidgetRun {
    private int chainStyle;
    ArrayList<WidgetRun> widgets = new ArrayList<>();

    public ChainRun(ConstraintWidget constraintWidget, int i) {
        super(constraintWidget);
        this.orientation = i;
        build();
    }

    public String toString() {
        StringBuilder sb = new StringBuilder("ChainRun ");
        sb.append(this.orientation == 0 ? "horizontal : " : "vertical : ");
        Iterator<WidgetRun> it = this.widgets.iterator();
        while (it.hasNext()) {
            sb.append("<");
            sb.append(it.next());
            sb.append("> ");
        }
        return sb.toString();
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.constraintlayout.core.widgets.analyzer.WidgetRun
    public boolean supportsWrapComputation() {
        int size = this.widgets.size();
        for (int i = 0; i < size; i++) {
            if (!this.widgets.get(i).supportsWrapComputation()) {
                return false;
            }
        }
        return true;
    }

    @Override // androidx.constraintlayout.core.widgets.analyzer.WidgetRun
    public long getWrapDimension() {
        int size = this.widgets.size();
        long j = 0;
        for (int i = 0; i < size; i++) {
            WidgetRun widgetRun = this.widgets.get(i);
            j = j + ((long) widgetRun.start.margin) + widgetRun.getWrapDimension() + ((long) widgetRun.end.margin);
        }
        return j;
    }

    private void build() {
        ConstraintWidget constraintWidget = this.widget;
        ConstraintWidget previousChainMember = constraintWidget.getPreviousChainMember(this.orientation);
        while (true) {
            constraintWidget = previousChainMember;
            if (constraintWidget == null) {
                break;
            }
            previousChainMember = constraintWidget.getPreviousChainMember(this.orientation);
        }
        this.widget = constraintWidget;
        this.widgets.add(constraintWidget.getRun(this.orientation));
        ConstraintWidget nextChainMember = constraintWidget.getNextChainMember(this.orientation);
        while (nextChainMember != null) {
            this.widgets.add(nextChainMember.getRun(this.orientation));
            nextChainMember = nextChainMember.getNextChainMember(this.orientation);
        }
        Iterator<WidgetRun> it = this.widgets.iterator();
        while (it.hasNext()) {
            WidgetRun next = it.next();
            if (this.orientation == 0) {
                next.widget.horizontalChainRun = this;
            } else if (this.orientation == 1) {
                next.widget.verticalChainRun = this;
            }
        }
        if ((this.orientation == 0 && ((ConstraintWidgetContainer) this.widget.getParent()).isRtl()) && this.widgets.size() > 1) {
            ArrayList<WidgetRun> arrayList = this.widgets;
            this.widget = arrayList.get(arrayList.size() - 1).widget;
        }
        this.chainStyle = this.orientation == 0 ? this.widget.getHorizontalChainStyle() : this.widget.getVerticalChainStyle();
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.constraintlayout.core.widgets.analyzer.WidgetRun
    public void clear() {
        this.runGroup = null;
        Iterator<WidgetRun> it = this.widgets.iterator();
        while (it.hasNext()) {
            it.next().clear();
        }
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.constraintlayout.core.widgets.analyzer.WidgetRun
    public void reset() {
        this.start.resolved = false;
        this.end.resolved = false;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:52:0x00cd, code lost:
        if (r3.dimension.resolved != false) goto L_0x00cf;
     */
    @Override // androidx.constraintlayout.core.widgets.analyzer.WidgetRun, androidx.constraintlayout.core.widgets.analyzer.Dependency
    public void update(Dependency dependency) {
        int i;
        int i2;
        int i3;
        int i4;
        int i5;
        float f;
        int i6;
        int i7;
        float f2;
        int i8;
        int i9;
        int i10;
        float f3;
        int i11;
        int i12;
        int i13;
        if (this.start.resolved && this.end.resolved) {
            ConstraintWidget parent = this.widget.getParent();
            boolean isRtl = parent instanceof ConstraintWidgetContainer ? ((ConstraintWidgetContainer) parent).isRtl() : false;
            int i14 = this.end.value - this.start.value;
            int size = this.widgets.size();
            int i15 = 0;
            while (true) {
                i = -1;
                i2 = 8;
                if (i15 >= size) {
                    i15 = -1;
                    break;
                }
                if (this.widgets.get(i15).widget.getVisibility() != 8) {
                    break;
                }
                i15++;
            }
            int i16 = size - 1;
            int i17 = i16;
            while (true) {
                if (i17 < 0) {
                    break;
                }
                if (this.widgets.get(i17).widget.getVisibility() != 8) {
                    i = i17;
                    break;
                }
                i17--;
            }
            int i18 = 0;
            while (true) {
                if (i18 >= 2) {
                    i3 = 0;
                    i4 = 0;
                    i5 = 0;
                    f = 0.0f;
                    break;
                }
                int i19 = 0;
                i4 = 0;
                i5 = 0;
                i13 = 0;
                f = 0.0f;
                while (i19 < size) {
                    WidgetRun widgetRun = this.widgets.get(i19);
                    if (widgetRun.widget.getVisibility() != i2) {
                        i13++;
                        if (i19 > 0 && i19 >= i15) {
                            i4 += widgetRun.start.margin;
                        }
                        int i20 = widgetRun.dimension.value;
                        boolean z = widgetRun.dimensionBehavior != ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                        if (!z) {
                            if (widgetRun.matchConstraintsType == 1 && i18 == 0) {
                                i20 = widgetRun.dimension.wrapValue;
                                i5++;
                            }
                            z = true;
                        } else if (this.orientation != 0 || widgetRun.widget.horizontalRun.dimension.resolved) {
                            if (this.orientation == 1 && !widgetRun.widget.verticalRun.dimension.resolved) {
                                return;
                            }
                        } else {
                            return;
                        }
                        if (!z) {
                            i5++;
                            float f4 = widgetRun.widget.mWeight[this.orientation];
                            if (f4 >= 0.0f) {
                                f += f4;
                            }
                        } else {
                            i4 += i20;
                        }
                        if (i19 < i16 && i19 < i) {
                            i4 += -widgetRun.end.margin;
                        }
                    }
                    i19++;
                    i2 = 8;
                }
                if (i4 < i14 || i5 == 0) {
                    i3 = i13;
                } else {
                    i18++;
                    i2 = 8;
                }
            }
            i3 = i13;
            int i21 = this.start.value;
            if (isRtl) {
                i21 = this.end.value;
            }
            if (i4 > i14) {
                i21 = isRtl ? i21 + ((int) ((((float) (i4 - i14)) / 2.0f) + 0.5f)) : i21 - ((int) ((((float) (i4 - i14)) / 2.0f) + 0.5f));
            }
            if (i5 > 0) {
                float f5 = (float) (i14 - i4);
                int i22 = (int) ((f5 / ((float) i5)) + 0.5f);
                int i23 = 0;
                int i24 = 0;
                while (i23 < size) {
                    WidgetRun widgetRun2 = this.widgets.get(i23);
                    if (widgetRun2.widget.getVisibility() != 8 && widgetRun2.dimensionBehavior == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && !widgetRun2.dimension.resolved) {
                        int i25 = f > 0.0f ? (int) (((widgetRun2.widget.mWeight[this.orientation] * f5) / f) + 0.5f) : i22;
                        if (this.orientation == 0) {
                            i11 = widgetRun2.widget.mMatchConstraintMaxWidth;
                            f3 = f5;
                            i12 = widgetRun2.widget.mMatchConstraintMinWidth;
                        } else {
                            f3 = f5;
                            i11 = widgetRun2.widget.mMatchConstraintMaxHeight;
                            i12 = widgetRun2.widget.mMatchConstraintMinHeight;
                        }
                        i10 = i4;
                        i9 = i21;
                        int max = Math.max(i12, widgetRun2.matchConstraintsType == 1 ? Math.min(i25, widgetRun2.dimension.wrapValue) : i25);
                        if (i11 > 0) {
                            max = Math.min(i11, max);
                        }
                        if (max != i25) {
                            i24++;
                            i25 = max;
                        }
                        widgetRun2.dimension.resolve(i25);
                    } else {
                        i9 = i21;
                        f3 = f5;
                        i10 = i4;
                    }
                    i23++;
                    i22 = i22;
                    f5 = f3;
                    i4 = i10;
                    i21 = i9;
                }
                i6 = i21;
                if (i24 > 0) {
                    i5 -= i24;
                    int i26 = 0;
                    for (int i27 = 0; i27 < size; i27++) {
                        WidgetRun widgetRun3 = this.widgets.get(i27);
                        if (widgetRun3.widget.getVisibility() != 8) {
                            if (i27 > 0 && i27 >= i15) {
                                i26 += widgetRun3.start.margin;
                            }
                            i26 += widgetRun3.dimension.value;
                            if (i27 < i16 && i27 < i) {
                                i26 += -widgetRun3.end.margin;
                            }
                        }
                    }
                    i4 = i26;
                } else {
                    i4 = i4;
                }
                i7 = 2;
                if (this.chainStyle == 2 && i24 == 0) {
                    this.chainStyle = 0;
                }
            } else {
                i6 = i21;
                i7 = 2;
            }
            if (i4 > i14) {
                this.chainStyle = i7;
            }
            if (i3 > 0 && i5 == 0 && i15 == i) {
                this.chainStyle = i7;
            }
            int i28 = this.chainStyle;
            if (i28 == 1) {
                if (i3 > 1) {
                    i8 = (i14 - i4) / (i3 - 1);
                } else {
                    i8 = i3 == 1 ? (i14 - i4) / 2 : 0;
                }
                if (i5 > 0) {
                    i8 = 0;
                }
                int i29 = i6;
                for (int i30 = 0; i30 < size; i30++) {
                    WidgetRun widgetRun4 = this.widgets.get(isRtl ? size - (i30 + 1) : i30);
                    if (widgetRun4.widget.getVisibility() == 8) {
                        widgetRun4.start.resolve(i29);
                        widgetRun4.end.resolve(i29);
                    } else {
                        if (i30 > 0) {
                            i29 = isRtl ? i29 - i8 : i29 + i8;
                        }
                        if (i30 > 0 && i30 >= i15) {
                            if (isRtl) {
                                i29 -= widgetRun4.start.margin;
                            } else {
                                i29 += widgetRun4.start.margin;
                            }
                        }
                        if (isRtl) {
                            widgetRun4.end.resolve(i29);
                        } else {
                            widgetRun4.start.resolve(i29);
                        }
                        int i31 = widgetRun4.dimension.value;
                        if (widgetRun4.dimensionBehavior == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && widgetRun4.matchConstraintsType == 1) {
                            i31 = widgetRun4.dimension.wrapValue;
                        }
                        i29 = isRtl ? i29 - i31 : i29 + i31;
                        if (isRtl) {
                            widgetRun4.start.resolve(i29);
                        } else {
                            widgetRun4.end.resolve(i29);
                        }
                        widgetRun4.resolved = true;
                        if (i30 < i16 && i30 < i) {
                            i29 = isRtl ? i29 - (-widgetRun4.end.margin) : i29 + (-widgetRun4.end.margin);
                        }
                    }
                }
            } else if (i28 == 0) {
                int i32 = (i14 - i4) / (i3 + 1);
                if (i5 > 0) {
                    i32 = 0;
                }
                int i33 = i6;
                for (int i34 = 0; i34 < size; i34++) {
                    WidgetRun widgetRun5 = this.widgets.get(isRtl ? size - (i34 + 1) : i34);
                    if (widgetRun5.widget.getVisibility() == 8) {
                        widgetRun5.start.resolve(i33);
                        widgetRun5.end.resolve(i33);
                    } else {
                        int i35 = isRtl ? i33 - i32 : i33 + i32;
                        if (i34 > 0 && i34 >= i15) {
                            i35 = isRtl ? i35 - widgetRun5.start.margin : i35 + widgetRun5.start.margin;
                        }
                        if (isRtl) {
                            widgetRun5.end.resolve(i35);
                        } else {
                            widgetRun5.start.resolve(i35);
                        }
                        int i36 = widgetRun5.dimension.value;
                        if (widgetRun5.dimensionBehavior == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && widgetRun5.matchConstraintsType == 1) {
                            i36 = Math.min(i36, widgetRun5.dimension.wrapValue);
                        }
                        i33 = isRtl ? i35 - i36 : i35 + i36;
                        if (isRtl) {
                            widgetRun5.start.resolve(i33);
                        } else {
                            widgetRun5.end.resolve(i33);
                        }
                        if (i34 < i16 && i34 < i) {
                            i33 = isRtl ? i33 - (-widgetRun5.end.margin) : i33 + (-widgetRun5.end.margin);
                        }
                    }
                }
            } else if (i28 == 2) {
                if (this.orientation == 0) {
                    f2 = this.widget.getHorizontalBiasPercent();
                } else {
                    f2 = this.widget.getVerticalBiasPercent();
                }
                if (isRtl) {
                    f2 = 1.0f - f2;
                }
                int i37 = (int) ((((float) (i14 - i4)) * f2) + 0.5f);
                if (i37 < 0 || i5 > 0) {
                    i37 = 0;
                }
                int i38 = isRtl ? i6 - i37 : i6 + i37;
                for (int i39 = 0; i39 < size; i39++) {
                    WidgetRun widgetRun6 = this.widgets.get(isRtl ? size - (i39 + 1) : i39);
                    if (widgetRun6.widget.getVisibility() == 8) {
                        widgetRun6.start.resolve(i38);
                        widgetRun6.end.resolve(i38);
                    } else {
                        if (i39 > 0 && i39 >= i15) {
                            if (isRtl) {
                                i38 -= widgetRun6.start.margin;
                            } else {
                                i38 += widgetRun6.start.margin;
                            }
                        }
                        if (isRtl) {
                            widgetRun6.end.resolve(i38);
                        } else {
                            widgetRun6.start.resolve(i38);
                        }
                        int i40 = widgetRun6.dimension.value;
                        if (widgetRun6.dimensionBehavior == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                            if (widgetRun6.matchConstraintsType == 1) {
                                i40 = widgetRun6.dimension.wrapValue;
                            }
                        }
                        i38 = isRtl ? i38 - i40 : i38 + i40;
                        if (isRtl) {
                            widgetRun6.start.resolve(i38);
                        } else {
                            widgetRun6.end.resolve(i38);
                        }
                        if (i39 < i16 && i39 < i) {
                            i38 = isRtl ? i38 - (-widgetRun6.end.margin) : i38 + (-widgetRun6.end.margin);
                        }
                    }
                }
            }
        }
    }

    @Override // androidx.constraintlayout.core.widgets.analyzer.WidgetRun
    public void applyToWidget() {
        for (int i = 0; i < this.widgets.size(); i++) {
            this.widgets.get(i).applyToWidget();
        }
    }

    private ConstraintWidget getFirstVisibleWidget() {
        for (int i = 0; i < this.widgets.size(); i++) {
            WidgetRun widgetRun = this.widgets.get(i);
            if (widgetRun.widget.getVisibility() != 8) {
                return widgetRun.widget;
            }
        }
        return null;
    }

    private ConstraintWidget getLastVisibleWidget() {
        for (int size = this.widgets.size() - 1; size >= 0; size--) {
            WidgetRun widgetRun = this.widgets.get(size);
            if (widgetRun.widget.getVisibility() != 8) {
                return widgetRun.widget;
            }
        }
        return null;
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.constraintlayout.core.widgets.analyzer.WidgetRun
    public void apply() {
        Iterator<WidgetRun> it = this.widgets.iterator();
        while (it.hasNext()) {
            it.next().apply();
        }
        int size = this.widgets.size();
        if (size >= 1) {
            ConstraintWidget constraintWidget = this.widgets.get(0).widget;
            ConstraintWidget constraintWidget2 = this.widgets.get(size - 1).widget;
            if (this.orientation == 0) {
                ConstraintAnchor constraintAnchor = constraintWidget.mLeft;
                ConstraintAnchor constraintAnchor2 = constraintWidget2.mRight;
                DependencyNode target = getTarget(constraintAnchor, 0);
                int margin = constraintAnchor.getMargin();
                ConstraintWidget firstVisibleWidget = getFirstVisibleWidget();
                if (firstVisibleWidget != null) {
                    margin = firstVisibleWidget.mLeft.getMargin();
                }
                if (target != null) {
                    addTarget(this.start, target, margin);
                }
                DependencyNode target2 = getTarget(constraintAnchor2, 0);
                int margin2 = constraintAnchor2.getMargin();
                ConstraintWidget lastVisibleWidget = getLastVisibleWidget();
                if (lastVisibleWidget != null) {
                    margin2 = lastVisibleWidget.mRight.getMargin();
                }
                if (target2 != null) {
                    addTarget(this.end, target2, -margin2);
                }
            } else {
                ConstraintAnchor constraintAnchor3 = constraintWidget.mTop;
                ConstraintAnchor constraintAnchor4 = constraintWidget2.mBottom;
                DependencyNode target3 = getTarget(constraintAnchor3, 1);
                int margin3 = constraintAnchor3.getMargin();
                ConstraintWidget firstVisibleWidget2 = getFirstVisibleWidget();
                if (firstVisibleWidget2 != null) {
                    margin3 = firstVisibleWidget2.mTop.getMargin();
                }
                if (target3 != null) {
                    addTarget(this.start, target3, margin3);
                }
                DependencyNode target4 = getTarget(constraintAnchor4, 1);
                int margin4 = constraintAnchor4.getMargin();
                ConstraintWidget lastVisibleWidget2 = getLastVisibleWidget();
                if (lastVisibleWidget2 != null) {
                    margin4 = lastVisibleWidget2.mBottom.getMargin();
                }
                if (target4 != null) {
                    addTarget(this.end, target4, -margin4);
                }
            }
            this.start.updateDelegate = this;
            this.end.updateDelegate = this;
        }
    }
}
