package cn.leancloud;

import cn.leancloud.core.PaasClient;
import cn.leancloud.query.AVCloudQueryResult;
import cn.leancloud.query.AVQueryResult;
import cn.leancloud.utils.AVUtils;
import cn.leancloud.utils.StringUtil;
import io.reactivex.Observable;
import io.reactivex.functions.Function;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;

class AVCloudQuery {
    private AVCloudQuery() {
    }

    public static Observable<AVCloudQueryResult> executeInBackground(String str) {
        return executeInBackground(str, AVObject.class);
    }

    public static Observable<AVCloudQueryResult> executeInBackground(String str, Object... objArr) {
        return executeInBackground(str, AVObject.class, objArr);
    }

    public static Observable<AVCloudQueryResult> executeInBackground(String str, Class<? extends AVObject> cls) {
        return executeInBackground(str, cls, null);
    }

    public static <T extends AVObject> Observable<AVCloudQueryResult> executeInBackground(String str, Class<T> cls, Object... objArr) {
        if (StringUtil.isEmpty(str)) {
            throw new IllegalArgumentException("cql is empty");
        } else if (cls != null) {
            LinkedList linkedList = new LinkedList();
            if (objArr != null) {
                for (Object obj : objArr) {
                    linkedList.add(obj);
                }
            }
            HashMap hashMap = new HashMap();
            hashMap.put("cql", str);
            if (!linkedList.isEmpty()) {
                hashMap.put("pvalues", AVUtils.jsonStringFromObjectWithNull(linkedList));
            }
            return PaasClient.getStorageClient().cloudQuery(hashMap).map(new Function<AVQueryResult, AVCloudQueryResult>() {
                /* class cn.leancloud.AVCloudQuery.AnonymousClass1 */

                public AVCloudQueryResult apply(AVQueryResult aVQueryResult) throws Exception {
                    AVCloudQueryResult aVCloudQueryResult = new AVCloudQueryResult();
                    ArrayList arrayList = new ArrayList(aVQueryResult.getCount());
                    for (AVObject aVObject : aVQueryResult.getResults()) {
                        arrayList.add(Transformer.transform(aVObject, aVQueryResult.getClassName()));
                    }
                    aVCloudQueryResult.setResults(arrayList);
                    aVCloudQueryResult.setCount(aVQueryResult.getCount());
                    return aVCloudQueryResult;
                }
            });
        } else {
            throw new IllegalArgumentException("target class is null");
        }
    }
}
