package cn.leancloud;

import android.content.ComponentName;
import android.content.Context;
import android.content.pm.PackageManager;
import androidx.core.app.ActivityCompat;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;

public class AVManifestUtils {
    private static final AVLogger LOGGER = LogUtil.getLogger(AVManifestUtils.class);

    public static boolean checkPermission(Context context, String str) {
        boolean z = ActivityCompat.checkSelfPermission(context, str) == 0;
        if (!z) {
            printErrorLog("permission " + str + " is missing!");
        }
        return z;
    }

    public static boolean checkService(Context context, Class<?> cls) {
        try {
            return context.getPackageManager().getServiceInfo(new ComponentName(context, cls), 0) != null;
        } catch (PackageManager.NameNotFoundException unused) {
            printErrorLog("service " + cls.getName() + " is missing!");
            return false;
        }
    }

    public static boolean checkReceiver(Context context, Class<?> cls) {
        try {
            return context.getPackageManager().getReceiverInfo(new ComponentName(context, cls), 0) != null;
        } catch (PackageManager.NameNotFoundException unused) {
            printErrorLog("receiver " + cls.getName() + " is missing!");
            return false;
        }
    }

    private static void printErrorLog(String str) {
        if (!StringUtil.isEmpty(str)) {
            LOGGER.e(str);
        }
    }
}
