package cn.leancloud;

import cn.leancloud.callback.SendCallback;
import cn.leancloud.core.PaasClient;
import cn.leancloud.utils.AVUtils;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import io.reactivex.Observable;
import io.reactivex.Observer;
import io.reactivex.disposables.Disposable;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public class AVPush {
    private static final String APNsTeamIdTag = "apns_team_id";
    private static final String APNsTopicTag = "topic";
    private static final Set<String> DEVICE_TYPES;
    private static final int FlowControlMinValue = 1000;
    private static final String FlowControlTag = "flow_control";
    private static final AVLogger LOGGER = LogUtil.getLogger(AVPush.class);
    private static final String NotificationIdTag = "notification_id";
    private static final String RequestIdTag = "req_id";
    private static final String deviceTypeTag = "deviceType";
    public static final String iOSEnvironmentDev = "dev";
    public static final String iOSEnvironmentProd = "prod";
    private static final String iOSEnvironmentTag = "prod";
    private String APNsTeamId = null;
    private String APNsTopic = null;
    private final Set<String> channelSet = new HashSet();
    private String cql;
    private long expirationTime;
    private long expirationTimeInterval;
    private int flowControl = 0;
    private String iOSEnvironment = null;
    private volatile AVObject notification;
    private String notificationId = null;
    private final Map<String, Object> pushData = new HashMap();
    private Date pushDate = null;
    private AVQuery<? extends AVInstallation> pushQuery = AVInstallation.getQuery();
    private final Set<String> pushTarget = new HashSet(DEVICE_TYPES);
    private String requestId = null;

    static {
        HashSet hashSet = new HashSet();
        DEVICE_TYPES = hashSet;
        hashSet.add("android");
        hashSet.add("ios");
    }

    public Set<String> getChannelSet() {
        return this.channelSet;
    }

    public AVObject getNotification() {
        return this.notification;
    }

    public AVQuery<? extends AVInstallation> getPushQuery() {
        return this.pushQuery;
    }

    public Date getPushDate() {
        return this.pushDate;
    }

    public long getExpirationTime() {
        return this.expirationTime;
    }

    public long getExpirationTimeInterval() {
        return this.expirationTimeInterval;
    }

    public Set<String> getPushTarget() {
        return this.pushTarget;
    }

    public Map<String, Object> getPushData() {
        return this.pushData;
    }

    public int getFlowControl() {
        return this.flowControl;
    }

    public void setFlowControl(int i) {
        if (i < 1000) {
            i = 1000;
        }
        this.flowControl = i;
    }

    public void setiOSEnvironment(String str) {
        this.iOSEnvironment = str;
    }

    public void setAPNsTopic(String str) {
        this.APNsTopic = str;
    }

    public void setAPNsTeamId(String str) {
        this.APNsTeamId = str;
    }

    public void setNotificationId(String str) {
        this.notificationId = str;
    }

    public void setRequestId(String str) {
        this.requestId = str;
    }

    public void setChannel(String str) {
        this.channelSet.clear();
        this.channelSet.add(str);
    }

    public void setChannels(Collection<String> collection) {
        this.channelSet.clear();
        this.channelSet.addAll(collection);
    }

    public void setData(Map<String, Object> map) {
        this.pushData.put("data", map);
    }

    public void setData(JSONObject jSONObject) {
        try {
            HashMap hashMap = new HashMap();
            for (Map.Entry<String, Object> entry : jSONObject.entrySet()) {
                hashMap.put(entry.getKey(), entry.getValue());
            }
            this.pushData.put("data", hashMap);
        } catch (Exception e) {
            LOGGER.w(e);
        }
    }

    private Date expirationDateTime() {
        return new Date(this.expirationTime);
    }

    public void setPushDate(Date date) {
        this.pushDate = date;
    }

    public void setExpirationTime(long j) {
        this.expirationTime = j;
    }

    public void setExpirationTimeInterval(long j) {
        this.expirationTimeInterval = j;
    }

    public void setMessage(String str) {
        this.pushData.clear();
        this.pushData.put("data", AVUtils.createStringObjectMap("alert", str));
    }

    public void setPushToAndroid(boolean z) {
        if (z) {
            this.pushTarget.add("android");
        } else {
            this.pushTarget.remove("android");
        }
    }

    public void setPushToIOS(boolean z) {
        if (z) {
            this.pushTarget.add("ios");
        } else {
            this.pushTarget.remove("ios");
        }
    }

    public void setPushToWindowsPhone(boolean z) {
        if (z) {
            this.pushTarget.add("wp");
        } else {
            this.pushTarget.remove("wp");
        }
    }

    public void setQuery(AVQuery<? extends AVInstallation> aVQuery) {
        this.pushQuery = aVQuery;
    }

    public void setCloudQuery(String str) {
        this.cql = str;
    }

    public void clearExpiration() {
        this.expirationTime = 0;
        this.expirationTimeInterval = 0;
    }

    public void send() {
        sendInBackground().blockingFirst();
    }

    public Observable<JSONObject> sendInBackground() {
        try {
            return PaasClient.getPushClient().sendPushRequest(postDataMap());
        } catch (Exception e) {
            return Observable.error(e);
        }
    }

    private Map<String, Object> pushChannelsData() {
        return AVUtils.createStringObjectMap("channels", this.channelSet);
    }

    private Map<String, Object> postDataMap() throws AVException {
        HashMap hashMap = new HashMap();
        if (this.pushQuery != null) {
            if (this.pushTarget.size() == 0) {
                this.pushQuery.whereNotContainedIn(deviceTypeTag, DEVICE_TYPES);
            } else if (this.pushTarget.size() == 1) {
                this.pushQuery.whereEqualTo(deviceTypeTag, this.pushTarget.toArray()[0]);
            }
            Map<String, String> assembleParameters = this.pushQuery.assembleParameters();
            if (assembleParameters.keySet().size() <= 0 || StringUtil.isEmpty(this.cql)) {
                for (Map.Entry<String, String> entry : assembleParameters.entrySet()) {
                    hashMap.put(entry.getKey(), JSON.parse(entry.getValue()));
                }
            } else {
                throw new IllegalStateException("You can't use AVQuery and Cloud query at the same time.");
            }
        }
        if (!StringUtil.isEmpty(this.cql)) {
            hashMap.put("cql", this.cql);
        }
        if (this.channelSet.size() > 0) {
            hashMap.putAll(pushChannelsData());
        }
        if (this.expirationTime > 0) {
            hashMap.put("expiration_time", expirationDateTime());
        }
        if (this.expirationTimeInterval > 0) {
            hashMap.put("push_time", StringUtil.stringFromDate(new Date()));
            hashMap.put("expiration_interval", Long.valueOf(this.expirationTimeInterval));
        }
        Date date = this.pushDate;
        if (date != null) {
            hashMap.put("push_time", StringUtil.stringFromDate(date));
        }
        int i = this.flowControl;
        if (i > 0) {
            hashMap.put(FlowControlTag, Integer.valueOf(i));
        }
        if (!StringUtil.isEmpty(this.iOSEnvironment)) {
            hashMap.put("prod", this.iOSEnvironment);
        }
        if (!StringUtil.isEmpty(this.APNsTopic)) {
            hashMap.put(APNsTopicTag, this.APNsTopic);
        }
        if (!StringUtil.isEmpty(this.APNsTeamId)) {
            hashMap.put(APNsTeamIdTag, this.APNsTeamId);
        }
        if (!StringUtil.isEmpty(this.notificationId)) {
            hashMap.put(NotificationIdTag, this.notificationId);
        }
        hashMap.putAll(this.pushData);
        return hashMap;
    }

    public void sendInBackground(final SendCallback sendCallback) {
        sendInBackground().subscribe(new Observer<JSONObject>() {
            /* class cn.leancloud.AVPush.AnonymousClass1 */

            @Override // io.reactivex.Observer
            public void onComplete() {
            }

            @Override // io.reactivex.Observer
            public void onSubscribe(Disposable disposable) {
            }

            public void onNext(JSONObject jSONObject) {
                AVPush.this.notification = new AVObject("_Notification");
                AVPush.this.notification.resetServerData(jSONObject.getInnerMap());
                SendCallback sendCallback = sendCallback;
                if (sendCallback != null) {
                    sendCallback.internalDone(null);
                }
            }

            @Override // io.reactivex.Observer
            public void onError(Throwable th) {
                SendCallback sendCallback = sendCallback;
                if (sendCallback != null) {
                    sendCallback.internalDone(new AVException(th));
                }
            }
        });
    }

    public static void sendDataInBackground(JSONObject jSONObject, AVQuery<? extends AVInstallation> aVQuery, SendCallback sendCallback) {
        AVPush aVPush = new AVPush();
        aVPush.setData(jSONObject);
        aVPush.setQuery(aVQuery);
        aVPush.sendInBackground(sendCallback);
    }

    public static Observable<JSONObject> sendDataInBackground(JSONObject jSONObject, AVQuery<? extends AVInstallation> aVQuery) {
        AVPush aVPush = new AVPush();
        aVPush.setData(jSONObject);
        aVPush.setQuery(aVQuery);
        return aVPush.sendInBackground();
    }

    public static Observable<JSONObject> sendMessageInBackground(String str, AVQuery<? extends AVInstallation> aVQuery) {
        AVPush aVPush = new AVPush();
        aVPush.setMessage(str);
        aVPush.setQuery(aVQuery);
        return aVPush.sendInBackground();
    }

    public static void sendMessageInBackground(String str, AVQuery<? extends AVInstallation> aVQuery, SendCallback sendCallback) {
        AVPush aVPush = new AVPush();
        aVPush.setMessage(str);
        aVPush.setQuery(aVQuery);
        aVPush.sendInBackground(sendCallback);
    }
}
