package cn.leancloud;

import cn.leancloud.AVObject;
import cn.leancloud.ops.Utils;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.annotation.JSONField;
import java.util.Collection;
import java.util.HashMap;

public class AVRelation<T extends AVObject> {
    private String key;
    @JSONField(serialize = false)
    private AVObject parent;
    private String targetClass;

    public AVRelation() {
    }

    public AVRelation(AVObject aVObject, String str) {
        this();
        this.parent = aVObject;
        this.key = str;
    }

    public AVRelation(String str) {
        this(null, null);
        this.targetClass = str;
    }

    public String getKey() {
        return this.key;
    }

    public void setKey(String str) {
        this.key = str;
    }

    public AVObject getParent() {
        return this.parent;
    }

    public void setParent(AVObject aVObject) {
        this.parent = aVObject;
    }

    public String getTargetClass() {
        return this.targetClass;
    }

    public void setTargetClass(String str) {
        this.targetClass = str;
    }

    public void add(T t) {
        if (t != null) {
            if (StringUtil.isEmpty(this.targetClass)) {
                this.targetClass = t.getClassName();
            }
            if (StringUtil.isEmpty(this.targetClass) || this.targetClass.equals(t.getClassName())) {
                this.parent.addRelation(t, this.key);
                return;
            }
            throw new IllegalArgumentException("Could not add class '" + t.getClassName() + "' to this relation,expect class is '" + this.targetClass + "'");
        }
        throw new IllegalArgumentException("null AVObject");
    }

    public void addAll(Collection<T> collection) {
        if (collection != null) {
            for (T t : collection) {
                add(t);
            }
        }
    }

    public void remove(AVObject aVObject) {
        this.parent.removeRelation(aVObject, this.key);
    }

    @JSONField(serialize = false)
    public AVQuery<T> getQuery() {
        return getQuery(null);
    }

    @JSONField(serialize = false)
    public AVQuery<T> getQuery(Class<T> cls) {
        if (getParent() == null || StringUtil.isEmpty(getParent().getObjectId())) {
            throw new IllegalStateException("unable to encode an association with an unsaved AVObject");
        }
        HashMap hashMap = new HashMap();
        hashMap.put("object", Utils.mapFromPointerObject(getParent()));
        hashMap.put("key", getKey());
        String targetClass2 = getTargetClass();
        if (StringUtil.isEmpty(targetClass2)) {
            targetClass2 = getParent().getClassName();
        }
        AVQuery<T> aVQuery = new AVQuery<>(targetClass2, cls);
        aVQuery.addWhereItem("$relatedTo", null, hashMap);
        if (StringUtil.isEmpty(getTargetClass())) {
            aVQuery.getParameters().put("redirectClassNameForKey", getKey());
        }
        return aVQuery;
    }

    public static <M extends AVObject> AVQuery<M> reverseQuery(String str, String str2, AVObject aVObject) {
        AVQuery<M> aVQuery = new AVQuery<>(str);
        aVQuery.whereEqualTo(str2, Utils.mapFromPointerObject(aVObject));
        return aVQuery;
    }

    public static <M extends AVObject> AVQuery<M> reverseQuery(Class<M> cls, String str, AVObject aVObject) {
        AVQuery<M> aVQuery = new AVQuery<>(Transformer.getSubClassName(cls), cls);
        aVQuery.whereEqualTo(str, Utils.mapFromPointerObject(aVObject));
        return aVQuery;
    }
}
