package cn.leancloud;

import cn.leancloud.core.PaasClient;
import cn.leancloud.ops.Utils;
import cn.leancloud.utils.ErrorUtils;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSONObject;
import io.reactivex.Observable;
import io.reactivex.functions.Function;
import java.util.List;
import java.util.Map;
import okhttp3.internal.cache.DiskLruCache;

public class AVStatusQuery extends AVQuery<AVStatus> {
    private String inboxType = null;
    private StatusIterator iterator;
    private AVUser owner = null;
    private AVUser source = null;
    private SourceType sourceType;

    public enum SourceType {
        INBOX,
        OWNED
    }

    public enum PaginationDirection {
        NEW_TO_OLD(0),
        OLD_TO_NEW(1);
        
        int value;

        private PaginationDirection(int i) {
            this.value = i;
        }

        public int value() {
            return this.value;
        }
    }

    protected AVStatusQuery(SourceType sourceType2) {
        super(AVStatus.CLASS_NAME, AVStatus.class);
        this.sourceType = sourceType2;
        this.iterator = new StatusIterator(sourceType2);
    }

    public void setSinceId(long j) {
        this.iterator.setSinceId(j);
    }

    public long getSinceId() {
        return this.iterator.getSinceId();
    }

    public long getMaxId() {
        return this.iterator.getMaxId();
    }

    public void setMaxId(long j) {
        this.iterator.setMaxId(j);
    }

    public int getPageSize() {
        return this.iterator.getPageSize();
    }

    public void setPageSize(int i) {
        this.iterator.setPageSize(i);
    }

    public void setDirection(PaginationDirection paginationDirection) {
        this.iterator.setDirection(paginationDirection);
    }

    /* access modifiers changed from: package-private */
    public void setSource(AVUser aVUser) {
        this.source = aVUser;
    }

    /* access modifiers changed from: package-private */
    public void setOwner(AVUser aVUser) {
        this.owner = aVUser;
        if (aVUser != null) {
            getInclude().add(AVStatus.ATTR_SOURCE);
        }
    }

    /* access modifiers changed from: package-private */
    public void setInboxType(String str) {
        this.inboxType = str;
    }

    @Override // cn.leancloud.AVQuery
    public Map<String, String> assembleParameters() {
        return assembleParameters(false);
    }

    private Map<String, String> assembleParameters(boolean z) {
        AVUser aVUser;
        if (SourceType.OWNED == this.sourceType) {
            if (!StringUtil.isEmpty(this.inboxType)) {
                whereEqualTo(AVStatus.ATTR_INBOX_TYPE, this.inboxType);
            }
            AVUser aVUser2 = this.source;
            if (aVUser2 != null) {
                whereEqualTo(AVStatus.ATTR_SOURCE, aVUser2);
            }
            if (z) {
                this.iterator.fillConditions(this);
            } else if (PaginationDirection.NEW_TO_OLD == this.iterator.getDirection()) {
                addDescendingOrder(AVObject.KEY_CREATED_AT);
            } else {
                addAscendingOrder(AVObject.KEY_CREATED_AT);
            }
        } else if (!z) {
            if (PaginationDirection.NEW_TO_OLD == this.iterator.getDirection()) {
                addDescendingOrder(AVStatus.ATTR_MESSAGE_ID);
            } else {
                addAscendingOrder(AVStatus.ATTR_MESSAGE_ID);
            }
        }
        Map<String, String> assembleParameters = super.assembleParameters();
        if (this.owner != null) {
            if (z) {
                this.iterator.fillConditions(assembleParameters);
            }
            if (!StringUtil.isEmpty(this.inboxType)) {
                assembleParameters.put(AVStatus.ATTR_INBOX_TYPE, this.inboxType);
            }
            assembleParameters.put(AVStatus.ATTR_OWNER, new JSONObject(Utils.mapFromAVObject(this.owner, false)).toJSONString());
        } else if (!(SourceType.OWNED == this.sourceType || (aVUser = this.source) == null)) {
            assembleParameters.put(AVStatus.ATTR_SOURCE, new JSONObject(Utils.mapFromAVObject(aVUser, false)).toJSONString());
        }
        if (getPageSize() > 0) {
            assembleParameters.put("limit", String.valueOf(getPageSize()));
        }
        return assembleParameters;
    }

    /* access modifiers changed from: protected */
    @Override // cn.leancloud.AVQuery
    public Observable<List<AVStatus>> findInBackground(int i) {
        return internalFindInBackground(i, false);
    }

    private Observable<List<AVStatus>> internalFindInBackground(int i, boolean z) {
        Map<String, String> map;
        AVUser aVUser = this.owner;
        if (aVUser == null && this.source == null) {
            return Observable.error(ErrorUtils.illegalArgument("source or owner is null, please initialize correctly."));
        }
        if (aVUser != null && !aVUser.isAuthenticated()) {
            return Observable.error(ErrorUtils.sessionMissingException());
        }
        if (z) {
            map = assembleParameters(true);
        } else {
            map = assembleParameters();
        }
        if (i > 0) {
            map.put("limit", String.valueOf(i));
        }
        return this.owner != null ? PaasClient.getStorageClient().queryInbox(map).map(new Function<List<AVStatus>, List<AVStatus>>() {
            /* class cn.leancloud.AVStatusQuery.AnonymousClass1 */

            public List<AVStatus> apply(List<AVStatus> list) throws Exception {
                if (list != null && list.size() >= 1) {
                    for (AVStatus aVStatus : list) {
                        AVStatusQuery.this.iterator.encounter(aVStatus);
                    }
                }
                return list;
            }
        }) : PaasClient.getStorageClient().queryStatus(map).map(new Function<List<AVStatus>, List<AVStatus>>() {
            /* class cn.leancloud.AVStatusQuery.AnonymousClass2 */

            public List<AVStatus> apply(List<AVStatus> list) throws Exception {
                if (list != null && list.size() >= 1) {
                    for (AVStatus aVStatus : list) {
                        AVStatusQuery.this.iterator.encounter(aVStatus);
                    }
                }
                return list;
            }
        });
    }

    public Observable<List<AVStatus>> nextInBackground() {
        return internalFindInBackground(0, true);
    }

    @Override // cn.leancloud.AVQuery
    public Observable<Integer> countInBackground() {
        AVUser aVUser = this.owner;
        if (aVUser == null && this.source == null) {
            return Observable.error(ErrorUtils.illegalArgument("source or owner is null, please initialize correctly."));
        }
        if (aVUser != null) {
            return Observable.error(ErrorUtils.invalidStateException("countInBackground doesn't work for inbox query, please use unreadCountInBackground."));
        }
        Map<String, String> assembleParameters = assembleParameters();
        assembleParameters.put("count", DiskLruCache.VERSION_1);
        assembleParameters.put("limit", "0");
        return PaasClient.getStorageClient().queryCount(AVStatus.CLASS_NAME, assembleParameters);
    }

    public Observable<JSONObject> unreadCountInBackground() {
        AVUser aVUser = this.owner;
        if (aVUser == null || !aVUser.isAuthenticated()) {
            return Observable.error(ErrorUtils.sessionMissingException());
        }
        Map<String, String> assembleParameters = assembleParameters();
        assembleParameters.put("count", DiskLruCache.VERSION_1);
        assembleParameters.put("limit", "0");
        return PaasClient.getStorageClient().getInboxCount(assembleParameters);
    }
}
