package cn.leancloud;

import cn.leancloud.annotation.AVClassName;
import cn.leancloud.cache.PersistenceUtil;
import cn.leancloud.callback.AVCallback;
import cn.leancloud.callback.FollowersAndFolloweesCallback;
import cn.leancloud.core.AppConfiguration;
import cn.leancloud.core.PaasClient;
import cn.leancloud.ops.Utils;
import cn.leancloud.sms.AVSMS;
import cn.leancloud.sms.AVSMSOption;
import cn.leancloud.types.AVNull;
import cn.leancloud.utils.ErrorUtils;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import io.reactivex.Observable;
import io.reactivex.Observer;
import io.reactivex.disposables.Disposable;
import io.reactivex.functions.Function;
import java.io.File;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

@AVClassName(AVUser.CLASS_NAME)
@JSONType(deserializer = ObjectTypeAdapter.class, serializer = ObjectTypeAdapter.class)
public class AVUser extends AVObject {
    public static final String ATTR_EMAIL = "email";
    public static final String ATTR_MOBILEPHONE = "mobilePhoneNumber";
    private static final String ATTR_MOBILEPHONE_VERIFIED = "mobilePhoneVerified";
    private static final String ATTR_PASSWORD = "password";
    public static final String ATTR_SESSION_TOKEN = "sessionToken";
    private static final String ATTR_SMSCODE = "smsCode";
    public static final String ATTR_USERNAME = "username";
    private static final String AUTHDATA_ATTR_MAIN_ACCOUNT = "main_account";
    private static final String AUTHDATA_ATTR_UNIONID = "unionid";
    private static final String AUTHDATA_ATTR_UNIONID_PLATFORM = "platform";
    private static final String AUTHDATA_PLATFORM_ANONYMOUS = "anonymous";
    private static final String AUTHDATA_TAG = "authData";
    public static final String CLASS_NAME = "_User";
    public static final String FOLLOWEE_TAG = "followee";
    public static final String FOLLOWER_TAG = "follower";
    private static final String ILLEGALARGUMENT_MSG_FORMAT = "illegal parameter. %s must not null/empty.";
    private static transient boolean enableAutomatic = false;
    private static Class<? extends AVUser> subClazz;

    public enum SNS_PLATFORM {
        FACEBOOK("facebook"),
        TWITTER("twitter"),
        QQ("qq"),
        WEIBO("weibo"),
        WECHAT("weixin");
        
        private String name;

        private SNS_PLATFORM(String str) {
            this.name = str;
        }

        public String getName() {
            return this.name;
        }
    }

    public AVUser() {
        super(CLASS_NAME);
    }

    public static AVUser currentUser() {
        return getCurrentUser();
    }

    @JSONField(serialize = false)
    public String getEmail() {
        return (String) get("email");
    }

    public void setEmail(String str) {
        put("email", str);
    }

    @JSONField(serialize = false)
    public String getUsername() {
        return (String) get(ATTR_USERNAME);
    }

    public void setUsername(String str) {
        put(ATTR_USERNAME, str);
    }

    @JSONField(serialize = false)
    public String getPassword() {
        return (String) get(ATTR_PASSWORD);
    }

    public void setPassword(String str) {
        put(ATTR_PASSWORD, str);
    }

    @JSONField(serialize = false)
    public String getMobilePhoneNumber() {
        return (String) get(ATTR_MOBILEPHONE);
    }

    public void setMobilePhoneNumber(String str) {
        put(ATTR_MOBILEPHONE, str);
    }

    @JSONField(serialize = false)
    public boolean isMobilePhoneVerified() {
        return getBoolean(ATTR_MOBILEPHONE_VERIFIED);
    }

    @JSONField(serialize = false)
    public String getSessionToken() {
        return (String) get(ATTR_SESSION_TOKEN);
    }

    public void internalChangeSessionToken(String str) {
        getServerData().put(ATTR_SESSION_TOKEN, str);
    }

    @JSONField(serialize = false)
    public boolean isAuthenticated() {
        return !StringUtil.isEmpty(getSessionToken());
    }

    private void updateCurrentUserCache() {
        String sessionToken = getSessionToken();
        AVUser currentUser = currentUser();
        if (currentUser != null && !StringUtil.isEmpty(currentUser.getObjectId()) && currentUser.getObjectId().equals(getObjectId()) && !StringUtil.isEmpty(sessionToken)) {
            changeCurrentUser(this, true);
        }
    }

    /* access modifiers changed from: protected */
    @Override // cn.leancloud.AVObject
    public void onSaveSuccess() {
        super.onSaveSuccess();
        updateCurrentUserCache();
    }

    /* access modifiers changed from: protected */
    @Override // cn.leancloud.AVObject
    public void onSaveFailure() {
        super.onSaveFailure();
    }

    /* access modifiers changed from: protected */
    @Override // cn.leancloud.AVObject
    public void onDataSynchronized() {
        super.onDataSynchronized();
        updateCurrentUserCache();
    }

    public boolean isAnonymous() {
        JSONObject jSONObject = getJSONObject(AUTHDATA_TAG);
        return jSONObject != null && jSONObject.size() == 1 && jSONObject.containsKey(AUTHDATA_PLATFORM_ANONYMOUS);
    }

    public void signUp() {
        signUpInBackground().blockingSubscribe();
    }

    public Observable<AVUser> signUpInBackground() {
        JSONObject generateChangedParam = generateChangedParam();
        AVLogger aVLogger = logger;
        aVLogger.d("signup param: " + generateChangedParam.toJSONString());
        return PaasClient.getStorageClient().signUp(generateChangedParam).map(new Function<AVUser, AVUser>() {
            /* class cn.leancloud.AVUser.AnonymousClass1 */

            public AVUser apply(AVUser aVUser) throws Exception {
                AVUser.this.mergeRawData(aVUser, true);
                AVUser.this.onSaveSuccess();
                return AVUser.this;
            }
        });
    }

    public static AVUser signUpOrLoginByMobilePhone(String str, String str2) {
        return signUpOrLoginByMobilePhone(str, str2, internalUserClazz());
    }

    public static <T extends AVUser> T signUpOrLoginByMobilePhone(String str, String str2, Class<T> cls) {
        return (T) ((AVUser) signUpOrLoginByMobilePhoneInBackground(str, str2, cls).blockingSingle());
    }

    public static Observable<? extends AVUser> signUpOrLoginByMobilePhoneInBackground(String str, String str2) {
        return signUpOrLoginByMobilePhoneInBackground(str, str2, internalUserClazz());
    }

    public static <T extends AVUser> Observable<T> signUpOrLoginByMobilePhoneInBackground(String str, String str2, Class<T> cls) {
        if (StringUtil.isEmpty(str)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, ATTR_MOBILEPHONE)));
        } else if (StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, ATTR_SMSCODE)));
        } else if (cls == null) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, "clazz")));
        } else {
            return PaasClient.getStorageClient().signUpOrLoginByMobilephone(new JSONObject(createUserMap(null, null, null, str, str2)), cls);
        }
    }

    public static Observable<? extends AVUser> logIn(String str, String str2) {
        return logIn(str, str2, internalUserClazz());
    }

    public static Observable<? extends AVUser> logInAnonymously() {
        String lowerCase = UUID.randomUUID().toString().toLowerCase();
        HashMap hashMap = new HashMap();
        hashMap.put("id", lowerCase);
        return loginWithAuthData(hashMap, AUTHDATA_PLATFORM_ANONYMOUS);
    }

    public static <T extends AVUser> Observable<T> logIn(String str, String str2, Class<T> cls) {
        return PaasClient.getStorageClient().logIn(new JSONObject(createUserMap(str, str2, null, null, null)), cls);
    }

    public static Observable<? extends AVUser> loginByMobilePhoneNumber(String str, String str2) {
        return loginByMobilePhoneNumber(str, str2, internalUserClazz());
    }

    public static Observable<? extends AVUser> loginByEmail(String str, String str2) {
        return PaasClient.getStorageClient().logIn(new JSONObject(createUserMapAFAP(null, str2, str, null, null)), internalUserClazz());
    }

    public static <T extends AVUser> Observable<T> loginByMobilePhoneNumber(String str, String str2, Class<T> cls) {
        return PaasClient.getStorageClient().logIn(new JSONObject(createUserMap(null, str2, null, str, null)), cls);
    }

    public static Observable<? extends AVUser> loginBySMSCode(String str, String str2) {
        return loginBySMSCode(str, str2, internalUserClazz());
    }

    public static <T extends AVUser> Observable<T> loginBySMSCode(String str, String str2, Class<T> cls) {
        return PaasClient.getStorageClient().logIn(new JSONObject(createUserMap(null, null, null, str, str2)), cls);
    }

    private static Map<String, Object> createUserMap(String str, String str2, String str3, String str4, String str5) {
        HashMap hashMap = new HashMap();
        if (!StringUtil.isEmpty(str) || !StringUtil.isEmpty(str4)) {
            if (!StringUtil.isEmpty(str)) {
                hashMap.put(ATTR_USERNAME, str);
            }
            if (!StringUtil.isEmpty(str2)) {
                hashMap.put(ATTR_PASSWORD, str2);
            }
            if (!StringUtil.isEmpty(str3)) {
                hashMap.put("email", str3);
            }
            if (!StringUtil.isEmpty(str4)) {
                hashMap.put(ATTR_MOBILEPHONE, str4);
            }
            if (!StringUtil.isEmpty(str5)) {
                hashMap.put(ATTR_SMSCODE, str5);
            }
            return hashMap;
        }
        throw new IllegalArgumentException("Blank username and blank mobile phone number");
    }

    private static HashMap<String, Object> createUserMapAFAP(String str, String str2, String str3, String str4, String str5) {
        HashMap<String, Object> hashMap = new HashMap<>();
        if (!StringUtil.isEmpty(str)) {
            hashMap.put(ATTR_USERNAME, str);
        }
        if (!StringUtil.isEmpty(str2)) {
            hashMap.put(ATTR_PASSWORD, str2);
        }
        if (!StringUtil.isEmpty(str3)) {
            hashMap.put("email", str3);
        }
        if (!StringUtil.isEmpty(str4)) {
            hashMap.put(ATTR_MOBILEPHONE, str4);
        }
        if (!StringUtil.isEmpty(str5)) {
            hashMap.put(ATTR_SMSCODE, str5);
        }
        return hashMap;
    }

    public static Observable<? extends AVUser> loginWithAuthData(Map<String, Object> map, String str) {
        return loginWithAuthData(internalUserClazz(), map, str);
    }

    public static Observable<? extends AVUser> loginWithAuthData(Map<String, Object> map, String str, String str2, String str3, boolean z) {
        return loginWithAuthData(internalUserClazz(), map, str, str2, str3, z);
    }

    /* JADX DEBUG: Type inference failed for r5v3. Raw type applied. Possible types: io.reactivex.Observable<R>, io.reactivex.Observable<T extends cn.leancloud.AVUser> */
    public static <T extends AVUser> Observable<T> loginWithAuthData(final Class<T> cls, Map<String, Object> map, String str) {
        if (cls == null) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, "clazz")));
        } else if (map == null || map.isEmpty()) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_TAG)));
        } else if (StringUtil.isEmpty(str)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_ATTR_UNIONID_PLATFORM)));
        } else {
            HashMap hashMap = new HashMap();
            HashMap hashMap2 = new HashMap();
            hashMap2.put(str, map);
            hashMap.put(AUTHDATA_TAG, hashMap2);
            return (Observable<R>) PaasClient.getStorageClient().signUp(new JSONObject(hashMap)).map(new Function<AVUser, T>() {
                /* class cn.leancloud.AVUser.AnonymousClass2 */

                public T apply(AVUser aVUser) throws Exception {
                    T t = (T) ((AVUser) Transformer.transform(aVUser, cls));
                    AVUser.changeCurrentUser(t, true);
                    return t;
                }
            });
        }
    }

    public static <T extends AVUser> Observable<T> loginWithAuthData(Class<T> cls, Map<String, Object> map, String str, String str2, String str3, boolean z) {
        if (StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, "unionId")));
        } else if (StringUtil.isEmpty(str3)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, "unionIdPlatform")));
        } else if (map == null || map.isEmpty()) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_TAG)));
        } else {
            map.put(AUTHDATA_ATTR_UNIONID, str2);
            map.put(AUTHDATA_ATTR_UNIONID_PLATFORM, str3);
            if (z) {
                map.put(AUTHDATA_ATTR_MAIN_ACCOUNT, Boolean.valueOf(z));
            }
            return loginWithAuthData(cls, map, str);
        }
    }

    public Observable<AVUser> loginWithAuthData(Map<String, Object> map, String str, boolean z) {
        if (map == null || map.isEmpty()) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_TAG)));
        } else if (StringUtil.isEmpty(str)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_ATTR_UNIONID_PLATFORM)));
        } else {
            HashMap<String, Object> createUserMapAFAP = createUserMapAFAP(getUsername(), null, getEmail(), getMobilePhoneNumber(), null);
            HashMap hashMap = new HashMap();
            hashMap.put(str, map);
            createUserMapAFAP.put(AUTHDATA_TAG, hashMap);
            return PaasClient.getStorageClient().signUpWithFlag(new JSONObject(createUserMapAFAP), z).map(new Function<AVUser, AVUser>() {
                /* class cn.leancloud.AVUser.AnonymousClass3 */

                public AVUser apply(AVUser aVUser) throws Exception {
                    AVUser.this.resetByRawData(aVUser);
                    AVUser.changeCurrentUser(AVUser.this, true);
                    return AVUser.this;
                }
            });
        }
    }

    public Observable<AVUser> loginWithAuthData(Map<String, Object> map, String str, String str2, String str3, boolean z, boolean z2) {
        if (map == null || map.isEmpty()) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_TAG)));
        } else if (StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, "unionId")));
        } else if (StringUtil.isEmpty(str3)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, "unionIdPlatform")));
        } else {
            map.put(AUTHDATA_ATTR_UNIONID, str2);
            map.put(AUTHDATA_ATTR_UNIONID_PLATFORM, str3);
            if (z) {
                map.put(AUTHDATA_ATTR_MAIN_ACCOUNT, Boolean.valueOf(z));
            }
            return loginWithAuthData(map, str, z2);
        }
    }

    /* JADX DEBUG: Type inference failed for r6v6. Raw type applied. Possible types: io.reactivex.Observable<? extends cn.leancloud.AVObject>, io.reactivex.Observable<cn.leancloud.AVUser> */
    public Observable<AVUser> associateWithAuthData(Map<String, Object> map, String str) {
        if (map == null || map.isEmpty()) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_TAG)));
        } else if (StringUtil.isEmpty(str)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_ATTR_UNIONID_PLATFORM)));
        } else {
            HashMap hashMap = new HashMap();
            hashMap.put(str, map);
            Object obj = get(AUTHDATA_TAG);
            if (obj instanceof Map) {
                hashMap.putAll((Map) obj);
            }
            put(AUTHDATA_TAG, hashMap);
            return saveInBackground(new AVSaveOption().setFetchWhenSave(true));
        }
    }

    public Observable<AVUser> associateWithAuthData(Map<String, Object> map, String str, String str2, String str3, boolean z) {
        if (map == null || map.isEmpty()) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_TAG)));
        } else if (StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, "unionId")));
        } else if (StringUtil.isEmpty(str3)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, "unionIdPlatform")));
        } else {
            map.put(AUTHDATA_ATTR_UNIONID, str2);
            map.put(AUTHDATA_ATTR_UNIONID_PLATFORM, str3);
            if (z) {
                map.put(AUTHDATA_ATTR_MAIN_ACCOUNT, true);
            }
            return associateWithAuthData(map, str);
        }
    }

    public Observable<AVUser> dissociateWithAuthData(final String str) {
        if (StringUtil.isEmpty(str)) {
            return Observable.error(new IllegalArgumentException(String.format(ILLEGALARGUMENT_MSG_FORMAT, AUTHDATA_ATTR_UNIONID_PLATFORM)));
        } else if (StringUtil.isEmpty(getObjectId()) || !isAuthenticated()) {
            return Observable.error(new AVException((int) AVException.SESSION_MISSING, "the user object missing a valid session"));
        } else {
            remove("authData." + str);
            return saveInBackground().map(new Function<AVObject, AVUser>() {
                /* class cn.leancloud.AVUser.AnonymousClass4 */

                public AVUser apply(AVObject aVObject) throws Exception {
                    Map map = (Map) AVUser.this.get(AVUser.AUTHDATA_TAG);
                    if (map != null) {
                        map.remove(str);
                    }
                    return AVUser.this;
                }
            });
        }
    }

    public Observable<Boolean> checkAuthenticatedInBackground() {
        String sessionToken = getSessionToken();
        if (!StringUtil.isEmpty(sessionToken)) {
            return PaasClient.getStorageClient().checkAuthenticated(sessionToken);
        }
        logger.d("sessionToken is not existed.");
        return Observable.just(false);
    }

    public Observable<Boolean> refreshSessionTokenInBackground() {
        return PaasClient.getStorageClient().refreshSessionToken(this);
    }

    public static AVUser becomeWithSessionToken(String str) {
        return (AVUser) becomeWithSessionTokenInBackground(str).blockingFirst();
    }

    public static Observable<? extends AVUser> becomeWithSessionTokenInBackground(String str) {
        return becomeWithSessionTokenInBackground(str, internalUserClazz());
    }

    public static <T extends AVUser> T becomeWithSessionToken(String str, Class<T> cls) {
        return (T) ((AVUser) becomeWithSessionTokenInBackground(str, cls).blockingFirst());
    }

    public static <T extends AVUser> Observable<T> becomeWithSessionTokenInBackground(String str, Class<T> cls) {
        return PaasClient.getStorageClient().createUserBySession(str, cls);
    }

    public static void logOut() {
        changeCurrentUser(null, true);
    }

    public static <T extends AVUser> AVQuery<T> getUserQuery(Class<T> cls) {
        return new AVQuery<>(CLASS_NAME, cls);
    }

    public static AVQuery<AVUser> getQuery() {
        return getQuery(AVUser.class);
    }

    public Observable<List<AVRole>> getRolesInBackground() {
        AVQuery aVQuery = new AVQuery(AVRole.CLASS_NAME);
        aVQuery.whereEqualTo("users", this);
        return aVQuery.findInBackground();
    }

    public static void enableAutomaticUser() {
        enableAutomatic = true;
    }

    @JSONField(serialize = false)
    public static boolean isEnableAutomatic() {
        return enableAutomatic;
    }

    public static void disableAutomaticUser() {
        enableAutomatic = false;
    }

    private static File currentUserArchivePath() {
        return new File(AppConfiguration.getDocumentDir() + "/currentUser");
    }

    private static boolean userArchiveExist() {
        return currentUserArchivePath().exists();
    }

    public static synchronized void changeCurrentUser(AVUser aVUser, boolean z) {
        synchronized (AVUser.class) {
            if (aVUser != null) {
                aVUser.setPassword(null);
            }
            File currentUserArchivePath = currentUserArchivePath();
            if (aVUser != null && z) {
                String jSONString = aVUser.toJSONString();
                logger.d(jSONString);
                PersistenceUtil.sharedInstance().saveContentToFile(jSONString, currentUserArchivePath);
            } else if (z) {
                PersistenceUtil.sharedInstance().removeLock(currentUserArchivePath.getAbsolutePath());
                if (!currentUserArchivePath.delete()) {
                    logger.w("failed to delete currentUser cache file.");
                }
            }
            PaasClient.getStorageClient().setCurrentUser(aVUser);
        }
    }

    public static AVUser getCurrentUser() {
        return getCurrentUser(internalUserClazz());
    }

    public static <T extends AVUser> T getCurrentUser(Class<T> cls) {
        T t;
        Exception e;
        AVUser aVUser;
        Exception e2;
        AVUser aVUser2;
        T t2 = (T) PaasClient.getStorageClient().getCurrentUser();
        if (t2 != null && cls.isAssignableFrom(t2.getClass())) {
            return t2;
        }
        if (userArchiveExist()) {
            File currentUserArchivePath = currentUserArchivePath();
            synchronized (AVUser.class) {
                String readContentFromFile = PersistenceUtil.sharedInstance().readContentFromFile(currentUserArchivePath);
                if (!StringUtil.isEmpty(readContentFromFile)) {
                    if (readContentFromFile.indexOf("@type") >= 0 || readContentFromFile.indexOf(ObjectTypeAdapter.KEY_VERSION) >= 0) {
                        try {
                            AVUser aVUser3 = (AVUser) AVObject.parseAVObject(readContentFromFile);
                            try {
                                PaasClient.getStorageClient().setCurrentUser(aVUser3);
                                aVUser2 = aVUser3;
                            } catch (Exception e3) {
                                e2 = e3;
                                aVUser = aVUser3;
                                logger.w("failed to deserialize AVUser instance.", e2);
                                aVUser2 = aVUser;
                                t2 = (T) aVUser2;
                                try {
                                    t = cls.newInstance();
                                    try {
                                        changeCurrentUser(t, true);
                                    } catch (Exception e4) {
                                        e = e4;
                                    }
                                } catch (Exception e5) {
                                    t = t2;
                                    e = e5;
                                    logger.w(e);
                                    t2 = t;
                                    return (T) ((AVUser) Transformer.transform(t2, cls));
                                }
                                t2 = t;
                                return (T) ((AVUser) Transformer.transform(t2, cls));
                            }
                        } catch (Exception e6) {
                            aVUser = t2;
                            e2 = e6;
                            logger.w("failed to deserialize AVUser instance.", e2);
                            aVUser2 = aVUser;
                            t2 = (T) aVUser2;
                            t = cls.newInstance();
                            changeCurrentUser(t, true);
                            t2 = t;
                            return (T) ((AVUser) Transformer.transform(t2, cls));
                        }
                        t2 = (T) aVUser2;
                    } else {
                        try {
                            T newInstance = cls.newInstance();
                            newInstance.resetServerData((Map) JSON.parseObject(readContentFromFile, Map.class));
                            changeCurrentUser(newInstance, true);
                            t2 = newInstance;
                        } catch (Exception e7) {
                            logger.w(e7);
                        }
                    }
                }
            }
        }
        if (enableAutomatic && t2 == null) {
            t = cls.newInstance();
            changeCurrentUser(t, true);
            t2 = t;
        }
        return (T) ((AVUser) Transformer.transform(t2, cls));
    }

    public static Observable<AVNull> requestPasswordResetInBackground(String str) {
        return PaasClient.getStorageClient().requestResetPassword(str);
    }

    public static Observable<AVNull> requestPasswordResetBySmsCodeInBackground(String str) {
        return requestPasswordResetBySmsCodeInBackground(str, null);
    }

    public static Observable<AVNull> requestPasswordResetBySmsCodeInBackground(String str, String str2) {
        return PaasClient.getStorageClient().requestResetPasswordBySmsCode(str, str2);
    }

    public static Observable<AVNull> resetPasswordBySmsCodeInBackground(String str, String str2) {
        return PaasClient.getStorageClient().resetPasswordBySmsCode(str, str2);
    }

    public Observable<AVNull> updatePasswordInBackground(String str, String str2) {
        return PaasClient.getStorageClient().updatePassword(this, str, str2);
    }

    public static Observable<AVNull> requestEmailVerifyInBackground(String str) {
        return PaasClient.getStorageClient().requestEmailVerify(str);
    }

    public static Observable<AVNull> requestMobilePhoneVerifyInBackground(String str) {
        if (StringUtil.isEmpty(str) || !AVSMS.checkMobilePhoneNumber(str)) {
            return Observable.error(new IllegalArgumentException("mobile phone number is empty or invalid"));
        }
        return requestMobilePhoneVerifyInBackground(str, null);
    }

    public static Observable<AVNull> requestMobilePhoneVerifyInBackground(String str, String str2) {
        if (StringUtil.isEmpty(str) || !AVSMS.checkMobilePhoneNumber(str)) {
            return Observable.error(new IllegalArgumentException("mobile phone number is empty or invalid"));
        }
        return PaasClient.getStorageClient().requestMobilePhoneVerify(str, str2);
    }

    public static Observable<AVNull> requestLoginSmsCodeInBackground(String str) {
        if (StringUtil.isEmpty(str) || !AVSMS.checkMobilePhoneNumber(str)) {
            return Observable.error(new IllegalArgumentException("mobile phone number is empty or invalid"));
        }
        return requestLoginSmsCodeInBackground(str, null);
    }

    public static Observable<AVNull> requestLoginSmsCodeInBackground(String str, String str2) {
        if (StringUtil.isEmpty(str) || !AVSMS.checkMobilePhoneNumber(str)) {
            return Observable.error(new IllegalArgumentException("mobile phone number is empty or invalid"));
        }
        return PaasClient.getStorageClient().requestLoginSmsCode(str, str2);
    }

    public static Observable<AVNull> verifyMobilePhoneInBackground(String str) {
        return PaasClient.getStorageClient().verifyMobilePhone(str);
    }

    public static Observable<AVNull> requestSMSCodeForUpdatingPhoneNumberInBackground(String str, AVSMSOption aVSMSOption) {
        if (StringUtil.isEmpty(str) || !AVSMS.checkMobilePhoneNumber(str)) {
            return Observable.error(new IllegalArgumentException("mobile phone number is empty or invalid"));
        }
        return PaasClient.getStorageClient().requestSMSCodeForUpdatingPhoneNumber(str, aVSMSOption == null ? new HashMap<>() : aVSMSOption.getOptionMap());
    }

    public static Observable<AVNull> verifySMSCodeForUpdatingPhoneNumberInBackground(String str, String str2) {
        if (StringUtil.isEmpty(str) || StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException("code or mobilePhone is empty"));
        }
        return PaasClient.getStorageClient().verifySMSCodeForUpdatingPhoneNumber(str, str2);
    }

    private boolean checkUserAuthentication(AVCallback aVCallback) {
        if (isAuthenticated() && !StringUtil.isEmpty(getObjectId())) {
            return true;
        }
        if (aVCallback == null) {
            return false;
        }
        aVCallback.internalDone(ErrorUtils.propagateException(AVException.SESSION_MISSING, "No valid session token, make sure signUp or login has been called."));
        return false;
    }

    public Observable<JSONObject> followInBackground(String str) {
        return followInBackground(str, new JSONObject());
    }

    public Observable<JSONObject> followInBackground(String str, Map<String, Object> map) {
        if (!checkUserAuthentication(null)) {
            return Observable.error(ErrorUtils.propagateException(AVException.SESSION_MISSING, "No valid session token, make sure signUp or login has been called."));
        }
        return PaasClient.getStorageClient().followUser(getObjectId(), str, map);
    }

    public Observable<JSONObject> unfollowInBackground(String str) {
        if (!checkUserAuthentication(null)) {
            return Observable.error(ErrorUtils.propagateException(AVException.SESSION_MISSING, "No valid session token, make sure signUp or login has been called."));
        }
        return PaasClient.getStorageClient().unfollowUser(getObjectId(), str);
    }

    public AVQuery<AVObject> followerQuery() {
        return followerQuery(getObjectId(), AVObject.class);
    }

    public AVQuery<AVObject> followeeQuery() {
        return followeeQuery(getObjectId(), AVObject.class);
    }

    public static <T extends AVObject> AVQuery<T> followerQuery(String str, Class<T> cls) {
        if (!StringUtil.isEmpty(str)) {
            AVQuery<T> aVQuery = new AVQuery<>("_Follower", cls);
            aVQuery.whereEqualTo("user", createWithoutData(CLASS_NAME, str));
            aVQuery.include(FOLLOWER_TAG);
            return aVQuery;
        }
        throw new IllegalArgumentException("Blank user objectId");
    }

    public static <T extends AVObject> AVQuery<T> followeeQuery(String str, Class<T> cls) {
        if (!StringUtil.isEmpty(str)) {
            AVQuery<T> aVQuery = new AVQuery<>("_Followee", cls);
            aVQuery.whereEqualTo("user", createWithoutData(CLASS_NAME, str));
            aVQuery.include(FOLLOWEE_TAG);
            return aVQuery;
        }
        throw new IllegalArgumentException("Blank user objectId");
    }

    private void processResultList(List<JSONObject> list, List<AVUser> list2, String str) {
        for (JSONObject jSONObject : list) {
            if (jSONObject != null) {
                list2.add((AVUser) Utils.parseObjectFromMap((Map) jSONObject.get(str)));
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Map<String, List<AVUser>> parseFollowerAndFollowee(JSONObject jSONObject) {
        HashMap hashMap = new HashMap();
        if (jSONObject != null) {
            List<JSONObject> list = (List) jSONObject.get("followers");
            if (list != null) {
                LinkedList linkedList = new LinkedList();
                processResultList(list, linkedList, FOLLOWER_TAG);
                hashMap.put(FOLLOWER_TAG, linkedList);
            }
            List<JSONObject> list2 = (List) jSONObject.get("followees");
            if (list2 != null) {
                LinkedList linkedList2 = new LinkedList();
                processResultList(list2, linkedList2, FOLLOWEE_TAG);
                hashMap.put(FOLLOWEE_TAG, linkedList2);
            }
        }
        return hashMap;
    }

    public void getFollowersAndFolloweesInBackground(final FollowersAndFolloweesCallback followersAndFolloweesCallback) {
        if (followersAndFolloweesCallback != null && checkUserAuthentication(followersAndFolloweesCallback)) {
            PaasClient.getStorageClient().getFollowersAndFollowees(getObjectId()).subscribe(new Observer<JSONObject>() {
                /* class cn.leancloud.AVUser.AnonymousClass5 */

                @Override // io.reactivex.Observer
                public void onComplete() {
                }

                @Override // io.reactivex.Observer
                public void onSubscribe(Disposable disposable) {
                }

                public void onNext(JSONObject jSONObject) {
                    if (jSONObject == null) {
                        followersAndFolloweesCallback.done(null, null);
                        return;
                    }
                    followersAndFolloweesCallback.done(AVUser.this.parseFollowerAndFollowee(jSONObject), null);
                }

                @Override // io.reactivex.Observer
                public void onError(Throwable th) {
                    followersAndFolloweesCallback.done(null, new AVException(th));
                }
            });
        }
    }

    public static void alwaysUseSubUserClass(Class<? extends AVUser> cls) {
        registerSubclass(cls);
        subClazz = cls;
    }

    private static Class internalUserClazz() {
        Class<? extends AVUser> cls = subClazz;
        return cls == null ? AVUser.class : cls;
    }

    public static <T extends AVUser> T cast(AVUser aVUser, Class<T> cls) {
        try {
            return (T) ((AVUser) AVObject.cast(aVUser, cls));
        } catch (Exception unused) {
            return null;
        }
    }
}
