package cn.leancloud;

import cn.leancloud.cache.PersistenceUtil;
import cn.leancloud.codec.MD5;
import cn.leancloud.core.AVOSCloud;
import cn.leancloud.core.AppConfiguration;
import cn.leancloud.network.NetworkingDetector;
import cn.leancloud.ops.BaseOperation;
import cn.leancloud.types.AVNull;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.serializer.SerializerFeature;
import io.reactivex.Observer;
import io.reactivex.disposables.Disposable;
import java.io.File;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Timer;
import java.util.TimerTask;

public class ArchivedRequests {
    private static final String ATTR_INTERNAL_ID = "internalId";
    private static final String ATTR_METHOD = "method";
    private static final String ATTR_OBJECT = "objectJson";
    private static final String ATTR_OPERATION = "opertions";
    private static final String METHOD_DELETE = "Delete";
    private static final String METHOD_SAVE = "Save";
    private static ArchivedRequests instance = null;
    private static final AVLogger logger = LogUtil.getLogger(ArchivedRequests.class);
    private Map<String, AVObject> deleteObjects = new HashMap();
    private Map<String, AVObject> saveObjects = new HashMap();
    private Timer timer = null;

    public static synchronized ArchivedRequests getInstance() {
        ArchivedRequests archivedRequests;
        synchronized (ArchivedRequests.class) {
            if (instance == null) {
                instance = new ArchivedRequests();
            }
            archivedRequests = instance;
        }
        return archivedRequests;
    }

    private ArchivedRequests() {
        String commandCacheDir = AppConfiguration.getCommandCacheDir();
        PersistenceUtil.sharedInstance();
        for (File file : PersistenceUtil.listFiles(commandCacheDir)) {
            parseArchiveFile(file);
        }
        this.timer = new Timer(true);
        this.timer.schedule(new TimerTask() {
            /* class cn.leancloud.ArchivedRequests.AnonymousClass1 */

            public void run() {
                ArchivedRequests.logger.i("begin to run timer task for archived request.");
                NetworkingDetector globalNetworkingDetector = AppConfiguration.getGlobalNetworkingDetector();
                if (globalNetworkingDetector == null || !globalNetworkingDetector.isConnected()) {
                    ArchivedRequests.logger.i("ignore timer task bcz networking is unavailable.");
                } else if (!ArchivedRequests.this.saveObjects.isEmpty() || !ArchivedRequests.this.deleteObjects.isEmpty()) {
                    if (ArchivedRequests.this.saveObjects.size() > 0) {
                        ArchivedRequests archivedRequests = ArchivedRequests.this;
                        archivedRequests.sendArchivedRequest(archivedRequests.saveObjects, false);
                    }
                    if (ArchivedRequests.this.deleteObjects.size() > 0) {
                        ArchivedRequests archivedRequests2 = ArchivedRequests.this;
                        archivedRequests2.sendArchivedRequest(archivedRequests2.deleteObjects, true);
                    }
                    ArchivedRequests.logger.i("end to run timer task for archived request.");
                } else {
                    ArchivedRequests.logger.i("ignore timer task bcz request queue is empty.");
                }
            }
        }, 10000, 15000);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendArchivedRequest(final Map<String, AVObject> map, final boolean z) {
        if (map != null && !map.isEmpty()) {
            Collection<AVObject> values = map.values();
            int i = 0;
            int i2 = 5;
            if (values.size() <= 5) {
                i2 = values.size();
            }
            Iterator<AVObject> it = values.iterator();
            while (i < i2 && it.hasNext()) {
                final AVObject next = it.next();
                i++;
                if (z) {
                    next.deleteInBackground().subscribe(new Observer<AVNull>() {
                        /* class cn.leancloud.ArchivedRequests.AnonymousClass2 */

                        @Override // io.reactivex.Observer
                        public void onComplete() {
                        }

                        @Override // io.reactivex.Observer
                        public void onSubscribe(Disposable disposable) {
                        }

                        public void onNext(AVNull aVNull) {
                            map.remove(next.internalId());
                            File archivedFile = ArchivedRequests.this.getArchivedFile(next, z);
                            if (!PersistenceUtil.sharedInstance().forceDeleteFile(archivedFile)) {
                                AVLogger aVLogger = ArchivedRequests.logger;
                                aVLogger.w("failed to delete file:" + archivedFile.getAbsolutePath() + " for objectInternalId: " + next.internalId());
                                return;
                            }
                            AVLogger aVLogger2 = ArchivedRequests.logger;
                            aVLogger2.d("succeed to delete file:" + archivedFile.getAbsolutePath() + " for objectInternalId: " + next.internalId());
                        }

                        @Override // io.reactivex.Observer
                        public void onError(Throwable th) {
                            ArchivedRequests.logger.w("failed to delete archived request. cause: ", th);
                        }
                    });
                } else {
                    next.saveInBackground().subscribe(new Observer<AVObject>() {
                        /* class cn.leancloud.ArchivedRequests.AnonymousClass3 */

                        @Override // io.reactivex.Observer
                        public void onComplete() {
                        }

                        @Override // io.reactivex.Observer
                        public void onSubscribe(Disposable disposable) {
                        }

                        public void onNext(AVObject aVObject) {
                            map.remove(next.internalId());
                            File archivedFile = ArchivedRequests.this.getArchivedFile(next, z);
                            if (!PersistenceUtil.sharedInstance().forceDeleteFile(archivedFile)) {
                                AVLogger aVLogger = ArchivedRequests.logger;
                                aVLogger.w("failed to delete file:" + archivedFile.getAbsolutePath() + " for objectInternalId: " + next.internalId());
                                return;
                            }
                            AVLogger aVLogger2 = ArchivedRequests.logger;
                            aVLogger2.d("succeed to delete file:" + archivedFile.getAbsolutePath() + " for objectInternalId: " + next.internalId());
                        }

                        @Override // io.reactivex.Observer
                        public void onError(Throwable th) {
                            ArchivedRequests.logger.w("failed to save archived request. cause: ", th);
                        }
                    });
                }
            }
        }
    }

    public void saveEventually(AVObject aVObject) {
        if (aVObject != null) {
            saveArchivedRequest(aVObject, false);
            this.saveObjects.put(aVObject.internalId(), aVObject);
        }
    }

    public void deleteEventually(AVObject aVObject) {
        if (aVObject != null) {
            saveArchivedRequest(aVObject, true);
            this.deleteObjects.put(aVObject.internalId(), aVObject);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File getArchivedFile(AVObject aVObject, boolean z) {
        return new File(AppConfiguration.getCommandCacheDir(), getArchiveRequestFileName(aVObject));
    }

    private void saveArchivedRequest(AVObject aVObject, boolean z) {
        PersistenceUtil.sharedInstance().saveContentToFile(getArchiveContent(aVObject, z), getArchivedFile(aVObject, z));
    }

    public static String getArchiveContent(AVObject aVObject, boolean z) {
        HashMap hashMap = new HashMap(3);
        hashMap.put("method", z ? METHOD_DELETE : METHOD_SAVE);
        hashMap.put(ATTR_INTERNAL_ID, aVObject.internalId());
        hashMap.put(ATTR_OBJECT, aVObject.toJSONString());
        if (AVOSCloud.isEnableCircularReferenceDetect()) {
            hashMap.put(ATTR_OPERATION, JSON.toJSONString(aVObject.operations.values(), ObjectValueFilter.instance, SerializerFeature.QuoteFieldNames));
        } else {
            hashMap.put(ATTR_OPERATION, JSON.toJSONString(aVObject.operations.values(), ObjectValueFilter.instance, SerializerFeature.QuoteFieldNames, SerializerFeature.DisableCircularReferenceDetect));
        }
        return JSON.toJSONString(hashMap);
    }

    private void parseArchiveFile(File file) {
        if (file != null) {
            if (!AVObject.verifyInternalId(file.getName())) {
                AVLogger aVLogger = logger;
                aVLogger.d("ignore invalid file. " + file.getAbsolutePath());
                return;
            }
            String readContentFromFile = PersistenceUtil.sharedInstance().readContentFromFile(file);
            if (!StringUtil.isEmpty(readContentFromFile)) {
                try {
                    Map map = (Map) JSON.parseObject(readContentFromFile, Map.class);
                    String str = (String) map.get("method");
                    AVObject parseAVObject = parseAVObject(map);
                    AVLogger aVLogger2 = logger;
                    aVLogger2.d("get archived request. method=" + str + ", object=" + parseAVObject.toString());
                    if (METHOD_SAVE.equalsIgnoreCase(str)) {
                        this.saveObjects.put(parseAVObject.internalId(), parseAVObject);
                    } else {
                        this.deleteObjects.put(parseAVObject.internalId(), parseAVObject);
                    }
                } catch (Exception e) {
                    logger.w("encounter exception whiling parse archived file.", e);
                }
            }
        }
    }

    protected static AVObject parseAVObject(String str) {
        return parseAVObject((Map) JSON.parseObject(str, Map.class));
    }

    private static AVObject parseAVObject(Map<String, String> map) {
        String str = map.get(ATTR_INTERNAL_ID);
        String str2 = map.get(ATTR_OPERATION);
        AVObject parseAVObject = AVObject.parseAVObject(map.get(ATTR_OBJECT));
        if (!StringUtil.isEmpty(str) && !str.equals(parseAVObject.getObjectId())) {
            parseAVObject.setUuid(str);
        }
        if (!StringUtil.isEmpty(str2)) {
            for (BaseOperation baseOperation : (List) JSON.parseObject(str2, new TypeReference<List<BaseOperation>>() {
                /* class cn.leancloud.ArchivedRequests.AnonymousClass4 */
            }, Feature.IgnoreNotMatch)) {
                parseAVObject.addNewOperation(baseOperation);
            }
        }
        return parseAVObject;
    }

    private static String getArchiveRequestFileName(AVObject aVObject) {
        if (StringUtil.isEmpty(aVObject.getObjectId())) {
            return aVObject.internalId();
        }
        return MD5.computeMD5(aVObject.getRequestRawEndpoint());
    }
}
