package cn.leancloud;

import cn.leancloud.core.AVOSCloud;
import cn.leancloud.ops.Utils;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.serializer.JSONSerializer;
import com.alibaba.fastjson.serializer.ObjectSerializer;
import com.alibaba.fastjson.serializer.SerializeWriter;
import com.alibaba.fastjson.serializer.SerializerFeature;
import java.io.IOException;
import java.lang.reflect.Type;
import java.util.Collection;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class ObjectTypeAdapter implements ObjectSerializer, ObjectDeserializer {
    private static final String DEFAULT_VERSION = "5";
    public static final String KEY_SERVERDATA = "serverData";
    public static final String KEY_VERSION = "_version";
    private static AVLogger LOGGER = LogUtil.getLogger(ObjectTypeAdapter.class);

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 14;
    }

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public void write(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type);
    }

    public void write(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type) throws IOException {
        AVObject aVObject = (AVObject) obj;
        SerializeWriter writer = jSONSerializer.getWriter();
        writer.write(123);
        writer.write(32);
        writer.writeFieldName(KEY_VERSION, false);
        writer.writeString(DEFAULT_VERSION);
        writer.write(44);
        writer.writeFieldName(AVObject.KEY_CLASSNAME, false);
        writer.writeString(aVObject.getClassName());
        writer.write(44);
        writer.writeFieldName(KEY_SERVERDATA, false);
        if (AVOSCloud.isEnableCircularReferenceDetect()) {
            writer.write(JSON.toJSONString(aVObject.serverData, ObjectValueFilter.instance, SerializerFeature.WriteClassName));
        } else {
            writer.write(JSON.toJSONString(aVObject.serverData, ObjectValueFilter.instance, SerializerFeature.WriteClassName, SerializerFeature.DisableCircularReferenceDetect));
        }
        writer.write(125);
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj) {
        String str;
        if (!AVObject.class.isAssignableFrom((Class) type)) {
            return (T) defaultJSONParser.parseObject();
        }
        Map map = (Map) defaultJSONParser.parseObject((Class) Map.class);
        if (map.containsKey(KEY_VERSION)) {
            str = (String) map.get(AVObject.KEY_CLASSNAME);
            if (map.containsKey(KEY_SERVERDATA)) {
                map = (Map) map.get(KEY_SERVERDATA);
            }
        } else if (map.containsKey(AVObject.KEY_CLASSNAME)) {
            str = (String) map.get(AVObject.KEY_CLASSNAME);
            map.remove(AVObject.KEY_CLASSNAME);
            if (map.containsKey(KEY_SERVERDATA)) {
                map.remove(KEY_SERVERDATA);
                map.putAll((ConcurrentHashMap) map.get(KEY_SERVERDATA));
            }
            map.remove("operationQueue");
        } else {
            str = "";
        }
        T t = type.toString().endsWith(AVFile.class.getCanonicalName()) ? (T) new AVFile() : type.toString().endsWith(AVUser.class.getCanonicalName()) ? (T) new AVUser() : type.toString().endsWith(AVInstallation.class.getCanonicalName()) ? (T) new AVInstallation() : type.toString().endsWith(AVStatus.class.getCanonicalName()) ? (T) new AVStatus() : type.toString().endsWith(AVRole.class.getCanonicalName()) ? (T) new AVRole() : !StringUtil.isEmpty(str) ? (T) Transformer.objectFromClassName(str) : (T) new AVObject();
        for (Map.Entry entry : map.entrySet()) {
            String str2 = (String) entry.getKey();
            Object value = entry.getValue();
            if ((value instanceof String) || (value instanceof Number) || (value instanceof Boolean) || (value instanceof Byte) || (value instanceof Character)) {
                t.serverData.put(str2, value);
            } else if ((value instanceof Map) || (value instanceof JSONObject)) {
                t.serverData.put(str2, Utils.getObjectFrom(value));
            } else if (value instanceof Collection) {
                t.serverData.put(str2, Utils.getObjectFrom(value));
            } else if (value != null) {
                t.serverData.put(str2, value);
            }
        }
        return t;
    }
}
