package cn.leancloud;

import cn.leancloud.AVStatusQuery;
import com.alibaba.fastjson.JSON;
import java.util.Map;

/* access modifiers changed from: package-private */
public class StatusIterator {
    private AVStatusQuery.PaginationDirection direction;
    AVStatus lastStatus;
    private long maxId;
    private int pageSize;
    private long sinceId;
    AVStatusQuery.SourceType sourceType;

    public StatusIterator(AVStatusQuery.SourceType sourceType2) {
        this(sourceType2, AVStatusQuery.PaginationDirection.NEW_TO_OLD, 0);
    }

    public StatusIterator(AVStatusQuery.SourceType sourceType2, AVStatusQuery.PaginationDirection paginationDirection, int i) {
        this.lastStatus = null;
        this.sinceId = (long) AVStatus.INVALID_MESSAGE_ID;
        this.maxId = (long) AVStatus.INVALID_MESSAGE_ID;
        this.sourceType = sourceType2;
        this.direction = paginationDirection;
        this.pageSize = i;
    }

    public int getPageSize() {
        return this.pageSize;
    }

    public void setPageSize(int i) {
        if (i > 0 && i < 200) {
            this.pageSize = i;
        }
    }

    public long getSinceId() {
        return this.sinceId;
    }

    public void setSinceId(long j) {
        this.sinceId = j;
    }

    public long getMaxId() {
        return this.maxId;
    }

    public void setMaxId(long j) {
        this.maxId = j;
    }

    public AVStatusQuery.PaginationDirection getDirection() {
        return this.direction;
    }

    public void setDirection(AVStatusQuery.PaginationDirection paginationDirection) {
        this.direction = paginationDirection;
    }

    public void fillConditions(AVQuery aVQuery) {
        if (aVQuery != null && this.lastStatus != null) {
            if (AVStatusQuery.PaginationDirection.NEW_TO_OLD == this.direction) {
                aVQuery.whereLessThan(AVObject.KEY_CREATED_AT, this.lastStatus.getCreatedAt());
            } else {
                aVQuery.whereGreaterThan(AVObject.KEY_CREATED_AT, this.lastStatus.getCreatedAt());
            }
        }
    }

    public void fillConditions(Map<String, String> map) {
        if (this.direction == AVStatusQuery.PaginationDirection.OLD_TO_NEW && this.sinceId > ((long) AVStatus.INVALID_MESSAGE_ID)) {
            map.put("sinceId", String.valueOf(this.sinceId));
        }
        if (this.direction == AVStatusQuery.PaginationDirection.NEW_TO_OLD && this.maxId > ((long) AVStatus.INVALID_MESSAGE_ID)) {
            map.put("maxId", String.valueOf(this.maxId - 1));
        }
    }

    public void encounter(AVStatus aVStatus) {
        this.lastStatus = aVStatus;
        if (AVStatusQuery.SourceType.INBOX == this.sourceType && aVStatus != null) {
            if (this.direction == AVStatusQuery.PaginationDirection.OLD_TO_NEW) {
                if (aVStatus.getMessageId() > this.sinceId) {
                    this.sinceId = aVStatus.getMessageId();
                }
            } else if (0 == this.maxId) {
                this.maxId = aVStatus.getMessageId();
            } else if (aVStatus.getMessageId() < this.maxId) {
                this.maxId = aVStatus.getMessageId();
            }
        }
    }

    public String toString() {
        return JSON.toJSONString(this);
    }
}
