package cn.leancloud;

import cn.leancloud.annotation.AVClassName;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.serializer.ObjectSerializer;
import com.alibaba.fastjson.serializer.SerializeConfig;
import java.lang.reflect.Type;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Pattern;

public class Transformer {
    private static Pattern classnamePattern = Pattern.compile("^[a-zA-Z_][a-zA-Z_0-9]*$");
    private static AVLogger logger = LogUtil.getLogger(Transformer.class);
    private static final Map<String, Class<? extends AVObject>> subClassesMAP = new HashMap();
    private static final Map<Class<? extends AVObject>, String> subClassesReverseMAP = new HashMap();

    static Class<? extends AVObject> getSubClass(String str) {
        return subClassesMAP.get(str);
    }

    public static String getSubClassName(Class<? extends AVObject> cls) {
        if (AVUser.class.isAssignableFrom(cls)) {
            return AVUser.CLASS_NAME;
        }
        if (AVRole.class.isAssignableFrom(cls)) {
            return AVRole.CLASS_NAME;
        }
        if (AVStatus.class.isAssignableFrom(cls)) {
            return AVStatus.CLASS_NAME;
        }
        if (AVFile.class.isAssignableFrom(cls)) {
            return AVFile.CLASS_NAME;
        }
        return subClassesReverseMAP.get(cls);
    }

    public static <T extends AVObject> void registerClass(Class<T> cls) {
        AVClassName aVClassName = (AVClassName) cls.getAnnotation(AVClassName.class);
        if (aVClassName != null) {
            String value = aVClassName.value();
            checkClassName(value);
            subClassesMAP.put(value, cls);
            subClassesReverseMAP.put(cls, value);
            ParserConfig.getGlobalInstance().putDeserializer(cls, new ObjectTypeAdapter());
            SerializeConfig.getGlobalInstance().put((Type) cls, (ObjectSerializer) new ObjectTypeAdapter());
            return;
        }
        throw new IllegalArgumentException("The class is not annotated by @AVClassName");
    }

    public static <T extends AVObject> T transform(AVObject aVObject, String str) {
        if (aVObject == null) {
            return null;
        }
        T t = (T) objectFromClassName(str);
        t.resetByRawData(aVObject);
        return t;
    }

    public static <T extends AVObject> T transform(AVObject aVObject, Class<T> cls) {
        AVFile aVFile;
        if (aVObject == null) {
            return null;
        }
        if (subClassesReverseMAP.containsKey(cls)) {
            try {
                aVFile = cls.newInstance();
            } catch (Exception e) {
                AVLogger aVLogger = logger;
                aVLogger.w("newInstance failed. cause: " + e.getMessage());
                aVFile = (T) new AVObject(cls.getSimpleName());
            }
        } else if (AVUser.class.isAssignableFrom(cls)) {
            aVFile = new AVUser();
        } else if (AVRole.class.isAssignableFrom(cls)) {
            aVFile = new AVRole();
        } else if (AVStatus.class.isAssignableFrom(cls)) {
            aVFile = new AVStatus();
        } else {
            aVFile = AVFile.class.isAssignableFrom(cls) ? new AVFile() : (T) new AVObject(cls.getSimpleName());
        }
        aVFile.resetByRawData(aVObject);
        return aVFile;
    }

    public static void checkClassName(String str) {
        if (StringUtil.isEmpty(str)) {
            throw new IllegalArgumentException("Blank class name");
        } else if (!classnamePattern.matcher(str).matches()) {
            throw new IllegalArgumentException("Invalid class name");
        }
    }

    public static AVObject objectFromClassName(String str) {
        AVObject aVObject;
        if (AVUser.CLASS_NAME.equals(str)) {
            return new AVUser();
        }
        if (AVStatus.CLASS_NAME.equals(str)) {
            return new AVStatus();
        }
        if (AVRole.CLASS_NAME.equals(str)) {
            return new AVRole();
        }
        if (AVFile.CLASS_NAME.equals(str)) {
            return new AVFile();
        }
        if (AVInstallation.CLASS_NAME.equals(str)) {
            return new AVInstallation();
        }
        Map<String, Class<? extends AVObject>> map = subClassesMAP;
        if (map.containsKey(str)) {
            try {
                aVObject = (AVObject) map.get(str).newInstance();
            } catch (Exception e) {
                AVLogger aVLogger = logger;
                aVLogger.w("failed to create subClass: " + str, e);
                aVObject = new AVObject(str);
            }
        } else {
            aVObject = new AVObject(str);
        }
        return aVObject;
    }

    private Transformer() {
    }
}
