package cn.leancloud.cache;

import cn.leancloud.utils.StringUtil;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;

public class LocalStorage {
    private String baseDir;
    private boolean disableLocalCache = false;

    public LocalStorage(String str) {
        if (StringUtil.isEmpty(str)) {
            this.disableLocalCache = true;
            return;
        }
        if (!str.endsWith("/")) {
            str = str + "/";
        }
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        this.baseDir = str;
    }

    public String saveData(String str, byte[] bArr) {
        if (this.disableLocalCache || StringUtil.isEmpty(str) || bArr == null) {
            return null;
        }
        String str2 = this.baseDir + str;
        PersistenceUtil.sharedInstance().saveContentToFile(bArr, new File(str2));
        return str2;
    }

    public String saveFile(String str, File file) {
        if (!this.disableLocalCache && !StringUtil.isEmpty(str) && file != null && file.exists() && file.isFile()) {
            String str2 = this.baseDir + str;
            if (PersistenceUtil.sharedInstance().saveFileToLocal(str2, file)) {
                return str2;
            }
        }
        return null;
    }

    public byte[] readData(String str) {
        if (this.disableLocalCache || StringUtil.isEmpty(str)) {
            return null;
        }
        return readData(new File(this.baseDir + str));
    }

    public byte[] readData(File file) {
        if (this.disableLocalCache) {
            return null;
        }
        return PersistenceUtil.sharedInstance().readContentBytesFromFile(file);
    }

    public File getCacheFile(String str) {
        if (this.disableLocalCache || StringUtil.isEmpty(str)) {
            return null;
        }
        return new File(this.baseDir + str);
    }

    public InputStream getInputStreamFromFile(File file) throws FileNotFoundException {
        if (this.disableLocalCache) {
            return null;
        }
        return new FileInputStream(file);
    }

    public void clearCachedFile(String str) {
        if (!this.disableLocalCache && !StringUtil.isEmpty(str)) {
            PersistenceUtil.sharedInstance().deleteFile(this.baseDir + str);
        }
    }

    public void clearAllCachedFiles() {
        if (!this.disableLocalCache) {
            clearCacheMoreThanDays(0);
        }
    }

    public void clearCacheMoreThanDays(int i) {
        if (!this.disableLocalCache) {
            long currentTimeMillis = System.currentTimeMillis();
            if (i > 0) {
                currentTimeMillis -= ((long) i) * 86400000;
            }
            PersistenceUtil.sharedInstance().clearDir(this.baseDir, currentTimeMillis);
        }
    }
}
