package cn.leancloud.core;

import cn.leancloud.AVFile;
import cn.leancloud.AVInstallation;
import cn.leancloud.AVLogger;
import cn.leancloud.AVObject;
import cn.leancloud.AVStatus;
import cn.leancloud.AVUser;
import cn.leancloud.ObjectTypeAdapter;
import cn.leancloud.ops.BaseOperation;
import cn.leancloud.ops.BaseOperationAdapter;
import cn.leancloud.types.AVDate;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.serializer.ObjectSerializer;
import com.alibaba.fastjson.serializer.SerializeConfig;
import io.reactivex.Observable;
import java.lang.reflect.Type;

public class AVOSCloud {
    private static String applicationId = "";
    private static String applicationKey = "";
    private static REGION defaultRegion = REGION.NorthChina;
    private static boolean enableCircularReferenceDetect = false;
    private static String hookKey = "";
    private static volatile AVLogger.Level logLevel = AVLogger.Level.INFO;
    static boolean printAllHeaders = false;

    public enum REGION {
        EastChina,
        NorthChina,
        NorthAmerica
    }

    static void setAlwaysFetchWhenSave(boolean z) {
    }

    public static void setRegion(REGION region) {
        defaultRegion = region;
    }

    public static REGION getRegion() {
        return defaultRegion;
    }

    public static void enablePrintAllHeaders4Debug(boolean z) {
        printAllHeaders = z;
        if (z) {
            System.out.println("======= WARNING: you are going to dump all details for a REST request, it is very risky for security!!! please ONLY USE IN absolutely trusted environment!!!");
            System.out.println("( •̀ᴗ•́ )و( •̀ᴗ•́ )و( •̀ᴗ•́ )و( •̀ᴗ•́ )و( •̀ᴗ•́ )و( •̀ᴗ•́ )و( •̀ᴗ•́ )و( •̀ᴗ•́ )و( •̀ᴗ•́ )و( •̀ᴗ•́ )و");
        }
    }

    public static void setLogLevel(AVLogger.Level level) {
        logLevel = level;
    }

    public static AVLogger.Level getLogLevel() {
        return logLevel;
    }

    public static boolean isDebugEnable() {
        return logLevel.intLevel() >= AVLogger.Level.DEBUG.intLevel();
    }

    public static void setCircularReferenceDetectEnable(boolean z) {
        enableCircularReferenceDetect = z;
    }

    public static boolean isEnableCircularReferenceDetect() {
        return enableCircularReferenceDetect;
    }

    public static void initialize(String str, String str2) {
        ObjectTypeAdapter objectTypeAdapter = new ObjectTypeAdapter();
        ParserConfig.getGlobalInstance().putDeserializer(AVObject.class, objectTypeAdapter);
        ParserConfig.getGlobalInstance().putDeserializer(AVUser.class, objectTypeAdapter);
        ParserConfig.getGlobalInstance().putDeserializer(AVFile.class, objectTypeAdapter);
        ParserConfig.getGlobalInstance().putDeserializer(AVStatus.class, objectTypeAdapter);
        ParserConfig.getGlobalInstance().putDeserializer(AVInstallation.class, objectTypeAdapter);
        SerializeConfig.getGlobalInstance().put((Type) AVObject.class, (ObjectSerializer) objectTypeAdapter);
        SerializeConfig.getGlobalInstance().put((Type) AVUser.class, (ObjectSerializer) objectTypeAdapter);
        SerializeConfig.getGlobalInstance().put((Type) AVFile.class, (ObjectSerializer) objectTypeAdapter);
        SerializeConfig.getGlobalInstance().put((Type) AVStatus.class, (ObjectSerializer) objectTypeAdapter);
        SerializeConfig.getGlobalInstance().put((Type) AVInstallation.class, (ObjectSerializer) objectTypeAdapter);
        BaseOperationAdapter baseOperationAdapter = new BaseOperationAdapter();
        ParserConfig.getGlobalInstance().putDeserializer(BaseOperation.class, baseOperationAdapter);
        SerializeConfig.getGlobalInstance().put((Type) BaseOperation.class, (ObjectSerializer) baseOperationAdapter);
        AVObject.registerSubclass(AVStatus.class);
        AVObject.registerSubclass(AVUser.class);
        AVObject.registerSubclass(AVFile.class);
        AVObject.registerSubclass(AVInstallation.class);
        applicationId = str;
        applicationKey = str2;
        PaasClient.initializeGlobalClient();
    }

    public static void initialize(String str, String str2, String str3) {
        setServerURLs(str3);
        initialize(str, str2);
    }

    public static Observable<AVDate> getServerDateInBackground() {
        return PaasClient.getStorageClient().getServerTime();
    }

    public static void setMasterKey(String str) {
        GeneralRequestSignature.setMasterKey(str);
    }

    public static void setServer(AVOSService aVOSService, String str) {
        if (!StringUtil.isEmpty(str)) {
            if (!str.toLowerCase().startsWith("http")) {
                str = "https://" + str;
            }
            AppRouter.getInstance().freezeEndpoint(aVOSService, str);
        }
    }

    protected static void setServerURLs(String str) {
        setServer(AVOSService.API, str);
        setServer(AVOSService.RTM, str);
        setServer(AVOSService.ENGINE, str);
        setServer(AVOSService.PUSH, str);
        setServer(AVOSService.STATS, str);
    }

    @Deprecated
    public static void setLastModifyEnabled(boolean z) {
        AppConfiguration.setLastModifyEnabled(z);
    }

    @Deprecated
    public static boolean isLastModifyEnabled() {
        return AppConfiguration.isLastModifyEnabled();
    }

    @Deprecated
    public static void setNetworkTimeout(int i) {
        AppConfiguration.setNetworkTimeout(i);
    }

    @Deprecated
    public static int getNetworkTimeout() {
        return AppConfiguration.getNetworkTimeout();
    }

    public static void setAutoMergeOperationDataWhenSave(boolean z) {
        AppConfiguration.setAutoMergeOperationDataWhenSave(z);
    }

    public static String getApplicationId() {
        return applicationId;
    }

    public static String getSimplifiedAppId() {
        if (StringUtil.isEmpty(applicationId)) {
            return "";
        }
        return applicationId.substring(0, 8);
    }

    public static String getApplicationKey() {
        return applicationKey;
    }

    public static String getHookKey() {
        return hookKey;
    }

    public static void setHookKey(String str) {
        hookKey = str;
    }
}
