package cn.leancloud.core;

import cn.leancloud.AVACL;
import cn.leancloud.cache.InMemorySetting;
import cn.leancloud.cache.LastModifyCache;
import cn.leancloud.cache.SystemSetting;
import cn.leancloud.logging.InternalLoggerAdapter;
import cn.leancloud.logging.SimpleLoggerAdapter;
import cn.leancloud.network.NetworkingDetector;
import cn.leancloud.network.SimpleNetworkingDetector;
import cn.leancloud.utils.FileUtil;
import io.reactivex.Scheduler;
import java.io.File;

public class AppConfiguration {
    public static final int DEFAULT_NETWORK_TIMEOUT = 30;
    private static final String DEFAULT_USER_AGENT = "LeanCloud-Java-SDK/6.5.14";
    private static final String SDK_VERSION = "6.5.14";
    private static String analyticsCacheDir = "./stats/";
    private static String applicationPackageName = "";
    private static boolean asynchronized = false;
    private static boolean autoMergeOperationDataWhenSave = true;
    private static String commandCacheDir = "./command/";
    private static AVACL defaultACL = null;
    private static SchedulerCreator defaultScheduler = null;
    private static SystemSetting defaultSetting = new InMemorySetting();
    private static String documentDir = "./data/";
    private static boolean enableLocalCache = true;
    private static String fileCacheDir = "./file/";
    private static NetworkingDetector globalNetworkingDetector = new SimpleNetworkingDetector();
    private static String importantFileDir = "./persistFiles/";
    private static InternalLoggerAdapter logAdapter = new SimpleLoggerAdapter();
    private static int networkTimeout = 30;
    private static String queryResultCacheDir = "./PaasKeyValueCache";

    public interface SchedulerCreator {
        Scheduler create();
    }

    public static String getUserAgent() {
        return DEFAULT_USER_AGENT;
    }

    public static void setNetworkTimeout(int i) {
        networkTimeout = i;
    }

    public static int getNetworkTimeout() {
        return networkTimeout;
    }

    public static void setLastModifyEnabled(boolean z) {
        LastModifyCache.getInstance().setLastModifyEnabled(z);
    }

    public static boolean isLastModifyEnabled() {
        return LastModifyCache.getInstance().isLastModifyEnabled();
    }

    public static AVACL getDefaultACL() {
        return defaultACL;
    }

    public static void setDefaultACL(AVACL avacl) {
        defaultACL = avacl;
    }

    public static void setLogAdapter(InternalLoggerAdapter internalLoggerAdapter) {
        logAdapter = internalLoggerAdapter;
    }

    public static InternalLoggerAdapter getLogAdapter() {
        return logAdapter;
    }

    public static void config(boolean z, SchedulerCreator schedulerCreator) {
        asynchronized = z;
        defaultScheduler = schedulerCreator;
    }

    public static boolean isEnableLocalCache() {
        return enableLocalCache;
    }

    public static void setEnableLocalCache(boolean z) {
        enableLocalCache = z;
    }

    public static boolean isAutoMergeOperationDataWhenSave() {
        return autoMergeOperationDataWhenSave;
    }

    public static void setAutoMergeOperationDataWhenSave(boolean z) {
        autoMergeOperationDataWhenSave = z;
    }

    public static boolean isAsynchronized() {
        return asynchronized;
    }

    public static SchedulerCreator getDefaultScheduler() {
        return defaultScheduler;
    }

    public static void makeSureCacheDirWorkable() {
        makeSureDirExist(importantFileDir);
        makeSureDirExist(documentDir);
        makeSureDirExist(fileCacheDir);
        makeSureDirExist(queryResultCacheDir);
        makeSureDirExist(commandCacheDir);
        makeSureDirExist(analyticsCacheDir);
    }

    private static void makeSureDirExist(String str) {
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
    }

    public static void configCacheSettings(String str, String str2, String str3, String str4, String str5, String str6, SystemSetting systemSetting) {
        importantFileDir = str;
        if (!str.endsWith("/")) {
            importantFileDir += "/";
        }
        documentDir = str2;
        if (!str2.endsWith("/")) {
            documentDir += "/";
        }
        fileCacheDir = str3;
        if (!str3.endsWith("/")) {
            fileCacheDir += "/";
        }
        queryResultCacheDir = str4;
        if (!str4.endsWith("/")) {
            queryResultCacheDir += "/";
        }
        commandCacheDir = str5;
        if (!str5.endsWith("/")) {
            commandCacheDir += "/";
        }
        analyticsCacheDir = str6;
        if (!str6.endsWith("/")) {
            analyticsCacheDir += "/";
        }
        makeSureCacheDirWorkable();
        defaultSetting = systemSetting;
    }

    public static String getAnalyticsCacheDir() {
        if (!enableLocalCache) {
            return null;
        }
        makeSureDirExist(analyticsCacheDir);
        return analyticsCacheDir;
    }

    public static String getCommandCacheDir() {
        if (!enableLocalCache) {
            return null;
        }
        makeSureDirExist(commandCacheDir);
        return commandCacheDir;
    }

    public static String getImportantFileDir() {
        if (!enableLocalCache) {
            return null;
        }
        makeSureDirExist(importantFileDir);
        return importantFileDir;
    }

    public static String getDocumentDir() {
        if (!enableLocalCache) {
            return null;
        }
        makeSureDirExist(documentDir);
        return documentDir;
    }

    public static String getFileCacheDir() {
        if (!enableLocalCache) {
            return null;
        }
        makeSureDirExist(fileCacheDir);
        return fileCacheDir;
    }

    public static String getQueryResultCacheDir() {
        if (!enableLocalCache) {
            return null;
        }
        makeSureDirExist(queryResultCacheDir);
        return queryResultCacheDir;
    }

    public static String getApplicationPackageName() {
        return applicationPackageName;
    }

    public static void setApplicationPackageName(String str) {
        applicationPackageName = str;
    }

    public static SystemSetting getDefaultSetting() {
        return defaultSetting;
    }

    public static NetworkingDetector getGlobalNetworkingDetector() {
        return globalNetworkingDetector;
    }

    public static void setGlobalNetworkingDetector(NetworkingDetector networkingDetector) {
        globalNetworkingDetector = networkingDetector;
    }

    public static void setMimeTypeDetector(FileUtil.MimeTypeDetector mimeTypeDetector) {
        if (mimeTypeDetector != null) {
            FileUtil.config(mimeTypeDetector);
        }
    }
}
