package cn.leancloud.core;

import cn.leancloud.AVLogger;
import cn.leancloud.cache.SystemSetting;
import cn.leancloud.core.AVOSCloud;
import cn.leancloud.core.AppConfiguration;
import cn.leancloud.network.DNSDetoxicant;
import cn.leancloud.service.AppAccessEndpoint;
import cn.leancloud.service.AppRouterService;
import cn.leancloud.service.RTMConnectionServerResponse;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSON;
import io.reactivex.Observable;
import io.reactivex.functions.Function;
import io.reactivex.schedulers.Schedulers;
import java.util.HashSet;
import java.util.Set;
import java.util.concurrent.TimeUnit;
import okhttp3.OkHttpClient;
import retrofit2.Retrofit;
import retrofit2.adapter.rxjava2.RxJava2CallAdapterFactory;
import retrofit2.converter.fastjson.FastJsonConverterFactory;

public class AppRouter {
    private static final String APP_ROUTER_HOST = "https://app-router.com";
    private static final String DEFAULT_REGION_EAST_CHINA = "lncldapi.com";
    private static final String DEFAULT_REGION_NORTH_AMERICA = "lncldglobal.com";
    private static final String DEFAULT_REGION_NORTH_CHINA = "lncld.net";
    private static final String DEFAULT_SERVER_API = AVOSService.API.toString();
    private static final String DEFAULT_SERVER_ENGINE = AVOSService.ENGINE.toString();
    private static final String DEFAULT_SERVER_HOST_FORMAT = "https://%s.%s.%s";
    private static final String DEFAULT_SERVER_PUSH = AVOSService.PUSH.toString();
    private static final String DEFAULT_SERVER_RTM_ROUTER = AVOSService.RTM.toString();
    private static final String DEFAULT_SERVER_STAT = AVOSService.STATS.toString();
    private static final AppRouter INSTANCE = new AppRouter();
    private static final AVLogger LOGGER = LogUtil.getLogger(AppRouter.class);
    private static final Set<String> NorthAmericaSpecialApps;
    private AppAccessEndpoint customizedEndpoint;
    private AppAccessEndpoint defaultEndpoint;
    private Retrofit retrofit;

    static {
        HashSet hashSet = new HashSet();
        NorthAmericaSpecialApps = hashSet;
        hashSet.add("143mgzglqmg4d0simqtn1zswggcro2ykugj76th8l38u3cm5");
        hashSet.add("18ry1wsn1p7808tagf2ka7sy1omna3nihe45cet0ne4xhg46");
        hashSet.add("7az5r9i0v95acx932a518ygz7mvr26uc7e3xxaq9s389sd2o");
        hashSet.add("8FfQwpvihLHK4htqmtEvkNrv");
        hashSet.add("AjQYwoIyObTeEkD16v1eCq55");
        hashSet.add("E0mVu1VMWrwBodUFWBpWzLNV");
        hashSet.add("J0Ev9alAhaS4IdnxBA95wKgn");
        hashSet.add("Ol0Cw6zL1xP9IIqJpiSv9uYC");
        hashSet.add("W9BCIPx2biwKiKfUvVJtc8kF");
        hashSet.add("YHE5exCaW7UolMFJUtHvXTUY");
        hashSet.add("glvame9g0qlj3a4o29j5xdzzrypxvvb30jt4vnvm66klph4r");
        hashSet.add("iuuztdrr4mj683kbsmwoalt1roaypb5d25eu0f23lrfsthgn");
        hashSet.add("kekxwm8uz1wtgxzvv5kitsgsammjcx4lcgm5b159qia5rqo5");
        hashSet.add("msjqtclsfmfeznwvm29dqvuwddt3cqmziszf0rjddxho8eis");
        hashSet.add("nHptjiXlt3g8mcraXYRDpYFT");
        hashSet.add("nf3udjhnnsbe99qg04j7oslck4w1yp2geewcy1kp6wskbu5w");
        hashSet.add("pFcwt2MaALYf70POa7bIqe0J");
        hashSet.add("q3er6vs0dkawy15skjeuktf7l4eam438wn5jkts2j7fpf2y3");
        hashSet.add("tsvezhhlefbdj1jbkohynipehgtpk353sfonvbtlyxaraqxy");
        hashSet.add("wnDg0lPt0wcYGJSiHRwHBhD4");
    }

    public static AppRouter getInstance() {
        return INSTANCE;
    }

    public static AVOSCloud.REGION getAppRegion(String str) {
        if (AVOSCloud.getRegion() != AVOSCloud.REGION.NorthChina) {
            return AVOSCloud.getRegion();
        }
        if (StringUtil.isEmpty(str)) {
            return AVOSCloud.REGION.NorthChina;
        }
        if (str.endsWith("-MdYXbMMI") || NorthAmericaSpecialApps.contains(str)) {
            return AVOSCloud.REGION.NorthAmerica;
        }
        if (str.endsWith("-9Nh9j0Va")) {
            return AVOSCloud.REGION.EastChina;
        }
        return AVOSCloud.REGION.NorthChina;
    }

    protected AppRouter() {
        this.retrofit = null;
        this.defaultEndpoint = null;
        this.customizedEndpoint = new AppAccessEndpoint();
        this.retrofit = new Retrofit.Builder().baseUrl(APP_ROUTER_HOST).addConverterFactory(FastJsonConverterFactory.create()).addCallAdapterFactory(RxJava2CallAdapterFactory.create()).client(new OkHttpClient.Builder().connectTimeout(15, TimeUnit.SECONDS).readTimeout(10, TimeUnit.SECONDS).writeTimeout(10, TimeUnit.SECONDS).addInterceptor(new LoggingInterceptor()).dns(new DNSDetoxicant()).build()).build();
    }

    /* access modifiers changed from: protected */
    public AppAccessEndpoint buildDefaultEndpoint(String str) {
        String str2;
        if (str == null || str.length() <= 8) {
            return null;
        }
        AppAccessEndpoint appAccessEndpoint = new AppAccessEndpoint();
        String lowerCase = str.substring(0, 8).toLowerCase();
        int i = AnonymousClass4.$SwitchMap$cn$leancloud$core$AVOSCloud$REGION[getAppRegion(str).ordinal()];
        if (i == 1) {
            str2 = DEFAULT_REGION_NORTH_CHINA;
        } else if (i == 2) {
            str2 = DEFAULT_REGION_EAST_CHINA;
        } else if (i != 3) {
            LOGGER.w("Invalid region");
            str2 = "";
        } else {
            str2 = DEFAULT_REGION_NORTH_AMERICA;
        }
        appAccessEndpoint.setApiServer(String.format(DEFAULT_SERVER_HOST_FORMAT, lowerCase, DEFAULT_SERVER_API, str2));
        appAccessEndpoint.setEngineServer(String.format(DEFAULT_SERVER_HOST_FORMAT, lowerCase, DEFAULT_SERVER_ENGINE, str2));
        appAccessEndpoint.setPushServer(String.format(DEFAULT_SERVER_HOST_FORMAT, lowerCase, DEFAULT_SERVER_PUSH, str2));
        appAccessEndpoint.setRtmRouterServer(String.format(DEFAULT_SERVER_HOST_FORMAT, lowerCase, DEFAULT_SERVER_RTM_ROUTER, str2));
        appAccessEndpoint.setStatServer(String.format(DEFAULT_SERVER_HOST_FORMAT, lowerCase, DEFAULT_SERVER_STAT, str2));
        appAccessEndpoint.setTtl((System.currentTimeMillis() / 1000) + 36000);
        return appAccessEndpoint;
    }

    private Observable<String> fetchServerFromRemote(String str, final AVOSService aVOSService) {
        return fetchServerHostsInBackground(str).map(new Function<AppAccessEndpoint, String>() {
            /* class cn.leancloud.core.AppRouter.AnonymousClass1 */

            public String apply(AppAccessEndpoint appAccessEndpoint) throws Exception {
                String str;
                int i = AnonymousClass4.$SwitchMap$cn$leancloud$core$AVOSService[aVOSService.ordinal()];
                if (i == 1) {
                    str = appAccessEndpoint.getApiServer();
                } else if (i == 2) {
                    str = appAccessEndpoint.getEngineServer();
                } else if (i == 3) {
                    str = appAccessEndpoint.getPushServer();
                } else if (i != 4) {
                    str = i != 5 ? "" : appAccessEndpoint.getStatServer();
                } else {
                    str = appAccessEndpoint.getRtmRouterServer();
                }
                if (StringUtil.isEmpty(str) || str.startsWith("http")) {
                    return str;
                }
                return "https://" + str;
            }
        });
    }

    /* access modifiers changed from: package-private */
    /* renamed from: cn.leancloud.core.AppRouter$4  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass4 {
        static final /* synthetic */ int[] $SwitchMap$cn$leancloud$core$AVOSCloud$REGION;
        static final /* synthetic */ int[] $SwitchMap$cn$leancloud$core$AVOSService;

        /* JADX WARNING: Can't wrap try/catch for region: R(17:0|(2:1|2)|3|(2:5|6)|7|9|10|11|12|13|14|15|17|18|19|20|(3:21|22|24)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(18:0|(2:1|2)|3|5|6|7|9|10|11|12|13|14|15|17|18|19|20|(3:21|22|24)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(21:0|1|2|3|5|6|7|9|10|11|12|13|14|15|17|18|19|20|21|22|24) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0028 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0033 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x004f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x0059 */
        static {
            int[] iArr = new int[AVOSService.values().length];
            $SwitchMap$cn$leancloud$core$AVOSService = iArr;
            try {
                iArr[AVOSService.API.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$cn$leancloud$core$AVOSService[AVOSService.ENGINE.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            $SwitchMap$cn$leancloud$core$AVOSService[AVOSService.PUSH.ordinal()] = 3;
            $SwitchMap$cn$leancloud$core$AVOSService[AVOSService.RTM.ordinal()] = 4;
            $SwitchMap$cn$leancloud$core$AVOSService[AVOSService.STATS.ordinal()] = 5;
            int[] iArr2 = new int[AVOSCloud.REGION.values().length];
            $SwitchMap$cn$leancloud$core$AVOSCloud$REGION = iArr2;
            iArr2[AVOSCloud.REGION.NorthChina.ordinal()] = 1;
            $SwitchMap$cn$leancloud$core$AVOSCloud$REGION[AVOSCloud.REGION.EastChina.ordinal()] = 2;
            try {
                $SwitchMap$cn$leancloud$core$AVOSCloud$REGION[AVOSCloud.REGION.NorthAmerica.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    public boolean hasFrozenEndpoint() {
        return this.customizedEndpoint.hasSpecifiedEndpoint();
    }

    public void freezeEndpoint(AVOSService aVOSService, String str) {
        this.customizedEndpoint.freezeEndpoint(aVOSService, str);
    }

    public Observable<String> getEndpoint(String str, AVOSService aVOSService) {
        return getEndpoint(str, aVOSService, false);
    }

    private Observable<String> getEndpoint(String str, AVOSService aVOSService, boolean z) {
        if (StringUtil.isEmpty(str)) {
            LOGGER.e("application id is empty.");
            return Observable.just("");
        } else if (str.length() <= 8) {
            LOGGER.e("application id is invalid(too short):" + str);
            return Observable.just("");
        } else {
            String serverHost = this.customizedEndpoint.getServerHost(aVOSService);
            if (!StringUtil.isEmpty(serverHost)) {
                return Observable.just(serverHost);
            }
            if (z) {
                return fetchServerFromRemote(str, aVOSService);
            }
            String str2 = null;
            if (this.defaultEndpoint == null) {
                SystemSetting defaultSetting = AppConfiguration.getDefaultSetting();
                String string = defaultSetting != null ? defaultSetting.getString(getPersistenceKeyZone(str, true), str, "") : null;
                if (!StringUtil.isEmpty(string)) {
                    this.defaultEndpoint = (AppAccessEndpoint) JSON.parseObject(string, AppAccessEndpoint.class);
                    if (System.currentTimeMillis() / 1000 > this.defaultEndpoint.getTtl()) {
                        this.defaultEndpoint = null;
                    }
                }
                if (this.defaultEndpoint == null) {
                    this.defaultEndpoint = buildDefaultEndpoint(str);
                }
            }
            int i = AnonymousClass4.$SwitchMap$cn$leancloud$core$AVOSService[aVOSService.ordinal()];
            if (i == 1) {
                str2 = this.defaultEndpoint.getApiServer();
            } else if (i == 2) {
                str2 = this.defaultEndpoint.getEngineServer();
            } else if (i == 3) {
                str2 = this.defaultEndpoint.getPushServer();
            } else if (i == 4) {
                str2 = this.defaultEndpoint.getRtmRouterServer();
            } else if (i == 5) {
                str2 = this.defaultEndpoint.getStatServer();
            }
            if (!StringUtil.isEmpty(str2) && !str2.startsWith("http")) {
                str2 = "https://" + str2;
            }
            return Observable.just(str2);
        }
    }

    public Observable<AppAccessEndpoint> fetchServerHostsInBackground(final String str) {
        Observable<AppAccessEndpoint> router = ((AppRouterService) this.retrofit.create(AppRouterService.class)).getRouter(str);
        if (AppConfiguration.isAsynchronized()) {
            router = router.subscribeOn(Schedulers.io());
        }
        AppConfiguration.SchedulerCreator defaultScheduler = AppConfiguration.getDefaultScheduler();
        if (defaultScheduler != null) {
            router = router.observeOn(defaultScheduler.create());
        }
        return router.map(new Function<AppAccessEndpoint, AppAccessEndpoint>() {
            /* class cn.leancloud.core.AppRouter.AnonymousClass2 */

            public AppAccessEndpoint apply(AppAccessEndpoint appAccessEndpoint) throws Exception {
                AppRouter.LOGGER.d(appAccessEndpoint.toString());
                AppRouter.this.defaultEndpoint = appAccessEndpoint;
                AppRouter.this.defaultEndpoint.setTtl(appAccessEndpoint.getTtl() + (System.currentTimeMillis() / 1000));
                SystemSetting defaultSetting = AppConfiguration.getDefaultSetting();
                if (defaultSetting != null) {
                    defaultSetting.saveString(AppRouter.this.getPersistenceKeyZone(str, true), str, JSON.toJSONString(AppRouter.this.defaultEndpoint));
                }
                return AppRouter.this.defaultEndpoint;
            }
        });
    }

    private Observable<RTMConnectionServerResponse> fetchRTMServerFromRemote(final String str, final String str2, String str3, int i) {
        AVLogger aVLogger = LOGGER;
        aVLogger.d("fetchRTMServerFromRemote. router=" + str + ", appId=" + str2 + ", installationId=" + str3);
        Observable<RTMConnectionServerResponse> rTMConnectionServer = ((AppRouterService) this.retrofit.newBuilder().baseUrl(str).build().create(AppRouterService.class)).getRTMConnectionServer(str2, str3, i);
        if (AppConfiguration.isAsynchronized()) {
            rTMConnectionServer = rTMConnectionServer.subscribeOn(Schedulers.io());
        }
        AppConfiguration.SchedulerCreator defaultScheduler = AppConfiguration.getDefaultScheduler();
        if (defaultScheduler != null) {
            rTMConnectionServer = rTMConnectionServer.observeOn(defaultScheduler.create());
        }
        return rTMConnectionServer.map(new Function<RTMConnectionServerResponse, RTMConnectionServerResponse>() {
            /* class cn.leancloud.core.AppRouter.AnonymousClass3 */

            public RTMConnectionServerResponse apply(RTMConnectionServerResponse rTMConnectionServerResponse) throws Exception {
                SystemSetting defaultSetting = AppConfiguration.getDefaultSetting();
                if (!(rTMConnectionServerResponse == null || defaultSetting == null)) {
                    rTMConnectionServerResponse.setTtl(rTMConnectionServerResponse.getTtl() + (System.currentTimeMillis() / 1000));
                    defaultSetting.saveString(AppRouter.this.getPersistenceKeyZone(str2, false), str, JSON.toJSONString(rTMConnectionServerResponse));
                }
                return rTMConnectionServerResponse;
            }
        });
    }

    public Observable<RTMConnectionServerResponse> fetchRTMConnectionServer(String str, String str2, String str3, int i, boolean z) {
        SystemSetting defaultSetting;
        if (!z && (defaultSetting = AppConfiguration.getDefaultSetting()) != null) {
            String string = defaultSetting.getString(getPersistenceKeyZone(str2, false), str, "");
            if (!StringUtil.isEmpty(string)) {
                try {
                    RTMConnectionServerResponse rTMConnectionServerResponse = (RTMConnectionServerResponse) JSON.parseObject(string, RTMConnectionServerResponse.class);
                    if (System.currentTimeMillis() / 1000 > rTMConnectionServerResponse.getTtl()) {
                        defaultSetting.removeKey(getPersistenceKeyZone(str2, false), str);
                        rTMConnectionServerResponse = null;
                    }
                    if (rTMConnectionServerResponse != null) {
                        return Observable.just(rTMConnectionServerResponse);
                    }
                } catch (Exception unused) {
                    defaultSetting.removeKey(getPersistenceKeyZone(str2, false), str);
                }
            }
        }
        return fetchRTMServerFromRemote(str, str2, str3, i);
    }

    /* access modifiers changed from: protected */
    public String getPersistenceKeyZone(String str, boolean z) {
        if (z) {
            return "com.avos.avoscloud.approuter." + str;
        }
        return "com.avos.push.router.server.cache" + str;
    }
}
