package cn.leancloud.core;

import cn.leancloud.network.DNSDetoxicant;
import cn.leancloud.service.APIService;
import cn.leancloud.service.PushService;
import io.reactivex.functions.Consumer;
import java.util.concurrent.TimeUnit;
import okhttp3.OkHttpClient;
import retrofit2.Retrofit;
import retrofit2.adapter.rxjava2.RxJava2CallAdapterFactory;
import retrofit2.converter.fastjson.FastJsonConverterFactory;

public class PaasClient {
    private static APIService apiService;
    private static OkHttpClient globalHttpClient;
    private static PushClient pushClient;
    private static PushService pushService;
    private static StorageClient storageClient;

    public static OkHttpClient getGlobalOkHttpClient() {
        if (globalHttpClient == null) {
            globalHttpClient = new OkHttpClient.Builder().connectTimeout(15, TimeUnit.SECONDS).readTimeout(10, TimeUnit.SECONDS).writeTimeout(10, TimeUnit.SECONDS).addInterceptor(new RequestPaddingInterceptor()).addInterceptor(new LoggingInterceptor()).dns(new DNSDetoxicant()).build();
        }
        return globalHttpClient;
    }

    static void initializeGlobalClient() {
        if (apiService == null) {
            AppRouter.getInstance().getEndpoint(AVOSCloud.getApplicationId(), AVOSService.API).subscribe(new Consumer<String>() {
                /* class cn.leancloud.core.PaasClient.AnonymousClass1 */

                public void accept(String str) throws Exception {
                    APIService unused = PaasClient.apiService = (APIService) new Retrofit.Builder().baseUrl(str).addConverterFactory(FastJsonConverterFactory.create()).addCallAdapterFactory(RxJava2CallAdapterFactory.create()).client(PaasClient.getGlobalOkHttpClient()).build().create(APIService.class);
                    StorageClient unused2 = PaasClient.storageClient = new StorageClient(PaasClient.apiService, AppConfiguration.isAsynchronized(), AppConfiguration.getDefaultScheduler());
                }
            });
        }
    }

    public static StorageClient getStorageClient() {
        if (apiService == null) {
            apiService = (APIService) new Retrofit.Builder().baseUrl(AppRouter.getInstance().getEndpoint(AVOSCloud.getApplicationId(), AVOSService.API).blockingFirst()).addConverterFactory(FastJsonConverterFactory.create()).addCallAdapterFactory(RxJava2CallAdapterFactory.create()).client(getGlobalOkHttpClient()).build().create(APIService.class);
            storageClient = new StorageClient(apiService, AppConfiguration.isAsynchronized(), AppConfiguration.getDefaultScheduler());
        }
        return storageClient;
    }

    public static PushClient getPushClient() {
        if (pushService == null) {
            PushService pushService2 = (PushService) new Retrofit.Builder().baseUrl(AppRouter.getInstance().getEndpoint(AVOSCloud.getApplicationId(), AVOSService.PUSH).blockingFirst()).addConverterFactory(FastJsonConverterFactory.create()).addCallAdapterFactory(RxJava2CallAdapterFactory.create()).client(getGlobalOkHttpClient()).build().create(PushService.class);
            pushService = pushService2;
            pushClient = new PushClient(pushService2, AppConfiguration.isAsynchronized(), AppConfiguration.getDefaultScheduler());
        }
        return pushClient;
    }
}
