package cn.leancloud.core;

import cn.leancloud.core.AppConfiguration;
import cn.leancloud.service.PushService;
import cn.leancloud.utils.ErrorUtils;
import com.alibaba.fastjson.JSONObject;
import io.reactivex.Observable;
import io.reactivex.ObservableSource;
import io.reactivex.functions.Function;
import io.reactivex.schedulers.Schedulers;
import java.util.Map;

public class PushClient {
    private boolean asynchronized = false;
    private AppConfiguration.SchedulerCreator defaultCreator = null;
    private PushService service = null;

    public PushClient(PushService pushService, boolean z, AppConfiguration.SchedulerCreator schedulerCreator) {
        this.service = pushService;
        this.asynchronized = AppConfiguration.isAsynchronized();
        this.defaultCreator = AppConfiguration.getDefaultScheduler();
        PaasClient.getGlobalOkHttpClient();
    }

    public Observable<JSONObject> sendPushRequest(Map<String, Object> map) {
        return wrapObservable(this.service.sendPushRequest(new JSONObject(map)));
    }

    private Observable wrapObservable(Observable observable) {
        if (observable == null) {
            return null;
        }
        if (this.asynchronized) {
            observable = observable.subscribeOn(Schedulers.io());
        }
        AppConfiguration.SchedulerCreator schedulerCreator = this.defaultCreator;
        if (schedulerCreator != null) {
            observable = observable.observeOn(schedulerCreator.create());
        }
        return observable.onErrorResumeNext(new Function<Throwable, ObservableSource>() {
            /* class cn.leancloud.core.PushClient.AnonymousClass1 */

            public ObservableSource apply(Throwable th) throws Exception {
                return Observable.error(ErrorUtils.propagateException(th));
            }
        });
    }
}
