package cn.leancloud.core;

import cn.leancloud.AVCloud;
import cn.leancloud.AVUser;
import cn.leancloud.utils.StringUtil;
import java.io.IOException;
import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.cache.DiskLruCache;

public class RequestPaddingInterceptor implements Interceptor {
    private static final String DEFAULT_CONTENT_TYPE = "application/json";
    private static final String HEADER_KEY_ACCEPT = "Accept";
    private static final String HEADER_KEY_CONTENT_TYPE = "Content-Type";
    public static final String HEADER_KEY_LC_APPID = "X-LC-Id";
    public static final String HEADER_KEY_LC_APPKEY = "X-LC-Key";
    public static final String HEADER_KEY_LC_HOOKKEY = "X-LC-Hook-Key";
    private static final String HEADER_KEY_LC_PROD_MODE = "X-LC-Prod";
    public static final String HEADER_KEY_LC_SESSIONTOKEN = "X-LC-Session";
    public static final String HEADER_KEY_LC_SIGN = "X-LC-Sign";
    private static final String HEADER_KEY_USER_AGENT = "User-Agent";
    private static RequestSignature requestSignature = new GeneralRequestSignature();

    public static void changeRequestSignature(RequestSignature requestSignature2) {
        requestSignature = requestSignature2;
    }

    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) throws IOException {
        Request request = chain.request();
        String str = "";
        String sessionToken = AVUser.getCurrentUser() == null ? str : AVUser.getCurrentUser().getSessionToken();
        Request.Builder header = request.newBuilder().header(HEADER_KEY_LC_PROD_MODE, AVCloud.isProductionMode() ? DiskLruCache.VERSION_1 : "0").header(HEADER_KEY_LC_APPID, AVOSCloud.getApplicationId()).header(HEADER_KEY_LC_SIGN, requestSignature.generateSign()).header(HEADER_KEY_ACCEPT, DEFAULT_CONTENT_TYPE).header("Content-Type", DEFAULT_CONTENT_TYPE).header(HEADER_KEY_USER_AGENT, AppConfiguration.getUserAgent());
        if (sessionToken != null) {
            str = sessionToken;
        }
        Request.Builder header2 = header.header(HEADER_KEY_LC_SESSIONTOKEN, str);
        if (!StringUtil.isEmpty(AVOSCloud.getHookKey())) {
            header2 = header2.header(HEADER_KEY_LC_HOOKKEY, AVOSCloud.getHookKey());
        }
        return chain.proceed(header2.build());
    }
}
