package cn.leancloud.network;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import androidx.core.app.ActivityCompat;
import cn.leancloud.AVLogger;
import cn.leancloud.network.NetworkingDetector;
import cn.leancloud.utils.LogUtil;

public class AndroidNetworkingDetector implements NetworkingDetector {
    private static AVLogger LOGGER = LogUtil.getLogger(AndroidNetworkingDetector.class);
    private Context context = null;

    public AndroidNetworkingDetector(Context context2) {
        this.context = context2;
    }

    @Override // cn.leancloud.network.NetworkingDetector
    public boolean isConnected() {
        try {
            if (ActivityCompat.checkSelfPermission(this.context, "android.permission.ACCESS_NETWORK_STATE") != 0) {
                LOGGER.w("android.Manifest.permission.ACCESS_NETWORK_STATE is not granted.");
                return false;
            }
            NetworkInfo activeNetworkInfo = ((ConnectivityManager) this.context.getSystemService("connectivity")).getActiveNetworkInfo();
            if (activeNetworkInfo == null || !activeNetworkInfo.isConnected()) {
                return false;
            }
            return true;
        } catch (Exception e) {
            LOGGER.w("failed to detect networking status.", e);
            return false;
        }
    }

    @Override // cn.leancloud.network.NetworkingDetector
    public NetworkingDetector.NetworkType getNetworkType() {
        NetworkingDetector.NetworkType networkType = NetworkingDetector.NetworkType.None;
        if (ActivityCompat.checkSelfPermission(this.context, "android.permission.ACCESS_NETWORK_STATE") != 0) {
            LOGGER.w("android.Manifest.permission.ACCESS_NETWORK_STATE is not granted.");
            return networkType;
        }
        NetworkInfo activeNetworkInfo = ((ConnectivityManager) this.context.getSystemService("connectivity")).getActiveNetworkInfo();
        if (activeNetworkInfo == null) {
            return networkType;
        }
        int type = activeNetworkInfo.getType();
        if (type == 0) {
            return NetworkingDetector.NetworkType.Mobile;
        }
        if (type != 1) {
            return networkType;
        }
        return NetworkingDetector.NetworkType.WIFI;
    }
}
