package cn.leancloud.ops;

import cn.leancloud.AVACL;
import cn.leancloud.AVFile;
import cn.leancloud.AVLogger;
import cn.leancloud.AVObject;
import cn.leancloud.codec.Base64;
import cn.leancloud.types.AVGeoPoint;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;

@JSONType(deserializer = BaseOperationAdapter.class, serializer = BaseOperationAdapter.class)
public abstract class BaseOperation implements ObjectFieldOperation {
    static final String KEY_AMOUNT = "amount";
    public static final String KEY_BODY = "body";
    public static final String KEY_HTTP_METHOD = "method";
    public static final String KEY_INTERNAL_ID = "__internalId";
    static final String KEY_OBJECTS = "objects";
    static final String KEY_OP = "__op";
    public static final String KEY_PATH = "path";
    static final String KEY_VALUE = "value";
    static final AVLogger LOGGER = LogUtil.getLogger(BaseOperation.class);
    protected String field = null;
    protected boolean isFinal = false;
    protected String op = null;
    protected Object value = null;

    @Override // cn.leancloud.ops.ObjectFieldOperation
    public abstract Object apply(Object obj);

    @Override // cn.leancloud.ops.ObjectFieldOperation
    public abstract Map<String, Object> encode();

    public BaseOperation(String str, String str2, Object obj, boolean z) {
        this.op = str;
        this.field = str2;
        this.value = obj;
        this.isFinal = z;
    }

    @Override // cn.leancloud.ops.ObjectFieldOperation
    public String getOperation() {
        return this.op;
    }

    @Override // cn.leancloud.ops.ObjectFieldOperation
    public String getField() {
        return this.field;
    }

    @Override // cn.leancloud.ops.ObjectFieldOperation
    public Object getValue() {
        return this.value;
    }

    public boolean isFinal() {
        return this.isFinal;
    }

    @Override // cn.leancloud.ops.ObjectFieldOperation
    public boolean checkCircleReference(Map<AVObject, Boolean> map) {
        if (map == null) {
            return false;
        }
        return checkValueCircleReference(map, this.value);
    }

    private static boolean checkValueCircleReference(Map<AVObject, Boolean> map, Object obj) {
        if (!(obj == null || map == null)) {
            if (obj instanceof AVObject) {
                AVObject aVObject = (AVObject) obj;
                if (map.containsKey(aVObject) && map.get(aVObject).booleanValue()) {
                    return true;
                }
                boolean hasCircleReference = aVObject.hasCircleReference(map);
                map.put(aVObject, Boolean.valueOf(hasCircleReference));
                return hasCircleReference;
            } else if (obj instanceof Collection) {
                for (Object obj2 : (Collection) obj) {
                    if (checkValueCircleReference(map, obj2)) {
                        return true;
                    }
                }
            }
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public ObjectFieldOperation mergeWithPrevious(ObjectFieldOperation objectFieldOperation) {
        return NullOperation.gInstance;
    }

    @Override // cn.leancloud.ops.ObjectFieldOperation
    public ObjectFieldOperation merge(ObjectFieldOperation objectFieldOperation) {
        if (objectFieldOperation == null || (objectFieldOperation instanceof NullOperation) || this.isFinal) {
            return this;
        }
        return mergeWithPrevious(objectFieldOperation);
    }

    /* access modifiers changed from: protected */
    public Object concatCollections(Object obj, Object obj2) {
        if (obj == null || obj2 == null) {
            return obj == null ? obj2 : obj;
        }
        ArrayList<Object> arrayList = new ArrayList();
        if (obj instanceof Collection) {
            arrayList.addAll((Collection) obj);
        } else {
            arrayList.add(obj);
        }
        if (obj2 instanceof Collection) {
            arrayList.addAll((Collection) obj2);
        } else {
            arrayList.add(obj2);
        }
        try {
            HashSet hashSet = new HashSet(arrayList.size());
            for (Object obj3 : arrayList) {
                hashSet.add(obj3);
            }
            return Arrays.asList(hashSet.toArray());
        } catch (Exception e) {
            LOGGER.w("failed to concat collections.", e);
            return arrayList;
        }
    }

    /* access modifiers changed from: protected */
    public void reportIllegalOperations(ObjectFieldOperation objectFieldOperation, ObjectFieldOperation objectFieldOperation2) {
        AVLogger aVLogger = LOGGER;
        aVLogger.w("illegal operations. current=" + objectFieldOperation.getClass().getSimpleName() + ", prev=" + objectFieldOperation2.getClass().getSimpleName());
    }

    public static Object encodeObject(Object obj) {
        return encodeObject(obj, false);
    }

    protected static Object encodeObject(Object obj, boolean z) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof Map) {
            return encodeMap((Map) obj, z);
        }
        if (obj instanceof Collection) {
            return encodeCollection((Collection) obj, z);
        }
        if (obj instanceof AVObject) {
            return encodeAVObject((AVObject) obj, z);
        }
        if (obj instanceof AVGeoPoint) {
            return encodeGeoPointer((AVGeoPoint) obj);
        }
        if (obj instanceof AVACL) {
            return ((AVACL) obj).toJSONObject();
        }
        if (obj instanceof AVFile) {
            return encodeAVFile((AVFile) obj);
        }
        if (obj instanceof Date) {
            return encodeDate((Date) obj);
        }
        if (obj instanceof byte[]) {
            return encodeByteArray((byte[]) obj);
        }
        if ((obj instanceof JSONObject) || (obj instanceof JSONArray)) {
        }
        return obj;
    }

    protected static Object encodeMap(Map<String, Object> map, boolean z) {
        HashMap hashMap = new HashMap(map.size());
        for (Map.Entry<String, Object> entry : map.entrySet()) {
            hashMap.put(entry.getKey(), encodeObject(entry.getValue(), z));
        }
        return hashMap;
    }

    protected static Object encodeCollection(Collection collection, boolean z) {
        ArrayList arrayList = new ArrayList(collection.size());
        for (Object obj : collection) {
            arrayList.add(encodeObject(obj, z));
        }
        return arrayList;
    }

    protected static Object encodeAVObject(AVObject aVObject, boolean z) {
        HashMap hashMap = new HashMap();
        hashMap.put(AVObject.KEY_CLASSNAME, aVObject.getClassName());
        if (!StringUtil.isEmpty(aVObject.getObjectId())) {
            hashMap.put(AVObject.KEY_OBJECT_ID, aVObject.getObjectId());
        }
        if (z) {
            hashMap.put("__type", "Object");
            Map map = (Map) encodeMap(aVObject.getServerData(), false);
            if (map != null && !map.isEmpty()) {
                hashMap.putAll(map);
            }
        } else {
            hashMap.put("__type", "Pointer");
        }
        return hashMap;
    }

    protected static Object encodeGeoPointer(AVGeoPoint aVGeoPoint) {
        HashMap hashMap = new HashMap();
        hashMap.put("__type", "GeoPoint");
        hashMap.put("latitude", Double.valueOf(aVGeoPoint.getLatitude()));
        hashMap.put("longitude", Double.valueOf(aVGeoPoint.getLongitude()));
        return hashMap;
    }

    protected static Object encodeAVFile(AVFile aVFile) {
        HashMap hashMap = new HashMap();
        hashMap.put("__type", AVFile.CLASS_NAME);
        hashMap.put("metaData", aVFile.getMetaData());
        hashMap.put("id", aVFile.getName());
        return hashMap;
    }

    protected static Object encodeByteArray(byte[] bArr) {
        HashMap hashMap = new HashMap();
        hashMap.put("__type", "Bytes");
        hashMap.put("base64", Base64.encodeToString(bArr, 2));
        return hashMap;
    }

    public static Map<String, Object> encodeDate(Date date) {
        HashMap hashMap = new HashMap();
        hashMap.put("__type", "Date");
        hashMap.put("iso", StringUtil.stringFromDate(date));
        return hashMap;
    }
}
