package cn.leancloud.ops;

import cn.leancloud.AVObject;
import cn.leancloud.ObjectValueFilter;
import cn.leancloud.core.AVOSCloud;
import cn.leancloud.ops.OperationBuilder;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.serializer.JSONSerializer;
import com.alibaba.fastjson.serializer.ObjectSerializer;
import com.alibaba.fastjson.serializer.SerializeWriter;
import com.alibaba.fastjson.serializer.SerializerFeature;
import java.io.IOException;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class BaseOperationAdapter implements ObjectSerializer, ObjectDeserializer {
    private static final String ATTR_FIELD = "field";
    private static final String ATTR_FINAL = "final";
    private static final String ATTR_OBJECT = "value";
    private static final String ATTR_OP = "operation";
    private static final String ATTR_SUBOPS = "subOps";

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 14;
    }

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public void write(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        BaseOperation baseOperation = (BaseOperation) obj;
        SerializeWriter writer = jSONSerializer.getWriter();
        writer.write(123);
        writer.writeFieldValue(' ', ATTR_OP, baseOperation.getOperation());
        writer.writeFieldValue(' ', ATTR_FIELD, baseOperation.getField());
        writer.writeFieldValue(',', ATTR_FINAL, baseOperation.isFinal);
        if (AVOSCloud.isEnableCircularReferenceDetect()) {
            writer.writeFieldValue(',', ATTR_OBJECT, JSON.toJSONString(baseOperation.getValue(), ObjectValueFilter.instance, SerializerFeature.WriteClassName));
        } else {
            writer.writeFieldValue(',', ATTR_OBJECT, JSON.toJSONString(baseOperation.getValue(), ObjectValueFilter.instance, SerializerFeature.WriteClassName, SerializerFeature.DisableCircularReferenceDetect));
        }
        if (obj instanceof CompoundOperation) {
            if (AVOSCloud.isEnableCircularReferenceDetect()) {
                writer.writeFieldValue(',', ATTR_SUBOPS, JSON.toJSONString(((CompoundOperation) baseOperation).getSubOperations(), ObjectValueFilter.instance, SerializerFeature.WriteClassName));
            } else {
                writer.writeFieldValue(',', ATTR_SUBOPS, JSON.toJSONString(((CompoundOperation) baseOperation).getSubOperations(), ObjectValueFilter.instance, SerializerFeature.WriteClassName, SerializerFeature.DisableCircularReferenceDetect));
            }
        }
        writer.write(125);
    }

    private Object getParsedObject(Object obj) {
        if (obj instanceof JSONObject) {
            JSONObject jSONObject = (JSONObject) obj;
            if (jSONObject.containsKey(AVObject.KEY_CLASSNAME)) {
                try {
                    return JSON.parseObject(JSON.toJSONString(jSONObject), AVObject.class);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
            return obj;
        } else if (!(obj instanceof Collection)) {
            return obj;
        } else {
            ArrayList arrayList = new ArrayList();
            for (Object obj2 : ((Collection) obj).toArray()) {
                arrayList.add(getParsedObject(obj2));
            }
            return arrayList;
        }
    }

    private <T> T parseJSONObject(JSONObject jSONObject) {
        Object obj = null;
        if (!jSONObject.containsKey(ATTR_OP) || !jSONObject.containsKey(ATTR_FIELD)) {
            return (T) new NullOperation("Null", null);
        }
        String string = jSONObject.getString(ATTR_OP);
        String string2 = jSONObject.getString(ATTR_FIELD);
        boolean booleanValue = jSONObject.containsKey(ATTR_FINAL) ? jSONObject.getBoolean(ATTR_FINAL).booleanValue() : false;
        OperationBuilder.OperationType valueOf = OperationBuilder.OperationType.valueOf(string);
        if (jSONObject.containsKey(ATTR_OBJECT)) {
            obj = jSONObject.get(ATTR_OBJECT);
        }
        T t = (T) OperationBuilder.gBuilder.create(valueOf, string2, getParsedObject(obj));
        t.isFinal = booleanValue;
        if (jSONObject.containsKey(ATTR_SUBOPS) && (t instanceof CompoundOperation)) {
            for (JSONObject jSONObject2 : (List) jSONObject.getObject(ATTR_SUBOPS, (Class) List.class)) {
                t.merge((BaseOperation) parseJSONObject(jSONObject2));
            }
        }
        return t;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj) {
        return (T) parseJSONObject(defaultJSONParser.parseObject());
    }
}
