package cn.leancloud.ops;

import cn.leancloud.AVObject;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class CompoundOperation extends BaseOperation {
    private List<ObjectFieldOperation> operations;

    public CompoundOperation(String str) {
        super("Compound", str, null, false);
        this.operations = new LinkedList();
    }

    public CompoundOperation(String str, ObjectFieldOperation... objectFieldOperationArr) {
        this(str);
        this.operations.addAll(Arrays.asList(objectFieldOperationArr));
    }

    public List<ObjectFieldOperation> getSubOperations() {
        return this.operations;
    }

    @Override // cn.leancloud.ops.BaseOperation, cn.leancloud.ops.ObjectFieldOperation
    public boolean checkCircleReference(Map<AVObject, Boolean> map) {
        Iterator<ObjectFieldOperation> it = this.operations.iterator();
        while (true) {
            boolean z = false;
            while (true) {
                if (!it.hasNext()) {
                    return z;
                }
                ObjectFieldOperation next = it.next();
                if (z || next.checkCircleReference(map)) {
                    z = true;
                }
            }
        }
    }

    @Override // cn.leancloud.ops.BaseOperation, cn.leancloud.ops.ObjectFieldOperation
    public Object apply(Object obj) {
        for (ObjectFieldOperation objectFieldOperation : this.operations) {
            obj = objectFieldOperation.apply(obj);
        }
        return obj;
    }

    /* access modifiers changed from: protected */
    @Override // cn.leancloud.ops.BaseOperation
    public ObjectFieldOperation mergeWithPrevious(ObjectFieldOperation objectFieldOperation) {
        this.operations.add(objectFieldOperation);
        return this;
    }

    public List<Map<String, Object>> encodeRestOp(AVObject aVObject) {
        ArrayList arrayList = new ArrayList();
        if (aVObject == null) {
            return arrayList;
        }
        String requestRawEndpoint = aVObject.getRequestRawEndpoint();
        String requestMethod = aVObject.getRequestMethod();
        for (int i = 1; i < this.operations.size(); i++) {
            Map<String, Object> makeCompletedRequest = Utils.makeCompletedRequest(aVObject.getObjectId(), requestRawEndpoint, requestMethod, this.operations.get(i).encode());
            if (makeCompletedRequest != null) {
                arrayList.add(makeCompletedRequest);
            }
        }
        return arrayList;
    }

    private Map<String, Object> encodeHeadOp() {
        if (this.operations.size() < 1) {
            return null;
        }
        return this.operations.get(0).encode();
    }

    @Override // cn.leancloud.ops.BaseOperation, cn.leancloud.ops.ObjectFieldOperation
    public Map<String, Object> encode() {
        return encodeHeadOp();
    }
}
