package cn.leancloud.ops;

import java.util.HashMap;
import java.util.Map;

public abstract class NumericOperation extends BaseOperation {
    public NumericOperation(String str, String str2, Object obj) {
        super(str, str2, obj, false);
        if (!(getValue() instanceof Number)) {
            throw new IllegalArgumentException("Value is not number!");
        }
    }

    @Override // cn.leancloud.ops.BaseOperation, cn.leancloud.ops.ObjectFieldOperation
    public Object apply(Object obj) {
        Number number;
        if (obj == null) {
            number = 0;
        } else if (obj instanceof Number) {
            number = (Number) obj;
        } else {
            LOGGER.w("cannot apply AddOperation on non number attribute. targetValueType=" + obj.getClass().getSimpleName());
            return obj;
        }
        if (this instanceof DecrementOperation) {
            return subNumbers(number, (Number) this.value);
        }
        if (this instanceof IncrementOperation) {
            return addNumbers(number, (Number) this.value);
        }
        if (this instanceof BitXorOperation) {
            return calculateLongs(number, (Number) this.value, 'X');
        }
        if (this instanceof BitAndOperation) {
            return calculateLongs(number, (Number) this.value, 'A');
        }
        if (this instanceof BitOrOperation) {
            return calculateLongs(number, (Number) this.value, 'O');
        }
        return 0;
    }

    @Override // cn.leancloud.ops.BaseOperation, cn.leancloud.ops.ObjectFieldOperation
    public Map<String, Object> encode() {
        HashMap hashMap = new HashMap();
        hashMap.put("__op", getOperation());
        if ((this instanceof IncrementOperation) || (this instanceof DecrementOperation)) {
            hashMap.put("amount", getValue());
        } else {
            hashMap.put("value", getValue());
        }
        HashMap hashMap2 = new HashMap();
        hashMap2.put(getField(), hashMap);
        return hashMap2;
    }

    /* access modifiers changed from: protected */
    @Override // cn.leancloud.ops.BaseOperation
    public ObjectFieldOperation mergeWithPrevious(ObjectFieldOperation objectFieldOperation) {
        if ((objectFieldOperation instanceof SetOperation) || (objectFieldOperation instanceof DeleteOperation)) {
            return objectFieldOperation;
        }
        if (objectFieldOperation instanceof NumericOperation) {
            return new CompoundOperation(this.field, objectFieldOperation, this);
        } else if (objectFieldOperation instanceof CompoundOperation) {
            return ((CompoundOperation) objectFieldOperation).mergeWithPrevious(this);
        } else {
            reportIllegalOperations(this, objectFieldOperation);
            return NullOperation.gInstance;
        }
    }

    protected static Long calculateLongs(Number number, Number number2, char c) {
        Long valueOf = Long.valueOf(number.longValue());
        Long valueOf2 = Long.valueOf(number2.longValue());
        if (c == 'A') {
            return Long.valueOf(valueOf2.longValue() & valueOf.longValue());
        } else if (c == 'O') {
            return Long.valueOf(valueOf2.longValue() | valueOf.longValue());
        } else if (c != 'X') {
            return 0L;
        } else {
            return Long.valueOf(valueOf2.longValue() ^ valueOf.longValue());
        }
    }

    protected static Number addNumbers(Number number, Number number2) {
        if ((number instanceof Double) || (number2 instanceof Double)) {
            return Double.valueOf(number.doubleValue() + number2.doubleValue());
        }
        if ((number instanceof Float) || (number2 instanceof Float)) {
            return Float.valueOf(number.floatValue() + number2.floatValue());
        }
        if ((number instanceof Long) || (number2 instanceof Long)) {
            return Long.valueOf(number.longValue() + number2.longValue());
        }
        return Integer.valueOf(number.intValue() + number2.intValue());
    }

    protected static Number subNumbers(Number number, Number number2) {
        if ((number instanceof Double) || (number2 instanceof Double)) {
            return Double.valueOf(number.doubleValue() - number2.doubleValue());
        }
        if ((number instanceof Float) || (number2 instanceof Float)) {
            return Float.valueOf(number.floatValue() - number2.floatValue());
        }
        if ((number instanceof Long) || (number2 instanceof Long)) {
            return Long.valueOf(number.longValue() - number2.longValue());
        }
        return Integer.valueOf(number.intValue() - number2.intValue());
    }
}
