package cn.leancloud.ops;

import cn.leancloud.AVFile;
import cn.leancloud.AVObject;
import cn.leancloud.AVRelation;
import cn.leancloud.ObjectTypeAdapter;
import cn.leancloud.Transformer;
import cn.leancloud.codec.Base64;
import cn.leancloud.types.AVGeoPoint;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSONObject;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class Utils {
    private static final String typeTag = "__type";

    public static Map<String, Object> createPointerArrayOpMap(String str, String str2, Collection<AVObject> collection) {
        HashMap hashMap = new HashMap();
        hashMap.put("__op", str2);
        ArrayList arrayList = new ArrayList();
        for (AVObject aVObject : collection) {
            arrayList.add(mapFromPointerObject(aVObject));
        }
        hashMap.put("objects", arrayList);
        HashMap hashMap2 = new HashMap();
        hashMap2.put(str, hashMap);
        return hashMap2;
    }

    public static Map<String, Object> mapFromPointerObject(AVObject aVObject) {
        return mapFromAVObject(aVObject, false);
    }

    public static Map<String, Object> mapFromGeoPoint(AVGeoPoint aVGeoPoint) {
        HashMap hashMap = new HashMap();
        hashMap.put(typeTag, "GeoPoint");
        hashMap.put("latitude", Double.valueOf(aVGeoPoint.getLatitude()));
        hashMap.put("longitude", Double.valueOf(aVGeoPoint.getLongitude()));
        return hashMap;
    }

    public static AVGeoPoint geoPointFromMap(Map<String, Object> map) {
        return new AVGeoPoint(((Number) map.get("latitude")).doubleValue(), ((Number) map.get("longitude")).doubleValue());
    }

    public static AVObject parseObjectFromMap(Map<String, Object> map) {
        AVObject objectFromClassName = Transformer.objectFromClassName((String) map.get(AVObject.KEY_CLASSNAME));
        map.remove(typeTag);
        objectFromClassName.resetServerData(map);
        return objectFromClassName;
    }

    public static byte[] dataFromMap(Map<String, Object> map) {
        return Base64.decode((String) map.get("base64"), 2);
    }

    public static Date dateFromMap(Map<String, Object> map) {
        return StringUtil.dateFromString((String) map.get("iso"));
    }

    public static Map<String, Object> mapFromDate(Date date) {
        HashMap hashMap = new HashMap();
        hashMap.put(typeTag, "Date");
        hashMap.put("iso", StringUtil.stringFromDate(date));
        return hashMap;
    }

    public static Map<String, Object> mapFromByteArray(byte[] bArr) {
        HashMap hashMap = new HashMap();
        hashMap.put(typeTag, "Bytes");
        hashMap.put("base64", Base64.encodeToString(bArr, 2));
        return hashMap;
    }

    public static Map<String, Object> mapFromFile(AVFile aVFile) {
        HashMap hashMap = new HashMap();
        hashMap.put(typeTag, AVFile.CLASS_NAME);
        hashMap.put("metaData", aVFile.getMetaData());
        hashMap.put("id", aVFile.getName());
        return hashMap;
    }

    public static Map<String, Object> mapFromAVObject(AVObject aVObject, boolean z) {
        HashMap hashMap = new HashMap();
        hashMap.put(AVObject.KEY_CLASSNAME, aVObject.internalClassName());
        if (!StringUtil.isEmpty(aVObject.getObjectId())) {
            hashMap.put(AVObject.KEY_OBJECT_ID, aVObject.getObjectId());
        }
        if (!z) {
            hashMap.put(typeTag, "Pointer");
        } else {
            hashMap.put(typeTag, "Object");
            Map<String, Object> parsedMap = getParsedMap(aVObject.getServerData(), false);
            if (parsedMap != null && !parsedMap.isEmpty()) {
                hashMap.putAll(parsedMap);
            }
        }
        return hashMap;
    }

    public static Map<String, Object> getParsedMap(Map<String, Object> map) {
        return getParsedMap(map, false);
    }

    public static Map<String, Object> getParsedMap(Map<String, Object> map, boolean z) {
        HashMap hashMap = new HashMap(map.size());
        for (Map.Entry<String, Object> entry : map.entrySet()) {
            hashMap.put(entry.getKey(), getParsedObject(entry.getValue(), z));
        }
        return hashMap;
    }

    public static List getParsedList(Collection collection) {
        ArrayList arrayList = new ArrayList(collection.size());
        for (Object obj : collection) {
            arrayList.add(getParsedObject(obj));
        }
        return arrayList;
    }

    public static List getParsedList(Collection collection, boolean z) {
        if (!z) {
            return getParsedList(collection);
        }
        ArrayList arrayList = new ArrayList(collection.size());
        for (Object obj : collection) {
            arrayList.add(getParsedObject(obj, true));
        }
        return arrayList;
    }

    public static Object getParsedObject(Object obj) {
        return getParsedObject(obj, false);
    }

    public static Object getParsedObject(Object obj, boolean z) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof Map) {
            return getParsedMap((Map) obj, z);
        }
        if (obj instanceof Collection) {
            return getParsedList((Collection) obj, z);
        }
        if (obj instanceof AVObject) {
            if (!z) {
                return mapFromPointerObject((AVObject) obj);
            }
            return mapFromAVObject((AVObject) obj, true);
        } else if (obj instanceof AVGeoPoint) {
            return mapFromGeoPoint((AVGeoPoint) obj);
        } else {
            if (obj instanceof Date) {
                return mapFromDate((Date) obj);
            }
            if (obj instanceof byte[]) {
                return mapFromByteArray((byte[]) obj);
            }
            return obj instanceof AVFile ? mapFromFile((AVFile) obj) : obj;
        }
    }

    public static Map<String, Object> createArrayOpMap(String str, String str2, Collection<?> collection) {
        HashMap hashMap = new HashMap();
        hashMap.put("__op", str2);
        ArrayList arrayList = new ArrayList();
        Iterator<?> it = collection.iterator();
        while (it.hasNext()) {
            arrayList.add(getParsedObject(it.next()));
        }
        hashMap.put("objects", arrayList);
        HashMap hashMap2 = new HashMap();
        hashMap2.put(str, hashMap);
        return hashMap2;
    }

    public static AVRelation objectFromRelationMap(Map<String, Object> map) {
        return new AVRelation((String) map.get(AVObject.KEY_CLASSNAME));
    }

    public static AVFile fileFromMap(Map<String, Object> map) {
        AVFile aVFile = new AVFile("", "");
        aVFile.resetServerData(map);
        Object obj = map.get("metaData");
        if (obj != null && (obj instanceof Map)) {
            aVFile.getMetaData().putAll((Map) obj);
        }
        return aVFile;
    }

    public static List getObjectFrom(Collection collection) {
        ArrayList arrayList = new ArrayList();
        for (Object obj : collection) {
            arrayList.add(getObjectFrom(obj));
        }
        return arrayList;
    }

    public static Object getObjectFrom(Map<String, Object> map) {
        Object obj = map.get(typeTag);
        if (obj != null && (obj instanceof String)) {
            map.remove(typeTag);
            if (obj.equals("Pointer") || obj.equals("Object")) {
                AVObject objectFromClassName = Transformer.objectFromClassName((String) map.get(AVObject.KEY_CLASSNAME));
                for (Map.Entry<String, Object> entry : map.entrySet()) {
                    String key = entry.getKey();
                    Object value = entry.getValue();
                    if ((value instanceof String) || (value instanceof Number) || (value instanceof Boolean) || (value instanceof Byte) || (value instanceof Character)) {
                        objectFromClassName.getServerData().put(key, value);
                    } else if ((value instanceof Map) || (value instanceof JSONObject)) {
                        objectFromClassName.getServerData().put(key, getObjectFrom(value));
                    } else if (value instanceof Collection) {
                        objectFromClassName.getServerData().put(key, getObjectFrom(value));
                    } else if (value != null) {
                        objectFromClassName.getServerData().put(key, value);
                    }
                }
                return objectFromClassName;
            } else if (obj.equals("GeoPoint")) {
                return geoPointFromMap(map);
            } else {
                if (obj.equals("Bytes")) {
                    return dataFromMap(map);
                }
                if (obj.equals("Date")) {
                    return dateFromMap(map);
                }
                if (obj.equals("Relation")) {
                    return objectFromRelationMap(map);
                }
                if (obj.equals("File")) {
                    return fileFromMap(map);
                }
                return map;
            }
        } else if (!map.containsKey(ObjectTypeAdapter.KEY_VERSION) || !map.containsKey(ObjectTypeAdapter.KEY_SERVERDATA)) {
            HashMap hashMap = new HashMap(map.size());
            for (Map.Entry<String, Object> entry2 : map.entrySet()) {
                hashMap.put(entry2.getKey(), getObjectFrom(entry2.getValue()));
            }
            return hashMap;
        } else {
            AVObject objectFromClassName2 = Transformer.objectFromClassName((String) map.get(AVObject.KEY_CLASSNAME));
            HashMap hashMap2 = new HashMap();
            for (Map.Entry entry3 : ((Map) map.get(ObjectTypeAdapter.KEY_SERVERDATA)).entrySet()) {
                String str = (String) entry3.getKey();
                Object value2 = entry3.getValue();
                if ((value2 instanceof String) || (value2 instanceof Number) || (value2 instanceof Boolean) || (value2 instanceof Byte) || (value2 instanceof Character)) {
                    hashMap2.put(str, value2);
                } else if ((value2 instanceof Map) || (value2 instanceof JSONObject)) {
                    hashMap2.put(str, getObjectFrom(value2));
                } else if (value2 instanceof Collection) {
                    hashMap2.put(str, getObjectFrom(value2));
                } else if (value2 != null) {
                    hashMap2.put(str, value2);
                }
            }
            objectFromClassName2.resetServerData(hashMap2);
            return objectFromClassName2;
        }
    }

    public static Object getObjectFrom(Object obj) {
        if (obj instanceof Collection) {
            return getObjectFrom((Collection) obj);
        }
        if ((obj instanceof Map) || (obj instanceof JSONObject)) {
            return getObjectFrom((Map<String, Object>) ((Map) obj));
        }
        return obj;
    }

    public static Map<String, Object> makeCompletedRequest(String str, String str2, String str3, Map<String, Object> map) {
        if (map == null || StringUtil.isEmpty(str2) || StringUtil.isEmpty(str3)) {
            return null;
        }
        map.put(BaseOperation.KEY_INTERNAL_ID, str);
        HashMap hashMap = new HashMap();
        hashMap.put(BaseOperation.KEY_BODY, map);
        hashMap.put(BaseOperation.KEY_PATH, str2);
        hashMap.put(BaseOperation.KEY_HTTP_METHOD, str3);
        return hashMap;
    }
}
