package cn.leancloud.query;

import cn.leancloud.AVObject;
import cn.leancloud.ops.Utils;
import cn.leancloud.types.AVGeoPoint;
import cn.leancloud.utils.AVUtils;
import cn.leancloud.utils.StringUtil;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class QueryConditions implements Cloneable {
    private List<String> include;
    private boolean includeACL;
    private int limit;
    private String order;
    private Map<String, String> parameters;
    private Set<String> selectedKeys;
    private int skip;
    private boolean trace;
    Map<String, List<QueryOperation>> where;

    public QueryConditions() {
        this.skip = -1;
        this.includeACL = false;
        this.where = new HashMap();
        this.include = new LinkedList();
        this.includeACL = false;
        this.parameters = new HashMap();
    }

    @Override // java.lang.Object
    public QueryConditions clone() {
        QueryConditions queryConditions = new QueryConditions();
        queryConditions.where.putAll(this.where);
        queryConditions.include.addAll(this.include);
        queryConditions.parameters.putAll(this.parameters);
        queryConditions.selectKeys(this.selectedKeys);
        queryConditions.setLimit(this.limit);
        queryConditions.setTrace(this.trace);
        queryConditions.setSkip(this.skip);
        queryConditions.setOrder(this.order);
        queryConditions.includeACL(this.includeACL);
        return queryConditions;
    }

    public int getLimit() {
        return this.limit;
    }

    public void setLimit(int i) {
        this.limit = i;
    }

    public int getSkip() {
        return this.skip;
    }

    public void setSkip(int i) {
        this.skip = i;
    }

    public String getOrder() {
        return this.order;
    }

    public void setOrder(String str) {
        this.order = str;
    }

    public List<String> getInclude() {
        return this.include;
    }

    public void setInclude(List<String> list) {
        this.include = list;
    }

    public Set<String> getSelectedKeys() {
        return this.selectedKeys;
    }

    public void setSelectedKeys(Set<String> set) {
        this.selectedKeys = set;
    }

    public Map<String, List<QueryOperation>> getWhere() {
        return this.where;
    }

    public void setWhere(Map<String, List<QueryOperation>> map) {
        this.where = map;
    }

    public Map<String, String> getParameters() {
        return new HashMap(this.parameters);
    }

    public void setParameters(Map<String, String> map) {
        this.parameters = map;
    }

    public boolean isTrace() {
        return this.trace;
    }

    public void setTrace(boolean z) {
        this.trace = z;
    }

    public void addAscendingOrder(String str) {
        if (StringUtil.isEmpty(this.order)) {
            orderByAscending(str);
            return;
        }
        this.order = String.format("%s,%s", this.order, str);
    }

    public void orderByAscending(String str) {
        this.order = String.format("%s", str);
    }

    public void addDescendingOrder(String str) {
        if (StringUtil.isEmpty(this.order)) {
            orderByDescending(str);
            return;
        }
        this.order = String.format("%s,-%s", this.order, str);
    }

    public void orderByDescending(String str) {
        this.order = String.format("-%s", str);
    }

    public void include(String str) {
        this.include.add(str);
    }

    public void selectKeys(Collection<String> collection) {
        if (this.selectedKeys == null) {
            this.selectedKeys = new HashSet();
        }
        if (collection != null) {
            this.selectedKeys.addAll(collection);
        }
    }

    public boolean isIncludeACL() {
        return this.includeACL;
    }

    public void includeACL(boolean z) {
        this.includeACL = z;
    }

    public Map<String, Object> compileWhereOperationMap() {
        HashMap hashMap = new HashMap();
        for (Map.Entry<String, List<QueryOperation>> entry : this.where.entrySet()) {
            List<QueryOperation> value = entry.getValue();
            String key = entry.getKey();
            if (key.equals(QueryOperation.OR_OP)) {
                ArrayList arrayList = new ArrayList();
                for (QueryOperation queryOperation : value) {
                    arrayList.add(queryOperation.toResult());
                }
                List list = (List) hashMap.get(QueryOperation.OR_OP);
                if (list != null) {
                    list.addAll(arrayList);
                } else {
                    hashMap.put(QueryOperation.OR_OP, arrayList);
                }
            } else if (key.equals(QueryOperation.AND_OP)) {
                ArrayList arrayList2 = new ArrayList();
                for (QueryOperation queryOperation2 : value) {
                    arrayList2.add(queryOperation2.getValue());
                }
                List list2 = (List) hashMap.get(QueryOperation.AND_OP);
                if (list2 != null) {
                    list2.addAll(arrayList2);
                } else {
                    hashMap.put(QueryOperation.AND_OP, arrayList2);
                }
            } else {
                int size = value.size();
                if (size != 0) {
                    if (size != 1) {
                        ArrayList arrayList3 = new ArrayList();
                        HashMap hashMap2 = new HashMap();
                        boolean z = false;
                        for (QueryOperation queryOperation3 : value) {
                            arrayList3.add(queryOperation3.toResult(key));
                            if (QueryOperation.EQUAL_OP.equals(queryOperation3.getOp())) {
                                z = true;
                            }
                            if (!z) {
                                hashMap2.putAll((Map) queryOperation3.toResult());
                            }
                        }
                        if (z) {
                            List list3 = (List) hashMap.get(QueryOperation.AND_OP);
                            if (list3 != null) {
                                list3.addAll(arrayList3);
                            } else {
                                hashMap.put(QueryOperation.AND_OP, arrayList3);
                            }
                        } else {
                            hashMap.put(key, hashMap2);
                        }
                    } else {
                        for (QueryOperation queryOperation4 : value) {
                            hashMap.put(key, queryOperation4.toResult());
                        }
                    }
                }
            }
        }
        return hashMap;
    }

    public Map<String, Object> assembleJsonParam() {
        HashMap hashMap = new HashMap();
        if (this.where.keySet().size() > 0) {
            hashMap.put("where", compileWhereOperationMap());
        }
        int i = this.limit;
        if (i > 0) {
            hashMap.put("limit", Integer.valueOf(i));
        }
        int i2 = this.skip;
        if (i2 >= 0) {
            hashMap.put("skip", Integer.valueOf(i2));
        }
        if (this.includeACL) {
            hashMap.put("returnACL", "true");
        }
        if (!StringUtil.isEmpty(this.order)) {
            hashMap.put("order", this.order);
        }
        List<String> list = this.include;
        if (list != null && list.size() > 0) {
            hashMap.put("include", StringUtil.join(",", this.include));
        }
        Set<String> set = this.selectedKeys;
        if (set != null && set.size() > 0) {
            hashMap.put("keys", StringUtil.join(",", this.selectedKeys));
        }
        return hashMap;
    }

    public Map<String, String> assembleParameters() {
        if (this.where.keySet().size() > 0) {
            this.parameters.put("where", AVUtils.jsonStringFromMapWithNull(Utils.getParsedMap(compileWhereOperationMap())));
        }
        int i = this.limit;
        if (i > 0) {
            this.parameters.put("limit", Integer.toString(i));
        }
        int i2 = this.skip;
        if (i2 >= 0) {
            this.parameters.put("skip", Integer.toString(i2));
        }
        if (this.includeACL) {
            this.parameters.put("returnACL", "true");
        }
        if (!StringUtil.isEmpty(this.order)) {
            this.parameters.put("order", this.order);
        }
        List<String> list = this.include;
        if (list != null && list.size() > 0) {
            this.parameters.put("include", StringUtil.join(",", this.include));
        }
        Set<String> set = this.selectedKeys;
        if (set != null && set.size() > 0) {
            this.parameters.put("keys", StringUtil.join(",", this.selectedKeys));
        }
        return this.parameters;
    }

    public void addWhereItem(QueryOperation queryOperation) {
        List<QueryOperation> list = this.where.get(queryOperation.getKey());
        if (list == null) {
            list = new LinkedList<>();
            this.where.put(queryOperation.getKey(), list);
        }
        removeDuplications(queryOperation, list);
        list.add(queryOperation);
    }

    public void addWhereItem(String str, String str2, Object obj) {
        addWhereItem(new QueryOperation(str, str2, obj));
    }

    private void removeDuplications(QueryOperation queryOperation, List<QueryOperation> list) {
        Iterator<QueryOperation> it = list.iterator();
        while (it.hasNext()) {
            if (it.next().sameOp(queryOperation)) {
                it.remove();
            }
        }
    }

    public void addOrItems(QueryOperation queryOperation) {
        List<QueryOperation> list = this.where.get(QueryOperation.OR_OP);
        if (list == null) {
            list = new LinkedList<>();
            this.where.put(QueryOperation.OR_OP, list);
        }
        Iterator<QueryOperation> it = list.iterator();
        while (it.hasNext()) {
            if (it.next().equals(queryOperation)) {
                it.remove();
            }
        }
        list.add(queryOperation);
    }

    public void addAndItems(QueryConditions queryConditions) {
        QueryOperation queryOperation = new QueryOperation(QueryOperation.AND_OP, QueryOperation.AND_OP, queryConditions.compileWhereOperationMap());
        List<QueryOperation> list = this.where.get(QueryOperation.AND_OP);
        if (list == null) {
            list = new LinkedList<>();
            this.where.put(QueryOperation.AND_OP, list);
        }
        Iterator<QueryOperation> it = list.iterator();
        while (it.hasNext()) {
            if (it.next().equals(queryOperation)) {
                it.remove();
            }
        }
        list.add(queryOperation);
    }

    public void whereWithinRadians(String str, AVGeoPoint aVGeoPoint, double d) {
        whereWithinRadians(str, aVGeoPoint, d, -1.0d);
    }

    public void whereWithinRadians(String str, AVGeoPoint aVGeoPoint, double d, double d2) {
        Map<String, Object> createMap = AVUtils.createMap("$nearSphere", Utils.mapFromGeoPoint(aVGeoPoint));
        if (d >= 0.0d) {
            createMap.put("$maxDistanceInRadians", Double.valueOf(d));
        }
        if (d2 >= 0.0d) {
            createMap.put("$minDistanceInRadians", Double.valueOf(d2));
        }
        addWhereItem(new QueryOperation(str, null, createMap));
    }

    public void whereGreaterThanOrEqualTo(String str, Object obj) {
        addWhereItem(new QueryOperation(str, "$gte", obj));
    }

    public void whereContainedIn(String str, Collection<? extends Object> collection) {
        addWhereItem(str, "$in", collection);
    }

    public void whereExists(String str) {
        addWhereItem(str, "$exists", true);
    }

    public void whereGreaterThan(String str, Object obj) {
        addWhereItem(str, "$gt", obj);
    }

    public void whereLessThan(String str, Object obj) {
        addWhereItem(str, "$lt", obj);
    }

    public void whereLessThanOrEqualTo(String str, Object obj) {
        addWhereItem(str, "$lte", obj);
    }

    public void whereMatches(String str, String str2) {
        addWhereItem(str, "$regex", str2);
    }

    public void whereMatches(String str, String str2, String str3) {
        addWhereItem(str, "$regex", str2);
        addWhereItem(str, "$options", str3);
    }

    public void whereNear(String str, AVGeoPoint aVGeoPoint) {
        addWhereItem(str, "$nearSphere", Utils.mapFromGeoPoint(aVGeoPoint));
    }

    public void whereNotContainedIn(String str, Collection<? extends Object> collection) {
        addWhereItem(str, "$nin", collection);
    }

    public void whereNotEqualTo(String str, Object obj) {
        addWhereItem(str, "$ne", obj);
    }

    public void whereEqualTo(String str, Object obj) {
        if (obj instanceof AVObject) {
            addWhereItem(str, QueryOperation.EQUAL_OP, Utils.mapFromPointerObject((AVObject) obj));
        } else {
            addWhereItem(str, QueryOperation.EQUAL_OP, obj);
        }
    }

    public void whereStartsWith(String str, String str2) {
        whereMatches(str, String.format("^%s.*", str2));
    }

    public void whereWithinGeoBox(String str, AVGeoPoint aVGeoPoint, AVGeoPoint aVGeoPoint2) {
        LinkedList linkedList = new LinkedList();
        linkedList.add(Utils.mapFromGeoPoint(aVGeoPoint));
        linkedList.add(Utils.mapFromGeoPoint(aVGeoPoint2));
        addWhereItem(str, "$within", AVUtils.createMap("$box", linkedList));
    }

    public void whereWithinKilometers(String str, AVGeoPoint aVGeoPoint, double d) {
        whereWithinKilometers(str, aVGeoPoint, d, -1.0d);
    }

    public void whereWithinKilometers(String str, AVGeoPoint aVGeoPoint, double d, double d2) {
        Map<String, Object> createMap = AVUtils.createMap("$nearSphere", Utils.mapFromGeoPoint(aVGeoPoint));
        if (d >= 0.0d) {
            createMap.put("$maxDistanceInKilometers", Double.valueOf(d));
        }
        if (d2 >= 0.0d) {
            createMap.put("$minDistanceInKilometers", Double.valueOf(d2));
        }
        addWhereItem(str, null, createMap);
    }

    public void whereWithinMiles(String str, AVGeoPoint aVGeoPoint, double d) {
        whereWithinMiles(str, aVGeoPoint, d, -1.0d);
    }

    public void whereWithinMiles(String str, AVGeoPoint aVGeoPoint, double d, double d2) {
        Map<String, Object> createMap = AVUtils.createMap("$nearSphere", Utils.mapFromGeoPoint(aVGeoPoint));
        if (d >= 0.0d) {
            createMap.put("$maxDistanceInMiles", Double.valueOf(d));
        }
        if (d2 >= 0.0d) {
            createMap.put("$minDistanceInMiles", Double.valueOf(d2));
        }
        addWhereItem(str, null, createMap);
    }

    public void whereEndsWith(String str, String str2) {
        whereMatches(str, String.format(".*%s$", str2));
    }

    public void whereContains(String str, String str2) {
        whereMatches(str, String.format(".*%s.*", str2));
    }

    public void whereSizeEqual(String str, int i) {
        addWhereItem(str, "$size", Integer.valueOf(i));
    }

    public void whereContainsAll(String str, Collection<?> collection) {
        addWhereItem(str, "$all", collection);
    }

    public void whereDoesNotExist(String str) {
        addWhereItem(str, "$exists", false);
    }
}
