package cn.leancloud.search;

import cn.leancloud.types.AVGeoPoint;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

public class AVSearchSortBuilder {
    private final List<Object> sortFields = new ArrayList();

    public static AVSearchSortBuilder newBuilder() {
        return new AVSearchSortBuilder();
    }

    public AVSearchSortBuilder orderByAscending(String str, String str2, String str3) {
        return addField(str, "asc", str2, str3);
    }

    public AVSearchSortBuilder orderByAscending(String str, String str2) {
        return orderByAscending(str, str2, "last");
    }

    public AVSearchSortBuilder orderByAscending(String str) {
        return orderByAscending(str, "avg");
    }

    public AVSearchSortBuilder orderByDescending(String str, String str2, String str3) {
        return addField(str, "desc", str2, str3);
    }

    public AVSearchSortBuilder orderByDescending(String str, String str2) {
        return orderByDescending(str, str2, "last");
    }

    public AVSearchSortBuilder orderByDescending(String str) {
        return orderByDescending(str, "avg");
    }

    private AVSearchSortBuilder addField(String str, String str2, String str3, String str4) {
        HashMap hashMap = new HashMap();
        HashMap hashMap2 = new HashMap();
        hashMap2.put("order", str2);
        hashMap2.put("mode", str3);
        hashMap2.put("missing", "_" + str4);
        hashMap.put(str, hashMap2);
        this.sortFields.add(hashMap);
        return this;
    }

    public AVSearchSortBuilder whereNear(String str, AVGeoPoint aVGeoPoint) {
        return whereNear(str, aVGeoPoint, "asc");
    }

    public AVSearchSortBuilder whereNear(String str, AVGeoPoint aVGeoPoint, String str2) {
        return whereNear(str, aVGeoPoint, str2, "avg", "km");
    }

    public AVSearchSortBuilder whereNear(String str, AVGeoPoint aVGeoPoint, String str2, String str3, String str4) {
        HashMap hashMap = new HashMap();
        HashMap hashMap2 = new HashMap();
        HashMap hashMap3 = new HashMap();
        hashMap3.put("lat", Double.valueOf(aVGeoPoint.getLatitude()));
        hashMap3.put("lon", Double.valueOf(aVGeoPoint.getLongitude()));
        hashMap2.put(str, hashMap3);
        hashMap2.put("unit", str4);
        hashMap2.put("mode", str3);
        hashMap2.put("order", str2);
        hashMap.put("_geo_distance", hashMap2);
        this.sortFields.add(hashMap);
        return this;
    }

    public List<Object> getSortFields() {
        return this.sortFields;
    }
}
