package cn.leancloud.upload;

import cn.leancloud.AVException;
import cn.leancloud.AVFile;
import cn.leancloud.AVLogger;
import cn.leancloud.callback.ProgressCallback;
import cn.leancloud.core.PaasClient;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSONObject;
import java.util.HashMap;
import java.util.Map;

public class FileUploader extends HttpClientUploader {
    static HashMap<String, String> UPLOAD_HEADERS = new HashMap<>();
    static final int gProgressComplete = 100;
    static final int gProgressGotToken = 10;
    static final int gProgressUploadedFile = 90;
    static final String gProviderQCloud = "qcloud";
    static final String gProviderS3 = "s3";
    private static AVLogger logger = LogUtil.getLogger(FileUploader.class);
    private String bucket;
    private String provider;
    private String token;
    private String uploadUrl;

    public interface FileUploadProgressCallback {
        void onProgress(int i);
    }

    public FileUploader(AVFile aVFile, FileUploadToken fileUploadToken, ProgressCallback progressCallback) {
        super(aVFile, progressCallback);
        this.token = fileUploadToken.getToken();
        this.bucket = fileUploadToken.getBucket();
        this.uploadUrl = fileUploadToken.getUploadUrl();
        this.provider = fileUploadToken.getProvider();
    }

    @Override // cn.leancloud.upload.Uploader
    public AVException execute() {
        publishProgress(10);
        Uploader uploaderImplementation = getUploaderImplementation();
        if (uploaderImplementation == null) {
            return new AVException(new Throwable("Uploader can not be instantiated."));
        }
        AVException execute = uploaderImplementation.execute();
        if (execute == null) {
            publishProgress(100);
            completeFileUpload(true);
            return null;
        }
        completeFileUpload(false);
        return execute;
    }

    private Uploader getUploaderImplementation() {
        if (StringUtil.isEmpty(this.provider)) {
            logger.w("provider doesnot exist, cannot upload any file.");
            return null;
        } else if (gProviderQCloud.equalsIgnoreCase(this.provider)) {
            return new QCloudUploader(this.avFile, this.token, this.uploadUrl, this.progressCallback);
        } else {
            if (gProviderS3.equalsIgnoreCase(this.provider)) {
                return new S3Uploader(this.avFile, this.uploadUrl, this.progressCallback);
            }
            return new QiniuSlicingUploader(this.avFile, this.token, this.uploadUrl, this.progressCallback);
        }
    }

    private void completeFileUpload(boolean z) {
        if (!StringUtil.isEmpty(this.token)) {
            try {
                JSONObject jSONObject = new JSONObject();
                jSONObject.put("result", (Object) Boolean.valueOf(z));
                jSONObject.put("token", (Object) this.token);
                PaasClient.getStorageClient().fileCallback(jSONObject);
            } catch (Exception unused) {
            }
        }
    }

    protected static class ProgressCalculator {
        Map<Integer, Integer> blockProgress = new HashMap();
        FileUploadProgressCallback callback;
        int fileBlockCount = 0;

        public ProgressCalculator(int i, FileUploadProgressCallback fileUploadProgressCallback) {
            this.callback = fileUploadProgressCallback;
            this.fileBlockCount = i;
        }

        public synchronized void publishProgress(int i, int i2) {
            this.blockProgress.put(Integer.valueOf(i), Integer.valueOf(i2));
            if (this.callback != null) {
                int i3 = 0;
                for (Map.Entry<Integer, Integer> entry : this.blockProgress.entrySet()) {
                    i3 += entry.getValue().intValue();
                }
                this.callback.onProgress(((i3 * 80) / (this.fileBlockCount * 100)) + 10);
            }
        }
    }

    public static void setUploadHeader(String str, String str2) {
        UPLOAD_HEADERS.put(str, str2);
    }
}
