package cn.leancloud.upload;

import cn.leancloud.AVException;
import cn.leancloud.AVFile;
import cn.leancloud.AVLogger;
import cn.leancloud.callback.ProgressCallback;
import cn.leancloud.network.DNSDetoxicant;
import cn.leancloud.utils.LogUtil;
import java.io.IOException;
import java.util.concurrent.TimeUnit;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public abstract class HttpClientUploader implements Uploader {
    protected static final int DEFAULT_RETRY_TIMES = 6;
    private static AVLogger logger = LogUtil.getLogger(HttpClientUploader.class);
    protected AVFile avFile = null;
    private volatile boolean cancelled = false;
    private OkHttpClient client = new OkHttpClient.Builder().connectTimeout(15, TimeUnit.SECONDS).readTimeout(10, TimeUnit.SECONDS).writeTimeout(10, TimeUnit.SECONDS).dns(new DNSDetoxicant()).build();
    ProgressCallback progressCallback;

    public void interruptImmediately() {
    }

    /* access modifiers changed from: protected */
    public synchronized OkHttpClient getOKHttpClient() {
        return this.client;
    }

    public HttpClientUploader(AVFile aVFile, ProgressCallback progressCallback2) {
        this.avFile = aVFile;
        this.progressCallback = progressCallback2;
        this.cancelled = false;
    }

    /* access modifiers changed from: protected */
    public Response executeWithRetry(Request request, int i) throws AVException {
        if (i <= 0 || isCancelled()) {
            throw new AVException(-1, "Upload File failure");
        }
        try {
            Response execute = getOKHttpClient().newCall(request).execute();
            if (execute.code() / 100 == 2) {
                return execute;
            }
            return executeWithRetry(request, i - 1);
        } catch (IOException unused) {
            return executeWithRetry(request, i - 1);
        }
    }

    @Override // cn.leancloud.upload.Uploader
    public void publishProgress(int i) {
        ProgressCallback progressCallback2 = this.progressCallback;
        if (progressCallback2 != null) {
            progressCallback2.internalDone(Integer.valueOf(i), null);
        }
    }

    @Override // cn.leancloud.upload.Uploader
    public boolean cancel(boolean z) {
        if (this.cancelled) {
            return false;
        }
        this.cancelled = true;
        if (z) {
            interruptImmediately();
        }
        return true;
    }

    @Override // cn.leancloud.upload.Uploader
    public boolean isCancelled() {
        return this.cancelled;
    }
}
