package cn.leancloud.upload;

import cn.leancloud.AVException;
import cn.leancloud.AVFile;
import cn.leancloud.callback.ProgressCallback;
import cn.leancloud.utils.FileUtil;
import com.android.volley.toolbox.HttpHeaderParser;
import java.io.IOException;
import java.util.Map;
import java.util.concurrent.TimeUnit;
import okhttp3.Call;
import okhttp3.MediaType;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;

/* access modifiers changed from: package-private */
public class S3Uploader extends HttpClientUploader {
    private static String DEFAULT_HEADER_CACHE_CONTROL = "Cache-Control";
    private static String DEFAULT_HEADER_CACHE_CONTROL_VALUE = "public, max-age=31536000";
    private static final int DEFAULT_MAX_WRITE_TIMEOUT = 240;
    private static final int DEFAULT_MIN_UPLOAD_RATE = 51200;
    private static final int DEFAULT_MIN_WRITE_TIMEOUT = 30;
    private static int writeTimeout;
    private volatile Call call;
    private int retryTimes = 6;
    private String uploadUrl;

    S3Uploader(AVFile aVFile, String str, ProgressCallback progressCallback) {
        super(aVFile, progressCallback);
        this.uploadUrl = str;
    }

    @Override // cn.leancloud.upload.Uploader
    public AVException execute() {
        try {
            return executeWithRetry(this.avFile.getData());
        } catch (Exception e) {
            return new AVException(e.getCause());
        }
    }

    private AVException executeWithRetry(byte[] bArr) {
        if (bArr == null || bArr.length <= 0) {
            return null;
        }
        OkHttpClient.Builder newBuilder = getOKHttpClient().newBuilder();
        int i = writeTimeout;
        if (i <= 0) {
            i = getWriteTimeoutByLength(bArr.length);
        }
        newBuilder.writeTimeout((long) i, TimeUnit.SECONDS);
        OkHttpClient build = newBuilder.build();
        try {
            String fileMimeType = FileUtil.getFileMimeType(this.avFile);
            Request.Builder builder = new Request.Builder();
            builder.url(this.uploadUrl);
            builder.put(RequestBody.create(MediaType.parse(fileMimeType), bArr));
            builder.addHeader(HttpHeaderParser.HEADER_CONTENT_TYPE, fileMimeType);
            if (!FileUploader.UPLOAD_HEADERS.containsKey(DEFAULT_HEADER_CACHE_CONTROL)) {
                builder.addHeader(DEFAULT_HEADER_CACHE_CONTROL, DEFAULT_HEADER_CACHE_CONTROL_VALUE);
            }
            for (Map.Entry<String, String> entry : FileUploader.UPLOAD_HEADERS.entrySet()) {
                builder.addHeader(entry.getKey(), entry.getValue());
            }
            this.call = build.newCall(builder.build());
            Response execute = this.call.execute();
            if (2 == execute.code() / 100) {
                return null;
            }
            int i2 = this.retryTimes;
            if (i2 > 0) {
                this.retryTimes = i2 - 1;
                executeWithRetry(bArr);
                return null;
            }
            return new AVException(-1, "upload file failure:" + execute.code());
        } catch (IOException e) {
            int i3 = this.retryTimes;
            if (i3 <= 0) {
                return new AVException(e.getCause());
            }
            this.retryTimes = i3 - 1;
            return executeWithRetry(bArr);
        }
    }

    private int getWriteTimeoutByLength(int i) {
        int i2 = i / DEFAULT_MIN_UPLOAD_RATE;
        if (i2 < 30) {
            return 30;
        }
        return i2 > DEFAULT_MAX_WRITE_TIMEOUT ? DEFAULT_MAX_WRITE_TIMEOUT : i2;
    }

    public static void setWriteTimeout(int i) throws AVException {
        if (i <= 0) {
            throw new AVException(new IllegalArgumentException("Timeout too small"));
        } else if (i <= 3600) {
            writeTimeout = i;
        } else {
            throw new AVException(new IllegalArgumentException("Timeout too large"));
        }
    }
}
