package cn.leancloud.utils;

import cn.leancloud.core.AVOSCloud;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.serializer.SerializerFeature;
import java.math.BigDecimal;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.ConcurrentMap;

public class AVUtils {
    public static final double earthMeanRadiusInKM = 6378.14d;

    public static double distance(double d, double d2, double d3, double d4, double d5, double d6) {
        double radians = Math.toRadians(d2 - d);
        double d7 = radians / 2.0d;
        double radians2 = Math.toRadians(d4 - d3) / 2.0d;
        double sin = (Math.sin(d7) * Math.sin(d7)) + (Math.cos(Math.toRadians(d)) * Math.cos(Math.toRadians(d2)) * Math.sin(radians2) * Math.sin(radians2));
        return Math.sqrt(Math.pow(Math.atan2(Math.sqrt(sin), Math.sqrt(1.0d - sin)) * 2.0d * 6378.14d * 1000.0d, 2.0d) + Math.pow(d5 - d6, 2.0d));
    }

    public static String getJSONString(Map<String, Object> map) {
        return JSON.toJSONString(map);
    }

    public static Map<String, Object> createMap(String str, Object obj) {
        HashMap hashMap = new HashMap();
        hashMap.put(str, obj);
        return hashMap;
    }

    public static Map<String, Object> createStringObjectMap(String str, Object obj) {
        HashMap hashMap = new HashMap();
        if (obj != null) {
            hashMap.put(str, obj);
        }
        return hashMap;
    }

    public static String jsonStringFromMapWithNull(Object obj) {
        if (AVOSCloud.isDebugEnable()) {
            return JSON.toJSONString(obj, SerializerFeature.WriteMapNullValue, SerializerFeature.WriteNullBooleanAsFalse, SerializerFeature.WriteNullNumberAsZero, SerializerFeature.PrettyFormat);
        }
        return JSON.toJSONString(obj, SerializerFeature.WriteMapNullValue, SerializerFeature.WriteNullBooleanAsFalse, SerializerFeature.WriteNullNumberAsZero);
    }

    public static String jsonStringFromObjectWithNull(Object obj) {
        if (AVOSCloud.isDebugEnable()) {
            return JSON.toJSONString(obj, SerializerFeature.WriteMapNullValue, SerializerFeature.WriteNullBooleanAsFalse, SerializerFeature.WriteNullNumberAsZero, SerializerFeature.PrettyFormat);
        }
        return JSON.toJSONString(obj, SerializerFeature.WriteMapNullValue, SerializerFeature.WriteNullBooleanAsFalse, SerializerFeature.WriteNullNumberAsZero);
    }

    public static long getCurrentTimestamp() {
        return System.currentTimeMillis();
    }

    public static boolean equals(Object obj, Object obj2) {
        return obj == obj2 || (obj != null && obj.equals(obj2));
    }

    public static int hash(Object... objArr) {
        return Arrays.hashCode(objArr);
    }

    public static void ensureElementsNotNull(List<String> list, String str) {
        for (String str2 : list) {
            Objects.requireNonNull(str2, str);
        }
    }

    public static double normalize2Double(int i, Double d) {
        return normalize2Double(i, new BigDecimal(d.doubleValue()));
    }

    public static double normalize2Double(int i, BigDecimal bigDecimal) {
        return bigDecimal.setScale(i, 4).doubleValue();
    }

    public static void mergeConcurrentMap(ConcurrentMap<String, Object> concurrentMap, Map<String, Object> map) {
        if (!(concurrentMap == null || map == null)) {
            for (Map.Entry<String, Object> entry : map.entrySet()) {
                if (!(entry.getKey() == null || entry.getValue() == null)) {
                    concurrentMap.put(entry.getKey(), entry.getValue());
                }
            }
        }
    }

    public static void putAllWithNullFilter(Map<String, Object> map, Map<String, Object> map2) {
        if (!(map == null || map2 == null)) {
            for (Map.Entry<String, Object> entry : map2.entrySet()) {
                if (entry.getValue() != null) {
                    map.put(entry.getKey(), entry.getValue());
                }
            }
        }
    }
}
