package cn.leancloud.utils;

import cn.leancloud.AVFile;
import java.util.regex.Pattern;

public class FileUtil {
    public static final String DEFAULTMIMETYPE = "application/octet-stream";
    public static final int DEFAULT_FILE_KEY_LEN = 40;
    private static MimeTypeDetector detector = new DefaultMimeTypeDetector();

    public interface MimeTypeDetector {
        String getMimeTypeFromExtension(String str);

        String getMimeTypeFromPath(String str);

        String getMimeTypeFromUrl(String str);
    }

    public static void config(MimeTypeDetector mimeTypeDetector) {
        detector = mimeTypeDetector;
    }

    public static String getExtensionFromFilename(String str) {
        int lastIndexOf;
        return (StringUtil.isEmpty(str) || !Pattern.matches("[a-zA-Z_0-9\\.\\-\\(\\)\\%]+", str) || (lastIndexOf = str.lastIndexOf(46)) < 0) ? "" : str.substring(lastIndexOf + 1);
    }

    public static String getFileMimeType(AVFile aVFile) {
        String str;
        String name = aVFile.getName();
        String url = aVFile.getUrl();
        if (!StringUtil.isEmpty(name)) {
            str = getMimeTypeFromFilename(name);
        } else {
            str = !StringUtil.isEmpty(url) ? getMimeTypeFromUrl(url) : null;
        }
        return StringUtil.isEmpty(str) ? DEFAULTMIMETYPE : str;
    }

    public static String getMimeTypeFromFilename(String str) {
        String mimeTypeFromExtension;
        String extensionFromFilename = getExtensionFromFilename(str);
        if (StringUtil.isEmpty(extensionFromFilename) || (mimeTypeFromExtension = detector.getMimeTypeFromExtension(extensionFromFilename)) == null) {
            return "";
        }
        return mimeTypeFromExtension;
    }

    public static String getMimeTypeFromPath(String str) {
        String mimeTypeFromPath;
        if (StringUtil.isEmpty(str) || (mimeTypeFromPath = detector.getMimeTypeFromPath(str)) == null) {
            return "";
        }
        return mimeTypeFromPath;
    }

    public static String getMimeTypeFromUrl(String str) {
        String mimeTypeFromUrl;
        if (StringUtil.isEmpty(str) || (mimeTypeFromUrl = detector.getMimeTypeFromUrl(str)) == null) {
            return "";
        }
        return mimeTypeFromUrl;
    }
}
