package com.bigkoo.pickerview.utils;

import cn.leancloud.AVException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.Locale;

public class ChinaDate {
    private static final String[] Animals = {"鼠", "牛", "虎", "兔", "龙", "蛇", "马", "羊", "猴", "鸡", "狗", "猪"};
    private static final String[] Gan = {"甲", "乙", "丙", "丁", "戊", "己", "庚", "辛", "壬", "癸"};
    private static final String[] Zhi = {"子", "丑", "寅", "卯", "辰", "巳", "午", "未", "申", "酉", "戌", "亥"};
    private static final long[] lunarInfo;
    private static final String[] nStr1 = {"", "正", "二", "三", "四", "五", "六", "七", "八", "九", "十", "冬", "腊"};
    private static SimpleDateFormat sdf = new SimpleDateFormat("yyyy年M月d日 EEEEE");

    static {
        long[] jArr = new long[AVException.PASSWORD_MISSING];
        // fill-array-data instruction
        jArr[0] = 19416;
        jArr[1] = 19168;
        jArr[2] = 42352;
        jArr[3] = 21717;
        jArr[4] = 53856;
        jArr[5] = 55632;
        jArr[6] = 91476;
        jArr[7] = 22176;
        jArr[8] = 39632;
        jArr[9] = 21970;
        jArr[10] = 19168;
        jArr[11] = 42422;
        jArr[12] = 42192;
        jArr[13] = 53840;
        jArr[14] = 119381;
        jArr[15] = 46400;
        jArr[16] = 54944;
        jArr[17] = 44450;
        jArr[18] = 38320;
        jArr[19] = 84343;
        jArr[20] = 18800;
        jArr[21] = 42160;
        jArr[22] = 46261;
        jArr[23] = 27216;
        jArr[24] = 27968;
        jArr[25] = 109396;
        jArr[26] = 11104;
        jArr[27] = 38256;
        jArr[28] = 21234;
        jArr[29] = 18800;
        jArr[30] = 25958;
        jArr[31] = 54432;
        jArr[32] = 59984;
        jArr[33] = 28309;
        jArr[34] = 23248;
        jArr[35] = 11104;
        jArr[36] = 100067;
        jArr[37] = 37600;
        jArr[38] = 116951;
        jArr[39] = 51536;
        jArr[40] = 54432;
        jArr[41] = 120998;
        jArr[42] = 46416;
        jArr[43] = 22176;
        jArr[44] = 107956;
        jArr[45] = 9680;
        jArr[46] = 37584;
        jArr[47] = 53938;
        jArr[48] = 43344;
        jArr[49] = 46423;
        jArr[50] = 27808;
        jArr[51] = 46416;
        jArr[52] = 86869;
        jArr[53] = 19872;
        jArr[54] = 42416;
        jArr[55] = 83315;
        jArr[56] = 21168;
        jArr[57] = 43432;
        jArr[58] = 59728;
        jArr[59] = 27296;
        jArr[60] = 44710;
        jArr[61] = 43856;
        jArr[62] = 19296;
        jArr[63] = 43748;
        jArr[64] = 42352;
        jArr[65] = 21088;
        jArr[66] = 62051;
        jArr[67] = 55632;
        jArr[68] = 23383;
        jArr[69] = 22176;
        jArr[70] = 38608;
        jArr[71] = 19925;
        jArr[72] = 19152;
        jArr[73] = 42192;
        jArr[74] = 54484;
        jArr[75] = 53840;
        jArr[76] = 54616;
        jArr[77] = 46400;
        jArr[78] = 46752;
        jArr[79] = 103846;
        jArr[80] = 38320;
        jArr[81] = 18864;
        jArr[82] = 43380;
        jArr[83] = 42160;
        jArr[84] = 45690;
        jArr[85] = 27216;
        jArr[86] = 27968;
        jArr[87] = 44870;
        jArr[88] = 43872;
        jArr[89] = 38256;
        jArr[90] = 19189;
        jArr[91] = 18800;
        jArr[92] = 25776;
        jArr[93] = 29859;
        jArr[94] = 59984;
        jArr[95] = 27480;
        jArr[96] = 21952;
        jArr[97] = 43872;
        jArr[98] = 38613;
        jArr[99] = 37600;
        jArr[100] = 51552;
        jArr[101] = 55636;
        jArr[102] = 54432;
        jArr[103] = 55888;
        jArr[104] = 30034;
        jArr[105] = 22176;
        jArr[106] = 43959;
        jArr[107] = 9680;
        jArr[108] = 37584;
        jArr[109] = 51893;
        jArr[110] = 43344;
        jArr[111] = 46240;
        jArr[112] = 47780;
        jArr[113] = 44368;
        jArr[114] = 21977;
        jArr[115] = 19360;
        jArr[116] = 42416;
        jArr[117] = 86390;
        jArr[118] = 21168;
        jArr[119] = 43312;
        jArr[120] = 31060;
        jArr[121] = 27296;
        jArr[122] = 44368;
        jArr[123] = 23378;
        jArr[124] = 19296;
        jArr[125] = 42726;
        jArr[126] = 42208;
        jArr[127] = 53856;
        jArr[128] = 60005;
        jArr[129] = 54576;
        jArr[130] = 23200;
        jArr[131] = 30371;
        jArr[132] = 38608;
        jArr[133] = 19195;
        jArr[134] = 19152;
        jArr[135] = 42192;
        jArr[136] = 118966;
        jArr[137] = 53840;
        jArr[138] = 54560;
        jArr[139] = 56645;
        jArr[140] = 46496;
        jArr[141] = 22224;
        jArr[142] = 21938;
        jArr[143] = 18864;
        jArr[144] = 42359;
        jArr[145] = 42160;
        jArr[146] = 43600;
        jArr[147] = 111189;
        jArr[148] = 27936;
        jArr[149] = 44448;
        jArr[150] = 84835;
        jArr[151] = 37744;
        jArr[152] = 18936;
        jArr[153] = 18800;
        jArr[154] = 25776;
        jArr[155] = 92326;
        jArr[156] = 59984;
        jArr[157] = 27424;
        jArr[158] = 108228;
        jArr[159] = 43744;
        jArr[160] = 41696;
        jArr[161] = 53987;
        jArr[162] = 51552;
        jArr[163] = 54615;
        jArr[164] = 54432;
        jArr[165] = 55888;
        jArr[166] = 23893;
        jArr[167] = 22176;
        jArr[168] = 42704;
        jArr[169] = 21972;
        jArr[170] = 21200;
        jArr[171] = 43448;
        jArr[172] = 43344;
        jArr[173] = 46240;
        jArr[174] = 46758;
        jArr[175] = 44368;
        jArr[176] = 21920;
        jArr[177] = 43940;
        jArr[178] = 42416;
        jArr[179] = 21168;
        jArr[180] = 45683;
        jArr[181] = 26928;
        jArr[182] = 29495;
        jArr[183] = 27296;
        jArr[184] = 44368;
        jArr[185] = 84821;
        jArr[186] = 19296;
        jArr[187] = 42352;
        jArr[188] = 21732;
        jArr[189] = 53600;
        jArr[190] = 59752;
        jArr[191] = 54560;
        jArr[192] = 55968;
        jArr[193] = 92838;
        jArr[194] = 22224;
        jArr[195] = 19168;
        jArr[196] = 43476;
        jArr[197] = 41680;
        jArr[198] = 53584;
        jArr[199] = 62034;
        jArr[200] = 54560;
        lunarInfo = jArr;
    }

    private static final int lYearDays(int i) {
        int i2 = 348;
        for (int i3 = 32768; i3 > 8; i3 >>= 1) {
            if ((lunarInfo[i - 1900] & ((long) i3)) != 0) {
                i2++;
            }
        }
        return i2 + leapDays(i);
    }

    public static final int leapDays(int i) {
        if (leapMonth(i) != 0) {
            return (lunarInfo[i + -1900] & 65536) != 0 ? 30 : 29;
        }
        return 0;
    }

    public static final int leapMonth(int i) {
        return (int) (lunarInfo[i - 1900] & 15);
    }

    public static final int monthDays(int i, int i2) {
        return (((long) (65536 >> i2)) & lunarInfo[i + -1900]) == 0 ? 29 : 30;
    }

    public static final String AnimalsYear(int i) {
        return Animals[(i - 4) % 12];
    }

    private static final String cyclicalm(int i) {
        return Gan[i % 10] + Zhi[i % 12];
    }

    public static final String cyclical(int i) {
        return cyclicalm((i - 1900) + 36);
    }

    public static final long[] calElement(int i, int i2, int i3) {
        long j;
        long j2;
        long[] jArr = new long[7];
        int i4 = LunarCalendar.MIN_YEAR;
        long time = (new GregorianCalendar(i, i2 - 1, i3).getTime().getTime() - new GregorianCalendar(LunarCalendar.MIN_YEAR, 0, 31).getTime().getTime()) / 86400000;
        jArr[5] = 40 + time;
        jArr[4] = 14;
        int i5 = 0;
        while (i4 < 2100 && time > 0) {
            i5 = lYearDays(i4);
            time -= (long) i5;
            jArr[4] = jArr[4] + 12;
            i4++;
        }
        if (time < 0) {
            time += (long) i5;
            i4--;
            jArr[4] = jArr[4] - 12;
        }
        jArr[0] = (long) i4;
        jArr[3] = (long) (i4 - 1864);
        int leapMonth = leapMonth(i4);
        jArr[6] = 0;
        int i6 = 1;
        while (i6 < 13 && time > 0) {
            if (leapMonth > 0 && i6 == leapMonth + 1 && jArr[6] == 0) {
                i6--;
                jArr[6] = 1;
                j2 = time;
                i5 = leapDays((int) jArr[0]);
            } else {
                j2 = time;
                i5 = monthDays((int) jArr[0], i6);
            }
            if (jArr[6] == 1 && i6 == leapMonth + 1) {
                jArr[6] = 0;
            }
            time = j2 - ((long) i5);
            if (jArr[6] == 0) {
                jArr[4] = jArr[4] + 1;
            }
            i6++;
        }
        int i7 = (time > 0 ? 1 : (time == 0 ? 0 : -1));
        if (i7 == 0 && leapMonth > 0 && i6 == leapMonth + 1) {
            if (jArr[6] == 1) {
                jArr[6] = 0;
            } else {
                jArr[6] = 1;
                i6--;
                jArr[4] = jArr[4] - 1;
            }
        }
        if (i7 < 0) {
            j = time + ((long) i5);
            i6--;
            jArr[4] = jArr[4] - 1;
        } else {
            j = time;
        }
        jArr[1] = (long) i6;
        jArr[2] = j + 1;
        return jArr;
    }

    public static final String getChinaDate(int i) {
        if (i == 10) {
            return "初十";
        }
        if (i == 20) {
            return "二十";
        }
        if (i == 30) {
            return "三十";
        }
        int i2 = i / 10;
        String str = i2 == 0 ? "初" : "";
        if (i2 == 1) {
            str = "十";
        }
        if (i2 == 2) {
            str = "廿";
        }
        if (i2 == 3) {
            str = "三";
        }
        switch (i % 10) {
            case 1:
                return str + "一";
            case 2:
                return str + "二";
            case 3:
                return str + "三";
            case 4:
                return str + "四";
            case 5:
                return str + "五";
            case 6:
                return str + "六";
            case 7:
                return str + "七";
            case 8:
                return str + "八";
            case 9:
                return str + "九";
            default:
                return str;
        }
    }

    public static String getCurrentLunarDate() {
        Calendar instance = Calendar.getInstance(Locale.SIMPLIFIED_CHINESE);
        int i = instance.get(1);
        long[] calElement = calElement(i, instance.get(2) + 1, instance.get(5));
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(sdf.format(instance.getTime()));
        stringBuffer.append(" 农历");
        stringBuffer.append(cyclical(i));
        stringBuffer.append('(');
        stringBuffer.append(AnimalsYear(i));
        stringBuffer.append(")年");
        stringBuffer.append(nStr1[(int) calElement[1]]);
        stringBuffer.append("月");
        stringBuffer.append(getChinaDate((int) calElement[2]));
        return stringBuffer.toString();
    }

    public static String oneDay(int i, int i2, int i3) {
        long[] calElement = calElement(i, i2, i3);
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(" 农历");
        stringBuffer.append(cyclical(i));
        stringBuffer.append('(');
        stringBuffer.append(AnimalsYear(i));
        stringBuffer.append(")年");
        stringBuffer.append(nStr1[(int) calElement[1]]);
        stringBuffer.append("月");
        stringBuffer.append(getChinaDate((int) calElement[2]));
        return stringBuffer.toString();
    }

    public static String getLunarYearText(int i) {
        StringBuilder sb = new StringBuilder();
        int i2 = i - 4;
        sb.append(Gan[i2 % 10]);
        sb.append(Zhi[i2 % 12]);
        sb.append("年");
        return sb.toString();
    }

    public static ArrayList<String> getYears(int i, int i2) {
        ArrayList<String> arrayList = new ArrayList<>();
        while (i < i2) {
            arrayList.add(String.format("%s(%d)", getLunarYearText(i), Integer.valueOf(i)));
            i++;
        }
        return arrayList;
    }

    public static ArrayList<String> getMonths(int i) {
        String[] strArr;
        ArrayList<String> arrayList = new ArrayList<>();
        int i2 = 1;
        while (true) {
            strArr = nStr1;
            if (i2 >= strArr.length) {
                break;
            }
            arrayList.add(strArr[i2] + "月");
            i2++;
        }
        if (leapMonth(i) != 0) {
            int leapMonth = leapMonth(i);
            arrayList.add(leapMonth, "闰" + strArr[leapMonth(i)] + "月");
        }
        return arrayList;
    }

    public static ArrayList<String> getLunarDays(int i) {
        ArrayList<String> arrayList = new ArrayList<>();
        for (int i2 = 1; i2 <= i; i2++) {
            arrayList.add(getChinaDate(i2));
        }
        return arrayList;
    }
}
