package com.jiazheng.app.base;

import android.text.TextUtils;
import androidx.lifecycle.MutableLiveData;
import com.jiazheng.app.bean.ParamsBuilder;
import com.jiazheng.app.bean.Resource;
import com.jiazheng.app.network.ResponseModel;
import com.jiazheng.app.network.RetrofitApiService;
import com.jiazheng.app.network.RetrofitManager;
import com.jiazheng.app.network.interceptor.NetCacheInterceptor;
import com.jiazheng.app.network.interceptor.OfflineCacheInterceptor;
import com.trello.rxlifecycle2.LifecycleTransformer;
import io.reactivex.Observable;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.functions.Action;
import io.reactivex.functions.Consumer;
import io.reactivex.functions.Function;
import io.reactivex.schedulers.Schedulers;
import java.util.ArrayList;
import java.util.concurrent.TimeUnit;

public class BaseModel {
    public LifecycleTransformer objectLifecycleTransformer;
    public ArrayList<String> onNetTags;

    public RetrofitApiService getApiService() {
        return RetrofitManager.getRetrofitManager().getApiService();
    }

    public void setObjectLifecycleTransformer(LifecycleTransformer lifecycleTransformer) {
        this.objectLifecycleTransformer = lifecycleTransformer;
    }

    public void setOnNetTags(ArrayList<String> arrayList) {
        this.onNetTags = arrayList;
    }

    public <T> MutableLiveData<T> observeGo(Observable observable, MutableLiveData<T> mutableLiveData) {
        return observe(observable, mutableLiveData, null);
    }

    public <T> MutableLiveData<T> observeGo(Observable observable, MutableLiveData<T> mutableLiveData, ParamsBuilder paramsBuilder) {
        if (paramsBuilder == null) {
            paramsBuilder = ParamsBuilder.build();
        }
        if (paramsBuilder.getRetryCount() > 0) {
            return observeWithRetry(observable, mutableLiveData, paramsBuilder);
        }
        return observe(observable, mutableLiveData, paramsBuilder);
    }

    public <T> MutableLiveData<T> observe(Observable observable, MutableLiveData<T> mutableLiveData, ParamsBuilder paramsBuilder) {
        if (paramsBuilder == null) {
            paramsBuilder = ParamsBuilder.build();
        }
        boolean isShowDialog = paramsBuilder.isShowDialog();
        String loadingMessage = paramsBuilder.getLoadingMessage();
        int onlineCacheTime = paramsBuilder.getOnlineCacheTime();
        int offlineCacheTime = paramsBuilder.getOfflineCacheTime();
        if (onlineCacheTime > 0) {
            setOnlineCacheTime(onlineCacheTime);
        }
        if (offlineCacheTime > 0) {
            setOfflineCacheTime(offlineCacheTime);
        }
        String oneTag = paramsBuilder.getOneTag();
        if (!TextUtils.isEmpty(oneTag) && this.onNetTags.contains(oneTag)) {
            return mutableLiveData;
        }
        observable.subscribeOn(Schedulers.io()).doOnSubscribe(new Consumer(oneTag, isShowDialog, mutableLiveData, loadingMessage) {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$ZGo9GGGj7NRKrRHE9MpeCCj5wSU */
            public final /* synthetic */ String f$1;
            public final /* synthetic */ boolean f$2;
            public final /* synthetic */ MutableLiveData f$3;
            public final /* synthetic */ String f$4;

            {
                this.f$1 = r2;
                this.f$2 = r3;
                this.f$3 = r4;
                this.f$4 = r5;
            }

            @Override // io.reactivex.functions.Consumer
            public final void accept(Object obj) {
                BaseModel.this.lambda$observe$0$BaseModel(this.f$1, this.f$2, this.f$3, this.f$4, obj);
            }
        }).doFinally(new Action(oneTag) {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$1LEyIRSpoR7KwbqQAPq7796Bvo */
            public final /* synthetic */ String f$1;

            {
                this.f$1 = r2;
            }

            @Override // io.reactivex.functions.Action
            public final void run() {
                BaseModel.this.lambda$observe$1$BaseModel(this.f$1);
            }
        }).observeOn(AndroidSchedulers.mainThread()).subscribe(new Consumer() {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$O5C0h2WGu6Sr3S7QgZmhu_mTRqc */

            @Override // io.reactivex.functions.Consumer
            public final void accept(Object obj) {
                BaseModel.lambda$observe$2(MutableLiveData.this, obj);
            }
        }, new Consumer() {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$UTv7ZNlurK75o2ddMTbrdvMFfmM */

            @Override // io.reactivex.functions.Consumer
            public final void accept(Object obj) {
                BaseModel.lambda$observe$3(MutableLiveData.this, obj);
            }
        });
        return mutableLiveData;
    }

    public /* synthetic */ void lambda$observe$0$BaseModel(String str, boolean z, MutableLiveData mutableLiveData, String str2, Object obj) throws Exception {
        if (!TextUtils.isEmpty(str)) {
            this.onNetTags.add(str);
        }
        if (z) {
            mutableLiveData.postValue(Resource.loading(str2));
        }
    }

    public /* synthetic */ void lambda$observe$1$BaseModel(String str) throws Exception {
        if (!TextUtils.isEmpty(str)) {
            this.onNetTags.remove(str);
        }
    }

    static /* synthetic */ void lambda$observe$2(MutableLiveData mutableLiveData, Object obj) throws Exception {
        mutableLiveData.postValue(Resource.response((ResponseModel) obj));
    }

    static /* synthetic */ void lambda$observe$3(MutableLiveData mutableLiveData, Object obj) throws Exception {
        mutableLiveData.postValue(Resource.error((Throwable) obj));
    }

    public <T> MutableLiveData<T> observeWithRetry(Observable observable, MutableLiveData<T> mutableLiveData, ParamsBuilder paramsBuilder) {
        if (paramsBuilder == null) {
            paramsBuilder = ParamsBuilder.build();
        }
        boolean isShowDialog = paramsBuilder.isShowDialog();
        String loadingMessage = paramsBuilder.getLoadingMessage();
        int onlineCacheTime = paramsBuilder.getOnlineCacheTime();
        int offlineCacheTime = paramsBuilder.getOfflineCacheTime();
        if (onlineCacheTime > 0) {
            setOnlineCacheTime(onlineCacheTime);
        }
        if (offlineCacheTime > 0) {
            setOfflineCacheTime(offlineCacheTime);
        }
        String oneTag = paramsBuilder.getOneTag();
        if (!TextUtils.isEmpty(oneTag) && this.onNetTags.contains(oneTag)) {
            return mutableLiveData;
        }
        int[] iArr = {0};
        observable.subscribeOn(Schedulers.io()).retryWhen(new Function(iArr, paramsBuilder.getRetryCount()) {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$SE29vARX0XhjYUbcSJUTHiVYXFY */
            public final /* synthetic */ int[] f$0;
            public final /* synthetic */ int f$1;

            {
                this.f$0 = r1;
                this.f$1 = r2;
            }

            @Override // io.reactivex.functions.Function
            public final Object apply(Object obj) {
                return BaseModel.lambda$observeWithRetry$4(this.f$0, this.f$1, obj);
            }
        }).doOnSubscribe(new Consumer(oneTag, isShowDialog, mutableLiveData, loadingMessage) {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$5rJKbig22D7RpjAAeiM3aTKCa6s */
            public final /* synthetic */ String f$1;
            public final /* synthetic */ boolean f$2;
            public final /* synthetic */ MutableLiveData f$3;
            public final /* synthetic */ String f$4;

            {
                this.f$1 = r2;
                this.f$2 = r3;
                this.f$3 = r4;
                this.f$4 = r5;
            }

            @Override // io.reactivex.functions.Consumer
            public final void accept(Object obj) {
                BaseModel.this.lambda$observeWithRetry$5$BaseModel(this.f$1, this.f$2, this.f$3, this.f$4, obj);
            }
        }).doFinally(new Action(oneTag) {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$sh22PIoQnL2WWeUdKPbynPlP_U */
            public final /* synthetic */ String f$1;

            {
                this.f$1 = r2;
            }

            @Override // io.reactivex.functions.Action
            public final void run() {
                BaseModel.this.lambda$observeWithRetry$6$BaseModel(this.f$1);
            }
        }).observeOn(AndroidSchedulers.mainThread()).subscribe(new Consumer() {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$9PrKReqKq_JpyfiSqENenisOgw */

            @Override // io.reactivex.functions.Consumer
            public final void accept(Object obj) {
                BaseModel.lambda$observeWithRetry$7(MutableLiveData.this, obj);
            }
        }, new Consumer() {
            /* class com.jiazheng.app.base.$$Lambda$BaseModel$n_RmDaDVAjDxPyE27K9DLbrzrqc */

            @Override // io.reactivex.functions.Consumer
            public final void accept(Object obj) {
                MutableLiveData.this.postValue(Resource.error((Throwable) obj));
            }
        });
        return mutableLiveData;
    }

    static /* synthetic */ Object lambda$observeWithRetry$4(int[] iArr, int i, Object obj) throws Exception {
        if (iArr[0] > i) {
            return Observable.error(new Throwable("The number of reconnections reached the maximum"));
        }
        iArr[0] = iArr[0] + 1;
        return Observable.just(1).delay(5000, TimeUnit.MILLISECONDS);
    }

    public /* synthetic */ void lambda$observeWithRetry$5$BaseModel(String str, boolean z, MutableLiveData mutableLiveData, String str2, Object obj) throws Exception {
        if (!TextUtils.isEmpty(str)) {
            this.onNetTags.add(str);
        }
        if (z) {
            mutableLiveData.postValue(Resource.loading(str2));
        }
    }

    public /* synthetic */ void lambda$observeWithRetry$6$BaseModel(String str) throws Exception {
        if (!TextUtils.isEmpty(str)) {
            this.onNetTags.remove(str);
        }
    }

    static /* synthetic */ void lambda$observeWithRetry$7(MutableLiveData mutableLiveData, Object obj) throws Exception {
        mutableLiveData.postValue(Resource.response((ResponseModel) obj));
    }

    public void setOnlineCacheTime(int i) {
        NetCacheInterceptor.getInstance().setOnlineTime(i);
    }

    public void setOfflineCacheTime(int i) {
        OfflineCacheInterceptor.getInstance().setOfflineCacheTime(i);
    }
}
