package com.jiazheng.app.bean;

import com.jiazheng.app.network.ResponseModel;
import okhttp3.ResponseBody;

public class Resource<T> {
    public static final int ERROR = 2;
    public static final int FAIL = 3;
    public static final int LOADING = 0;
    public static final int PROGRESS = 4;
    public static final int SUCCESS = 1;
    public int code;
    public T data;
    public Throwable error;
    public ResponseBody errorBody;
    public String msg;
    public int precent;
    public int state;
    public long total;

    public interface OnHandleCallback<T> {
        void onCompleted();

        void onError(Throwable th);

        void onFailure(String str);

        void onLoading(String str);

        void onProgress(int i, long j);

        void onSuccess(T t);
    }

    public Resource(int i, T t, String str) {
        this.state = i;
        this.msg = str;
        this.data = t;
    }

    public Resource(int i, Throwable th) {
        this.state = i;
        this.error = th;
    }

    public Resource(int i, ResponseBody responseBody) {
        this.state = i;
        this.errorBody = responseBody;
    }

    public Resource(int i, int i2, long j) {
        this.state = i;
        this.precent = i2;
        this.total = j;
    }

    public static <T> Resource<T> loading(String str) {
        return new Resource<>(0, (Object) null, str);
    }

    public static <T> Resource<T> success(T t) {
        return new Resource<>(1, t, (String) null);
    }

    public static <T> Resource<T> response(ResponseModel<T> responseModel) {
        if (responseModel == null) {
            return new Resource<>(2, (Object) null, (String) null);
        }
        if (responseModel.getResponse_status() == 1) {
            return new Resource<>(1, responseModel.getData(), (String) null);
        }
        return new Resource<>(3, (Object) null, responseModel.getResponse_msg());
    }

    public static <T> Resource<T> failure(String str) {
        return new Resource<>(2, (Object) null, str);
    }

    public static <T> Resource<T> error(Throwable th) {
        return new Resource<>(2, th);
    }

    public static <T> Resource<T> error(ResponseBody responseBody) {
        return new Resource<>(2, responseBody);
    }

    public static <T> Resource<T> progress(int i, long j) {
        return new Resource<>(4, i, j);
    }

    public void handler(OnHandleCallback<T> onHandleCallback) {
        int i = this.state;
        if (i == 0) {
            onHandleCallback.onLoading(this.msg);
        } else if (i == 1) {
            onHandleCallback.onSuccess(this.data);
        } else if (i == 2) {
            onHandleCallback.onError(this.error);
        } else if (i == 3) {
            onHandleCallback.onFailure(this.msg);
        } else if (i == 4) {
            onHandleCallback.onProgress(this.precent, this.total);
        }
        if (this.state != 0) {
            onHandleCallback.onCompleted();
        }
    }
}
