package com.jiazheng.app.network;

import android.os.Environment;
import com.jiazheng.app.network.interceptor.HttpLogInterceptor;
import com.jiazheng.app.network.interceptor.NetCacheInterceptor;
import com.jiazheng.app.network.interceptor.OfflineCacheInterceptor;
import java.io.File;
import java.lang.reflect.Field;
import java.security.SecureRandom;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.concurrent.TimeUnit;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import okhttp3.Cache;
import okhttp3.OkHttpClient;
import retrofit2.Retrofit;
import retrofit2.adapter.rxjava2.RxJava2CallAdapterFactory;
import retrofit2.converter.gson.GsonConverterFactory;

public class RetrofitManager {
    private static RetrofitManager retrofitManager;
    private OkHttpClient okHttpClient;
    private Retrofit retrofit;
    private RetrofitApiService retrofitApiService;

    public RetrofitManager() {
        initOkhttpClient();
        initRetrofit();
    }

    private void initOkhttpClient() {
        OkHttpClient.Builder builder = new OkHttpClient.Builder();
        this.okHttpClient = builder.cache(new Cache(new File(Environment.getExternalStorageDirectory() + "/okhttp_cache/"), 52428800)).addInterceptor(new HttpLogInterceptor()).connectTimeout(10, TimeUnit.SECONDS).readTimeout(10, TimeUnit.SECONDS).writeTimeout(10, TimeUnit.SECONDS).addInterceptor(OfflineCacheInterceptor.getInstance()).addNetworkInterceptor(NetCacheInterceptor.getInstance()).build();
    }

    public static RetrofitManager getRetrofitManager() {
        if (retrofitManager == null) {
            synchronized (RetrofitManager.class) {
                if (retrofitManager == null) {
                    retrofitManager = new RetrofitManager();
                }
            }
        }
        return retrofitManager;
    }

    public RetrofitApiService getApiService() {
        if (retrofitManager == null) {
            retrofitManager = getRetrofitManager();
        }
        return retrofitManager.retrofitApiService;
    }

    private void ignoreSSLCheck() {
        SSLContext sSLContext;
        Exception e;
        try {
            sSLContext = SSLContext.getInstance("SSL");
            try {
                sSLContext.init(null, new TrustManager[]{new X509TrustManager() {
                    /* class com.jiazheng.app.network.RetrofitManager.AnonymousClass1 */

                    @Override // javax.net.ssl.X509TrustManager
                    public void checkClientTrusted(X509Certificate[] x509CertificateArr, String str) throws CertificateException {
                    }

                    @Override // javax.net.ssl.X509TrustManager
                    public void checkServerTrusted(X509Certificate[] x509CertificateArr, String str) throws CertificateException {
                    }

                    public X509Certificate[] getAcceptedIssuers() {
                        return null;
                    }
                }}, new SecureRandom());
            } catch (Exception e2) {
                e = e2;
            }
        } catch (Exception e3) {
            sSLContext = null;
            e = e3;
            e.printStackTrace();
            AnonymousClass2 r0 = new HostnameVerifier() {
                /* class com.jiazheng.app.network.RetrofitManager.AnonymousClass2 */

                public boolean verify(String str, SSLSession sSLSession) {
                    return true;
                }
            };
            Class<?> cls = Class.forName("okhttp3.OkHttpClient");
            Field declaredField = cls.getDeclaredField("hostnameVerifier");
            declaredField.setAccessible(true);
            declaredField.set(this.okHttpClient, r0);
            Field declaredField2 = cls.getDeclaredField("sslSocketFactory");
            declaredField2.setAccessible(true);
            declaredField2.set(this.okHttpClient, sSLContext.getSocketFactory());
        }
        AnonymousClass2 r02 = new HostnameVerifier() {
            /* class com.jiazheng.app.network.RetrofitManager.AnonymousClass2 */

            public boolean verify(String str, SSLSession sSLSession) {
                return true;
            }
        };
        try {
            Class<?> cls2 = Class.forName("okhttp3.OkHttpClient");
            Field declaredField3 = cls2.getDeclaredField("hostnameVerifier");
            declaredField3.setAccessible(true);
            declaredField3.set(this.okHttpClient, r02);
            Field declaredField22 = cls2.getDeclaredField("sslSocketFactory");
            declaredField22.setAccessible(true);
            declaredField22.set(this.okHttpClient, sSLContext.getSocketFactory());
        } catch (Exception e4) {
            e4.printStackTrace();
        }
    }

    private void initRetrofit() {
        Retrofit build = new Retrofit.Builder().baseUrl("https://www.paycashin.com/api/v6/public/index.php/").addConverterFactory(GsonConverterFactory.create()).addCallAdapterFactory(RxJava2CallAdapterFactory.create()).client(this.okHttpClient).build();
        this.retrofit = build;
        this.retrofitApiService = (RetrofitApiService) build.create(RetrofitApiService.class);
    }
}
