package com.jiazheng.app.network.interceptor;

import android.os.Build;
import android.text.TextUtils;
import com.jiazheng.app.utils.BaseUtils;
import com.jiazheng.app.utils.PreferenceUtil;
import java.io.IOException;
import java.util.List;
import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.Response;

public class NetCacheInterceptor implements Interceptor {
    private static NetCacheInterceptor cacheInterceptor;
    private int onlineCacheTime;

    public static NetCacheInterceptor getInstance() {
        if (cacheInterceptor == null) {
            synchronized (NetCacheInterceptor.class) {
                if (cacheInterceptor == null) {
                    cacheInterceptor = new NetCacheInterceptor();
                }
            }
        }
        return cacheInterceptor;
    }

    private NetCacheInterceptor() {
    }

    public void setOnlineTime(int i) {
        this.onlineCacheTime = i;
    }

    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) throws IOException {
        Request.Builder newBuilder = chain.request().newBuilder();
        String str = (String) PreferenceUtil.get("token", "");
        if (!TextUtils.isEmpty(str)) {
            newBuilder.addHeader("token", str).build();
        }
        newBuilder.addHeader("os-type", "android").addHeader("os-version", Build.VERSION.RELEASE.trim()).addHeader("brand", Build.BRAND.trim()).addHeader("model", Build.MODEL.trim()).addHeader("app-version", BaseUtils.getVersionName()).addHeader("device-id", (String) PreferenceUtil.get("uuid", "")).addHeader("adid", "").addHeader("gps-adid", "").build();
        Response proceed = chain.proceed(newBuilder.build());
        List<String> values = proceed.headers().values("token");
        if (values.size() > 0) {
            PreferenceUtil.put("token", values.get(0));
        }
        if (proceed != null) {
            proceed.code();
        }
        int i = this.onlineCacheTime;
        if (i == 0) {
            return proceed.newBuilder().header("Cache-Control", "no-cache").removeHeader("Pragma").build();
        }
        Response.Builder newBuilder2 = proceed.newBuilder();
        Response build = newBuilder2.header("Cache-Control", "public, max-age=" + i).removeHeader("Pragma").build();
        this.onlineCacheTime = 0;
        return build;
    }
}
