package com.jiazheng.app.network.interceptor;

import com.jiazheng.app.base.MyApplication;
import com.jiazheng.app.utils.network.NetWorkUtils;
import java.io.IOException;
import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.Response;

public class OfflineCacheInterceptor implements Interceptor {
    private static OfflineCacheInterceptor offlineCacheInterceptor;
    private int offlineCacheTime;

    private OfflineCacheInterceptor() {
    }

    public static OfflineCacheInterceptor getInstance() {
        if (offlineCacheInterceptor == null) {
            synchronized (OfflineCacheInterceptor.class) {
                if (offlineCacheInterceptor == null) {
                    offlineCacheInterceptor = new OfflineCacheInterceptor();
                }
            }
        }
        return offlineCacheInterceptor;
    }

    public void setOfflineCacheTime(int i) {
        this.offlineCacheTime = i;
    }

    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) throws IOException {
        Request request = chain.request();
        if (!NetWorkUtils.isNetworkConnected(MyApplication.getContext())) {
            int i = this.offlineCacheTime;
            if (i != 0) {
                Request.Builder newBuilder = request.newBuilder();
                request = newBuilder.header("Cache-Control", "public, only-if-cached, max-stale=" + i).build();
                this.offlineCacheTime = 0;
            } else {
                request = request.newBuilder().header("Cache-Control", "no-cache").build();
            }
        }
        return chain.proceed(request);
    }
}
