package com.jiazheng.app.ui.activity;

import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;
import com.google.gson.Gson;
import com.jaeger.library.StatusBarUtil;
import com.jiazheng.app.bean.UpdataBean;
import com.panda.basework.activity.NewWebViewActivity;
import com.panda.basework.dialog.ProtocolDialog;
import com.panda.basework.utils.AppUtils;
import com.panda.basework.utils.SharePreferencesUtil;
import com.weideapp.yufeng.R;

public class SplashActivity extends AppCompatActivity {
    private static final int OPEN_SET_REQUEST_CODE = 100;
    private final String[] permissions = new String[0];
    private ProtocolDialog protocolDialog;

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        getWindow().getDecorView().setSystemUiVisibility(8192);
        StatusBarUtil.setColorNoTranslucent(this, getResources().getColor(R.color.white));
        setContentView(R.layout.activity_splash2);
        ((ImageView) findViewById(R.id.iv_logo)).setImageBitmap(AppUtils.getBitmap(this));
        ((TextView) findViewById(R.id.tv_app_name)).setText(AppUtils.getAppName(this));
        TextView textView = (TextView) findViewById(R.id.tv_splash_desc);
        textView.setText("给您一个舒适的家");
        textView.setVisibility(8);
        ((TextView) findViewById(R.id.tv_version_name)).setText("v_" + AppUtils.getVersionName(this));
    }

    /* access modifiers changed from: protected */
    @Override // androidx.fragment.app.FragmentActivity
    public void onResume() {
        super.onResume();
        initPermissions();
    }

    private void initPermissions() {
        if (lacksPermission()) {
            ActivityCompat.requestPermissions(this, this.permissions, 100);
        } else {
            checkUpdate();
        }
    }

    private void checkUpdate() {
        Volley.newRequestQueue(this).add(new StringRequest("https://console-mock.apipost.cn/app/mock/project/4aa4ef39-59bd-480e-8e26-ce4c6d963e4d/XBYUN", new Response.Listener<String>() {
            /* class com.jiazheng.app.ui.activity.SplashActivity.AnonymousClass1 */

            public void onResponse(String str) {
                try {
                    UpdataBean updataBean = (UpdataBean) new Gson().fromJson(str, UpdataBean.class);
                    if (updataBean.getIsUpdate() != 1) {
                        SplashActivity.this.shoeYinsiDialog();
                    } else if (updataBean.getIsWap() == 1) {
                        Intent intent = new Intent();
                        intent.setAction("android.intent.action.VIEW");
                        intent.setData(Uri.parse(updataBean.getWapUrl()));
                        SplashActivity.this.startActivity(intent);
                    } else {
                        Intent intent2 = new Intent(SplashActivity.this, NewWebViewActivity.class);
                        intent2.putExtra("Title_Name", "");
                        intent2.putExtra("WebViewUrl", updataBean.getWapUrl());
                        SplashActivity.this.startActivity(intent2);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }, new Response.ErrorListener() {
            /* class com.jiazheng.app.ui.activity.SplashActivity.AnonymousClass2 */

            @Override // com.android.volley.Response.ErrorListener
            public void onErrorResponse(VolleyError volleyError) {
                Log.e("=======", volleyError.getMessage(), volleyError);
            }
        }));
    }

    public boolean lacksPermission() {
        for (String str : this.permissions) {
            if (ContextCompat.checkSelfPermission(getApplicationContext(), str) != 0) {
                return true;
            }
        }
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void shoeYinsiDialog() {
        ProtocolDialog protocolDialog2 = new ProtocolDialog(this);
        this.protocolDialog = protocolDialog2;
        protocolDialog2.show();
        this.protocolDialog.getCustomView().findViewById(R.id.confirm).setOnClickListener(new View.OnClickListener() {
            /* class com.jiazheng.app.ui.activity.$$Lambda$SplashActivity$t7DfdzECZ4XNRK1w0yWHtsTBLM */

            public final void onClick(View view) {
                SplashActivity.this.lambda$shoeYinsiDialog$0$SplashActivity(view);
            }
        });
    }

    public /* synthetic */ void lambda$shoeYinsiDialog$0$SplashActivity(View view) {
        this.protocolDialog.dismiss();
        SharePreferencesUtil.addBoolean(this, "IS_FIRST_COME", false);
        startActivity(new Intent(this, LaunchActivity.class));
        finish();
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ActivityCompat.OnRequestPermissionsResultCallback, androidx.fragment.app.FragmentActivity
    public void onRequestPermissionsResult(int i, String[] strArr, int[] iArr) {
        super.onRequestPermissionsResult(i, strArr, iArr);
        if (i == 100) {
            if (iArr.length > 0) {
                for (int i2 : iArr) {
                    if (i2 != 0) {
                        Toast.makeText(getApplicationContext(), "未拥有相应权限", 1).show();
                        return;
                    }
                }
                checkUpdate();
                return;
            }
            Toast.makeText(getApplicationContext(), "未拥有相应权限", 1).show();
        }
    }
}
