package com.jiazheng.app.ui.base;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import androidx.databinding.DataBindingUtil;
import androidx.databinding.ViewDataBinding;
import androidx.lifecycle.ViewModelProvider;
import com.google.gson.JsonSyntaxException;
import com.jaeger.library.StatusBarUtil;
import com.jiazheng.app.base.BaseViewModel;
import com.jiazheng.app.bean.Resource;
import com.jiazheng.app.ui.activity.LoginActivity;
import com.jiazheng.app.utils.PreferenceUtil;
import com.jiazheng.app.utils.ToastUtils;
import com.jiazheng.app.utils.network.NetWorkUtils;
import com.jiazheng.app.weiget.CustomProgress;
import com.trello.rxlifecycle2.components.support.RxFragmentActivity;
import com.weideapp.yufeng.R;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.net.ConnectException;
import java.net.SocketTimeoutException;
import javax.net.ssl.SSLHandshakeException;
import retrofit2.HttpException;

public abstract class BaseActivity<VM extends BaseViewModel, VDB extends ViewDataBinding> extends RxFragmentActivity {
    protected VDB dataBinding;
    private CustomProgress dialog;
    protected VM mViewModel;

    /* access modifiers changed from: protected */
    public abstract int getContentViewId();

    public Context getContext() {
        return this;
    }

    /* access modifiers changed from: protected */
    public abstract void processLogic();

    /* access modifiers changed from: protected */
    public abstract void setListener();

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.fragment.app.FragmentActivity, com.trello.rxlifecycle2.components.support.RxFragmentActivity
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        getWindow().getDecorView().setSystemUiVisibility(9216);
        VDB vdb = (VDB) DataBindingUtil.setContentView(this, getContentViewId());
        this.dataBinding = vdb;
        vdb.setLifecycleOwner(this);
        createViewModel();
        setListener();
        processLogic();
        StatusBarUtil.setColorNoTranslucent(this, getResources().getColor(R.color.white));
    }

    private void createViewModel() {
        Class<BaseViewModel> cls;
        if (this.mViewModel == null) {
            Type genericSuperclass = getClass().getGenericSuperclass();
            if (genericSuperclass instanceof ParameterizedType) {
                cls = (Class) ((ParameterizedType) genericSuperclass).getActualTypeArguments()[0];
            } else {
                cls = BaseViewModel.class;
            }
            VM vm = (VM) ((BaseViewModel) new ViewModelProvider(this).get(cls));
            this.mViewModel = vm;
            vm.setObjectLifecycleTransformer(bindToLifecycle());
        }
    }

    /* access modifiers changed from: protected */
    public void showDialog() {
        if (this.dialog == null) {
            this.dialog = CustomProgress.show(this, "", true, null);
        }
        if (!this.dialog.isShowing()) {
            this.dialog.show();
        }
    }

    /* access modifiers changed from: protected */
    public void hideDialog() {
        CustomProgress customProgress = this.dialog;
        if (customProgress != null) {
            customProgress.dismiss();
        }
    }

    public abstract class OnCallback<T> implements Resource.OnHandleCallback<T> {
        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onProgress(int i, long j) {
        }

        public OnCallback() {
        }

        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onLoading(String str) {
            if (BaseActivity.this.dialog == null) {
                BaseActivity baseActivity = BaseActivity.this;
                baseActivity.dialog = CustomProgress.show(baseActivity, "", true, null);
            }
            if (!TextUtils.isEmpty(str)) {
                BaseActivity.this.dialog.setMessage(str);
            }
            if (!BaseActivity.this.dialog.isShowing()) {
                BaseActivity.this.dialog.show();
            }
        }

        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onError(Throwable th) {
            if (!NetWorkUtils.isNetworkConnected(BaseActivity.this.getContext())) {
                ToastUtils.showToast(BaseActivity.this.getContext().getResources().getString(R.string.result_network_error));
            } else if (th instanceof ConnectException) {
                ToastUtils.showToast(BaseActivity.this.getContext().getResources().getString(R.string.result_server_error));
            } else if (th instanceof SocketTimeoutException) {
                ToastUtils.showToast(BaseActivity.this.getContext().getResources().getString(R.string.result_server_timeout));
            } else if (th instanceof JsonSyntaxException) {
                ToastUtils.showToast(BaseActivity.this.getContext().getResources().getString(R.string.result_data_json));
            } else if (th instanceof SSLHandshakeException) {
                ToastUtils.showToast(BaseActivity.this.getContext().getResources().getString(R.string.result_verification_failed));
            } else if (!(th instanceof HttpException)) {
                ToastUtils.showToast(BaseActivity.this.getContext().getResources().getString(R.string.result_empty_error));
            } else if (((HttpException) th).code() == 401) {
                BaseActivity.this.exitLogin();
            }
        }

        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onFailure(String str) {
            ToastUtils.showToast(str);
        }

        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onCompleted() {
            if (BaseActivity.this.dialog != null && BaseActivity.this.dialog.isShowing()) {
                BaseActivity.this.dialog.dismiss();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void exitLogin() {
        PreferenceUtil.remove("token");
        PreferenceUtil.remove("mobile");
        Intent intent = new Intent(this, LoginActivity.class);
        intent.addFlags(32768);
        startActivity(intent);
    }
}
