package com.jiazheng.app.ui.base;

import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import androidx.databinding.DataBindingUtil;
import androidx.databinding.ViewDataBinding;
import androidx.lifecycle.ViewModelProvider;
import com.google.gson.JsonSyntaxException;
import com.jiazheng.app.base.BaseViewModel;
import com.jiazheng.app.bean.Resource;
import com.jiazheng.app.ui.activity.LoginActivity;
import com.jiazheng.app.utils.PreferenceUtil;
import com.jiazheng.app.utils.ToastUtils;
import com.jiazheng.app.utils.network.NetWorkUtils;
import com.jiazheng.app.weiget.CustomProgress;
import com.trello.rxlifecycle2.components.support.RxFragment;
import com.weideapp.yufeng.R;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.net.ConnectException;
import java.net.SocketTimeoutException;
import javax.net.ssl.SSLHandshakeException;
import retrofit2.HttpException;

public abstract class BaseFragment<VM extends BaseViewModel, VDB extends ViewDataBinding> extends RxFragment implements View.OnClickListener {
    protected VDB dataBinding;
    private CustomProgress dialog;
    protected View mContentView;
    protected VM mViewModel;

    /* access modifiers changed from: protected */
    public abstract int getContentViewId();

    /* access modifiers changed from: protected */
    public abstract void processLogic(Bundle bundle);

    /* access modifiers changed from: protected */
    public abstract void setListener();

    @Override // androidx.fragment.app.Fragment
    public View onCreateView(LayoutInflater layoutInflater, ViewGroup viewGroup, Bundle bundle) {
        View view = this.mContentView;
        if (view == null) {
            VDB vdb = (VDB) DataBindingUtil.inflate(layoutInflater, getContentViewId(), null, false);
            this.dataBinding = vdb;
            this.mContentView = vdb.getRoot();
            this.dataBinding.setLifecycleOwner(this);
            createViewModel();
            setListener();
            processLogic(bundle);
        } else {
            ViewGroup viewGroup2 = (ViewGroup) view.getParent();
            if (viewGroup2 != null) {
                viewGroup2.removeView(this.mContentView);
            }
        }
        return this.mContentView;
    }

    public void createViewModel() {
        Class<BaseViewModel> cls;
        if (this.mViewModel == null) {
            Type genericSuperclass = getClass().getGenericSuperclass();
            if (genericSuperclass instanceof ParameterizedType) {
                cls = (Class) ((ParameterizedType) genericSuperclass).getActualTypeArguments()[0];
            } else {
                cls = BaseViewModel.class;
            }
            VM vm = (VM) ((BaseViewModel) new ViewModelProvider(this).get(cls));
            this.mViewModel = vm;
            vm.setObjectLifecycleTransformer(bindToLifecycle());
        }
    }

    public abstract class OnCallback<T> implements Resource.OnHandleCallback<T> {
        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onProgress(int i, long j) {
        }

        public OnCallback() {
        }

        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onLoading(String str) {
            if (BaseFragment.this.dialog == null) {
                BaseFragment baseFragment = BaseFragment.this;
                baseFragment.dialog = CustomProgress.show(baseFragment.getActivity(), "", true, null);
            }
            if (!TextUtils.isEmpty(str)) {
                BaseFragment.this.dialog.setMessage(str);
            }
            if (!BaseFragment.this.dialog.isShowing()) {
                BaseFragment.this.dialog.show();
            }
        }

        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onError(Throwable th) {
            if (!NetWorkUtils.isNetworkConnected(BaseFragment.this.getContext())) {
                ToastUtils.showToast(BaseFragment.this.getContext().getResources().getString(R.string.result_network_error));
            } else if (th instanceof ConnectException) {
                ToastUtils.showToast(BaseFragment.this.getContext().getResources().getString(R.string.result_server_error));
            } else if (th instanceof SocketTimeoutException) {
                ToastUtils.showToast(BaseFragment.this.getContext().getResources().getString(R.string.result_server_timeout));
            } else if (th instanceof JsonSyntaxException) {
                ToastUtils.showToast(BaseFragment.this.getContext().getResources().getString(R.string.result_data_json));
            } else if (th instanceof SSLHandshakeException) {
                ToastUtils.showToast(BaseFragment.this.getContext().getResources().getString(R.string.result_verification_failed));
            } else if (!(th instanceof HttpException)) {
                ToastUtils.showToast(BaseFragment.this.getContext().getResources().getString(R.string.result_empty_error));
            } else if (((HttpException) th).code() == 401) {
                BaseFragment.this.exitLogin();
            }
        }

        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onFailure(String str) {
            ToastUtils.showToast(str);
        }

        @Override // com.jiazheng.app.bean.Resource.OnHandleCallback
        public void onCompleted() {
            if (BaseFragment.this.dialog != null && BaseFragment.this.dialog.isShowing()) {
                BaseFragment.this.dialog.dismiss();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void exitLogin() {
        PreferenceUtil.remove("token");
        PreferenceUtil.remove("mobile");
        Intent intent = new Intent(getActivity(), LoginActivity.class);
        intent.addFlags(32768);
        startActivity(intent);
    }
}
