package com.jiazheng.app.utils.network;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import com.jiazheng.app.utils.BaseUtils;
import java.util.ArrayList;
import java.util.List;

public class NetStateChangeReceiver extends BroadcastReceiver {
    private List<NetStateChangeObserver> mObservers = new ArrayList();
    private NetworkType mType = NetWorkUtils.getNetworkType(BaseUtils.getApplication());

    /* access modifiers changed from: private */
    public static class InstanceHolder {
        private static final NetStateChangeReceiver INSTANCE = new NetStateChangeReceiver();

        private InstanceHolder() {
        }
    }

    public void onReceive(Context context, Intent intent) {
        if ("android.net.conn.CONNECTIVITY_CHANGE".equals(intent.getAction())) {
            notifyObservers(NetWorkUtils.getNetworkType(context));
        }
    }

    public static void registerReceiver(Context context) {
        context.registerReceiver(InstanceHolder.INSTANCE, new IntentFilter("android.net.conn.CONNECTIVITY_CHANGE"));
    }

    public static void unRegisterReceiver(Context context) {
        context.unregisterReceiver(InstanceHolder.INSTANCE);
    }

    public static void registerObserver(NetStateChangeObserver netStateChangeObserver) {
        if (netStateChangeObserver != null && !InstanceHolder.INSTANCE.mObservers.contains(netStateChangeObserver)) {
            InstanceHolder.INSTANCE.mObservers.add(netStateChangeObserver);
        }
    }

    public static void unRegisterObserver(NetStateChangeObserver netStateChangeObserver) {
        if (netStateChangeObserver != null && InstanceHolder.INSTANCE.mObservers != null) {
            InstanceHolder.INSTANCE.mObservers.remove(netStateChangeObserver);
        }
    }

    private void notifyObservers(NetworkType networkType) {
        if (this.mType != networkType) {
            this.mType = networkType;
            if (networkType == NetworkType.NETWORK_NO) {
                for (NetStateChangeObserver netStateChangeObserver : this.mObservers) {
                    netStateChangeObserver.onNetDisconnected();
                }
                return;
            }
            for (NetStateChangeObserver netStateChangeObserver2 : this.mObservers) {
                netStateChangeObserver2.onNetConnected(networkType);
            }
        }
    }
}
