package com.jiazheng.db;

import android.database.Cursor;
import android.database.sqlite.SQLiteStatement;
import androidx.core.app.NotificationCompat;
import com.jiazheng.app.dao.AccountInfo;
import org.greenrobot.greendao.AbstractDao;
import org.greenrobot.greendao.Property;
import org.greenrobot.greendao.database.Database;
import org.greenrobot.greendao.database.DatabaseStatement;
import org.greenrobot.greendao.internal.DaoConfig;

public class AccountInfoDao extends AbstractDao<AccountInfo, Long> {
    public static final String TABLENAME = "ACCOUNT_INFO";

    public static class Properties {
        public static final Property Account = new Property(1, String.class, "account", false, "ACCOUNT");
        public static final Property Address = new Property(3, String.class, "address", false, "ADDRESS");
        public static final Property Address2 = new Property(4, String.class, "address2", false, "ADDRESS2");
        public static final Property Id = new Property(0, Long.class, "id", true, "_id");
        public static final Property Name = new Property(5, String.class, "name", false, "NAME");
        public static final Property Phone = new Property(6, String.class, "phone", false, "PHONE");
        public static final Property Pwd = new Property(2, String.class, "pwd", false, "PWD");
        public static final Property Score = new Property(7, String.class, "score", false, "SCORE");
        public static final Property Status = new Property(8, Integer.TYPE, NotificationCompat.CATEGORY_STATUS, false, "STATUS");
    }

    /* access modifiers changed from: protected */
    @Override // org.greenrobot.greendao.AbstractDao
    public final boolean isEntityUpdateable() {
        return true;
    }

    public AccountInfoDao(DaoConfig daoConfig) {
        super(daoConfig);
    }

    public AccountInfoDao(DaoConfig daoConfig, DaoSession daoSession) {
        super(daoConfig, daoSession);
    }

    public static void createTable(Database database, boolean z) {
        String str = z ? "IF NOT EXISTS " : "";
        database.execSQL("CREATE TABLE " + str + "\"ACCOUNT_INFO\" (\"_id\" INTEGER PRIMARY KEY AUTOINCREMENT ,\"ACCOUNT\" TEXT,\"PWD\" TEXT,\"ADDRESS\" TEXT,\"ADDRESS2\" TEXT,\"NAME\" TEXT,\"PHONE\" TEXT,\"SCORE\" TEXT,\"STATUS\" INTEGER NOT NULL );");
        database.execSQL("CREATE UNIQUE INDEX " + str + "IDX_ACCOUNT_INFO_ACCOUNT ON \"ACCOUNT_INFO\" (\"ACCOUNT\" ASC);");
    }

    public static void dropTable(Database database, boolean z) {
        StringBuilder sb = new StringBuilder();
        sb.append("DROP TABLE ");
        sb.append(z ? "IF EXISTS " : "");
        sb.append("\"ACCOUNT_INFO\"");
        database.execSQL(sb.toString());
    }

    /* access modifiers changed from: protected */
    public final void bindValues(DatabaseStatement databaseStatement, AccountInfo accountInfo) {
        databaseStatement.clearBindings();
        Long id = accountInfo.getId();
        if (id != null) {
            databaseStatement.bindLong(1, id.longValue());
        }
        String account = accountInfo.getAccount();
        if (account != null) {
            databaseStatement.bindString(2, account);
        }
        String pwd = accountInfo.getPwd();
        if (pwd != null) {
            databaseStatement.bindString(3, pwd);
        }
        String address = accountInfo.getAddress();
        if (address != null) {
            databaseStatement.bindString(4, address);
        }
        String address2 = accountInfo.getAddress2();
        if (address2 != null) {
            databaseStatement.bindString(5, address2);
        }
        String name = accountInfo.getName();
        if (name != null) {
            databaseStatement.bindString(6, name);
        }
        String phone = accountInfo.getPhone();
        if (phone != null) {
            databaseStatement.bindString(7, phone);
        }
        String score = accountInfo.getScore();
        if (score != null) {
            databaseStatement.bindString(8, score);
        }
        databaseStatement.bindLong(9, (long) accountInfo.getStatus());
    }

    /* access modifiers changed from: protected */
    public final void bindValues(SQLiteStatement sQLiteStatement, AccountInfo accountInfo) {
        sQLiteStatement.clearBindings();
        Long id = accountInfo.getId();
        if (id != null) {
            sQLiteStatement.bindLong(1, id.longValue());
        }
        String account = accountInfo.getAccount();
        if (account != null) {
            sQLiteStatement.bindString(2, account);
        }
        String pwd = accountInfo.getPwd();
        if (pwd != null) {
            sQLiteStatement.bindString(3, pwd);
        }
        String address = accountInfo.getAddress();
        if (address != null) {
            sQLiteStatement.bindString(4, address);
        }
        String address2 = accountInfo.getAddress2();
        if (address2 != null) {
            sQLiteStatement.bindString(5, address2);
        }
        String name = accountInfo.getName();
        if (name != null) {
            sQLiteStatement.bindString(6, name);
        }
        String phone = accountInfo.getPhone();
        if (phone != null) {
            sQLiteStatement.bindString(7, phone);
        }
        String score = accountInfo.getScore();
        if (score != null) {
            sQLiteStatement.bindString(8, score);
        }
        sQLiteStatement.bindLong(9, (long) accountInfo.getStatus());
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public Long readKey(Cursor cursor, int i) {
        int i2 = i + 0;
        if (cursor.isNull(i2)) {
            return null;
        }
        return Long.valueOf(cursor.getLong(i2));
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public AccountInfo readEntity(Cursor cursor, int i) {
        int i2 = i + 0;
        Long valueOf = cursor.isNull(i2) ? null : Long.valueOf(cursor.getLong(i2));
        int i3 = i + 1;
        String string = cursor.isNull(i3) ? null : cursor.getString(i3);
        int i4 = i + 2;
        String string2 = cursor.isNull(i4) ? null : cursor.getString(i4);
        int i5 = i + 3;
        String string3 = cursor.isNull(i5) ? null : cursor.getString(i5);
        int i6 = i + 4;
        String string4 = cursor.isNull(i6) ? null : cursor.getString(i6);
        int i7 = i + 5;
        String string5 = cursor.isNull(i7) ? null : cursor.getString(i7);
        int i8 = i + 6;
        String string6 = cursor.isNull(i8) ? null : cursor.getString(i8);
        int i9 = i + 7;
        return new AccountInfo(valueOf, string, string2, string3, string4, string5, string6, cursor.isNull(i9) ? null : cursor.getString(i9), cursor.getInt(i + 8));
    }

    public void readEntity(Cursor cursor, AccountInfo accountInfo, int i) {
        int i2 = i + 0;
        String str = null;
        accountInfo.setId(cursor.isNull(i2) ? null : Long.valueOf(cursor.getLong(i2)));
        int i3 = i + 1;
        accountInfo.setAccount(cursor.isNull(i3) ? null : cursor.getString(i3));
        int i4 = i + 2;
        accountInfo.setPwd(cursor.isNull(i4) ? null : cursor.getString(i4));
        int i5 = i + 3;
        accountInfo.setAddress(cursor.isNull(i5) ? null : cursor.getString(i5));
        int i6 = i + 4;
        accountInfo.setAddress2(cursor.isNull(i6) ? null : cursor.getString(i6));
        int i7 = i + 5;
        accountInfo.setName(cursor.isNull(i7) ? null : cursor.getString(i7));
        int i8 = i + 6;
        accountInfo.setPhone(cursor.isNull(i8) ? null : cursor.getString(i8));
        int i9 = i + 7;
        if (!cursor.isNull(i9)) {
            str = cursor.getString(i9);
        }
        accountInfo.setScore(str);
        accountInfo.setStatus(cursor.getInt(i + 8));
    }

    /* access modifiers changed from: protected */
    public final Long updateKeyAfterInsert(AccountInfo accountInfo, long j) {
        accountInfo.setId(Long.valueOf(j));
        return Long.valueOf(j);
    }

    public Long getKey(AccountInfo accountInfo) {
        if (accountInfo != null) {
            return accountInfo.getId();
        }
        return null;
    }

    public boolean hasKey(AccountInfo accountInfo) {
        return accountInfo.getId() != null;
    }
}
