package com.jiazheng.db;

import android.database.Cursor;
import android.database.sqlite.SQLiteStatement;
import androidx.core.app.NotificationCompat;
import com.jiazheng.app.dao.OrderInfo;
import org.greenrobot.greendao.AbstractDao;
import org.greenrobot.greendao.Property;
import org.greenrobot.greendao.database.Database;
import org.greenrobot.greendao.database.DatabaseStatement;
import org.greenrobot.greendao.internal.DaoConfig;

public class OrderInfoDao extends AbstractDao<OrderInfo, Long> {
    public static final String TABLENAME = "ORDER_INFO";

    public static class Properties {
        public static final Property Account = new Property(13, String.class, "account", false, "ACCOUNT");
        public static final Property Address = new Property(4, String.class, "address", false, "ADDRESS");
        public static final Property GetScore = new Property(8, String.class, "getScore", false, "GET_SCORE");
        public static final Property Id = new Property(0, Long.class, "id", true, "_id");
        public static final Property Name = new Property(5, String.class, "name", false, "NAME");
        public static final Property Number = new Property(11, String.class, "number", false, "NUMBER");
        public static final Property OrderId = new Property(1, String.class, "orderId", false, "ORDER_ID");
        public static final Property OrderStatus = new Property(3, String.class, "orderStatus", false, "ORDER_STATUS");
        public static final Property Phone = new Property(6, String.class, "phone", false, "PHONE");
        public static final Property QTime = new Property(10, String.class, "qTime", false, "Q_TIME");
        public static final Property RecycleType = new Property(2, String.class, "recycleType", false, "RECYCLE_TYPE");
        public static final Property Remark = new Property(7, String.class, "remark", false, "REMARK");
        public static final Property STime = new Property(9, String.class, "sTime", false, "S_TIME");
        public static final Property Status = new Property(12, String.class, NotificationCompat.CATEGORY_STATUS, false, "STATUS");
    }

    /* access modifiers changed from: protected */
    @Override // org.greenrobot.greendao.AbstractDao
    public final boolean isEntityUpdateable() {
        return true;
    }

    public OrderInfoDao(DaoConfig daoConfig) {
        super(daoConfig);
    }

    public OrderInfoDao(DaoConfig daoConfig, DaoSession daoSession) {
        super(daoConfig, daoSession);
    }

    public static void createTable(Database database, boolean z) {
        String str = z ? "IF NOT EXISTS " : "";
        database.execSQL("CREATE TABLE " + str + "\"ORDER_INFO\" (\"_id\" INTEGER PRIMARY KEY AUTOINCREMENT ,\"ORDER_ID\" TEXT,\"RECYCLE_TYPE\" TEXT,\"ORDER_STATUS\" TEXT,\"ADDRESS\" TEXT,\"NAME\" TEXT,\"PHONE\" TEXT,\"REMARK\" TEXT,\"GET_SCORE\" TEXT,\"S_TIME\" TEXT,\"Q_TIME\" TEXT,\"NUMBER\" TEXT,\"STATUS\" TEXT,\"ACCOUNT\" TEXT);");
        database.execSQL("CREATE UNIQUE INDEX " + str + "IDX_ORDER_INFO_ORDER_ID ON \"ORDER_INFO\" (\"ORDER_ID\" ASC);");
    }

    public static void dropTable(Database database, boolean z) {
        StringBuilder sb = new StringBuilder();
        sb.append("DROP TABLE ");
        sb.append(z ? "IF EXISTS " : "");
        sb.append("\"ORDER_INFO\"");
        database.execSQL(sb.toString());
    }

    /* access modifiers changed from: protected */
    public final void bindValues(DatabaseStatement databaseStatement, OrderInfo orderInfo) {
        databaseStatement.clearBindings();
        Long id = orderInfo.getId();
        if (id != null) {
            databaseStatement.bindLong(1, id.longValue());
        }
        String orderId = orderInfo.getOrderId();
        if (orderId != null) {
            databaseStatement.bindString(2, orderId);
        }
        String recycleType = orderInfo.getRecycleType();
        if (recycleType != null) {
            databaseStatement.bindString(3, recycleType);
        }
        String orderStatus = orderInfo.getOrderStatus();
        if (orderStatus != null) {
            databaseStatement.bindString(4, orderStatus);
        }
        String address = orderInfo.getAddress();
        if (address != null) {
            databaseStatement.bindString(5, address);
        }
        String name = orderInfo.getName();
        if (name != null) {
            databaseStatement.bindString(6, name);
        }
        String phone = orderInfo.getPhone();
        if (phone != null) {
            databaseStatement.bindString(7, phone);
        }
        String remark = orderInfo.getRemark();
        if (remark != null) {
            databaseStatement.bindString(8, remark);
        }
        String getScore = orderInfo.getGetScore();
        if (getScore != null) {
            databaseStatement.bindString(9, getScore);
        }
        String sTime = orderInfo.getSTime();
        if (sTime != null) {
            databaseStatement.bindString(10, sTime);
        }
        String qTime = orderInfo.getQTime();
        if (qTime != null) {
            databaseStatement.bindString(11, qTime);
        }
        String number = orderInfo.getNumber();
        if (number != null) {
            databaseStatement.bindString(12, number);
        }
        String status = orderInfo.getStatus();
        if (status != null) {
            databaseStatement.bindString(13, status);
        }
        String account = orderInfo.getAccount();
        if (account != null) {
            databaseStatement.bindString(14, account);
        }
    }

    /* access modifiers changed from: protected */
    public final void bindValues(SQLiteStatement sQLiteStatement, OrderInfo orderInfo) {
        sQLiteStatement.clearBindings();
        Long id = orderInfo.getId();
        if (id != null) {
            sQLiteStatement.bindLong(1, id.longValue());
        }
        String orderId = orderInfo.getOrderId();
        if (orderId != null) {
            sQLiteStatement.bindString(2, orderId);
        }
        String recycleType = orderInfo.getRecycleType();
        if (recycleType != null) {
            sQLiteStatement.bindString(3, recycleType);
        }
        String orderStatus = orderInfo.getOrderStatus();
        if (orderStatus != null) {
            sQLiteStatement.bindString(4, orderStatus);
        }
        String address = orderInfo.getAddress();
        if (address != null) {
            sQLiteStatement.bindString(5, address);
        }
        String name = orderInfo.getName();
        if (name != null) {
            sQLiteStatement.bindString(6, name);
        }
        String phone = orderInfo.getPhone();
        if (phone != null) {
            sQLiteStatement.bindString(7, phone);
        }
        String remark = orderInfo.getRemark();
        if (remark != null) {
            sQLiteStatement.bindString(8, remark);
        }
        String getScore = orderInfo.getGetScore();
        if (getScore != null) {
            sQLiteStatement.bindString(9, getScore);
        }
        String sTime = orderInfo.getSTime();
        if (sTime != null) {
            sQLiteStatement.bindString(10, sTime);
        }
        String qTime = orderInfo.getQTime();
        if (qTime != null) {
            sQLiteStatement.bindString(11, qTime);
        }
        String number = orderInfo.getNumber();
        if (number != null) {
            sQLiteStatement.bindString(12, number);
        }
        String status = orderInfo.getStatus();
        if (status != null) {
            sQLiteStatement.bindString(13, status);
        }
        String account = orderInfo.getAccount();
        if (account != null) {
            sQLiteStatement.bindString(14, account);
        }
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public Long readKey(Cursor cursor, int i) {
        int i2 = i + 0;
        if (cursor.isNull(i2)) {
            return null;
        }
        return Long.valueOf(cursor.getLong(i2));
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public OrderInfo readEntity(Cursor cursor, int i) {
        int i2 = i + 0;
        int i3 = i + 1;
        int i4 = i + 2;
        int i5 = i + 3;
        int i6 = i + 4;
        int i7 = i + 5;
        int i8 = i + 6;
        int i9 = i + 7;
        int i10 = i + 8;
        int i11 = i + 9;
        int i12 = i + 10;
        int i13 = i + 11;
        int i14 = i + 12;
        int i15 = i + 13;
        return new OrderInfo(cursor.isNull(i2) ? null : Long.valueOf(cursor.getLong(i2)), cursor.isNull(i3) ? null : cursor.getString(i3), cursor.isNull(i4) ? null : cursor.getString(i4), cursor.isNull(i5) ? null : cursor.getString(i5), cursor.isNull(i6) ? null : cursor.getString(i6), cursor.isNull(i7) ? null : cursor.getString(i7), cursor.isNull(i8) ? null : cursor.getString(i8), cursor.isNull(i9) ? null : cursor.getString(i9), cursor.isNull(i10) ? null : cursor.getString(i10), cursor.isNull(i11) ? null : cursor.getString(i11), cursor.isNull(i12) ? null : cursor.getString(i12), cursor.isNull(i13) ? null : cursor.getString(i13), cursor.isNull(i14) ? null : cursor.getString(i14), cursor.isNull(i15) ? null : cursor.getString(i15));
    }

    public void readEntity(Cursor cursor, OrderInfo orderInfo, int i) {
        int i2 = i + 0;
        String str = null;
        orderInfo.setId(cursor.isNull(i2) ? null : Long.valueOf(cursor.getLong(i2)));
        int i3 = i + 1;
        orderInfo.setOrderId(cursor.isNull(i3) ? null : cursor.getString(i3));
        int i4 = i + 2;
        orderInfo.setRecycleType(cursor.isNull(i4) ? null : cursor.getString(i4));
        int i5 = i + 3;
        orderInfo.setOrderStatus(cursor.isNull(i5) ? null : cursor.getString(i5));
        int i6 = i + 4;
        orderInfo.setAddress(cursor.isNull(i6) ? null : cursor.getString(i6));
        int i7 = i + 5;
        orderInfo.setName(cursor.isNull(i7) ? null : cursor.getString(i7));
        int i8 = i + 6;
        orderInfo.setPhone(cursor.isNull(i8) ? null : cursor.getString(i8));
        int i9 = i + 7;
        orderInfo.setRemark(cursor.isNull(i9) ? null : cursor.getString(i9));
        int i10 = i + 8;
        orderInfo.setGetScore(cursor.isNull(i10) ? null : cursor.getString(i10));
        int i11 = i + 9;
        orderInfo.setSTime(cursor.isNull(i11) ? null : cursor.getString(i11));
        int i12 = i + 10;
        orderInfo.setQTime(cursor.isNull(i12) ? null : cursor.getString(i12));
        int i13 = i + 11;
        orderInfo.setNumber(cursor.isNull(i13) ? null : cursor.getString(i13));
        int i14 = i + 12;
        orderInfo.setStatus(cursor.isNull(i14) ? null : cursor.getString(i14));
        int i15 = i + 13;
        if (!cursor.isNull(i15)) {
            str = cursor.getString(i15);
        }
        orderInfo.setAccount(str);
    }

    /* access modifiers changed from: protected */
    public final Long updateKeyAfterInsert(OrderInfo orderInfo, long j) {
        orderInfo.setId(Long.valueOf(j));
        return Long.valueOf(j);
    }

    public Long getKey(OrderInfo orderInfo) {
        if (orderInfo != null) {
            return orderInfo.getId();
        }
        return null;
    }

    public boolean hasKey(OrderInfo orderInfo) {
        return orderInfo.getId() != null;
    }
}
