package com.panda.basework.dialog;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.os.Build;
import android.os.Bundle;
import android.os.Process;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.Stack;

public class AppManager {
    private static int actAccount = 0;
    private static final ActivityLifecycleImpl activityLifecycle = new ActivityLifecycleImpl();
    private static Stack<Activity> activityStack = null;
    private static Activity currentActivity = null;
    private static AppManager instance = null;
    private static boolean isForeground = false;
    private static boolean isInit = false;
    private static Application sApplication;
    private final List<OnAppStatusChangedListener> mStatusListeners = new ArrayList();

    public interface OnActivityOnDestroyListener {
        void onActivityDestroyed(Activity activity);
    }

    public interface OnAppStatusChangedListener {
        void onBackground(Activity activity);

        void onForeground(Activity activity);
    }

    static /* synthetic */ int access$108() {
        int i = actAccount;
        actAccount = i + 1;
        return i;
    }

    static /* synthetic */ int access$110() {
        int i = actAccount;
        actAccount = i - 1;
        return i;
    }

    private AppManager(Application application) {
        if (application != null) {
            sApplication = application;
            application.registerActivityLifecycleCallbacks(activityLifecycle);
            return;
        }
        throw new UnsupportedOperationException("u can't instantiate me...");
    }

    public static AppManager init(Application application) {
        if (instance == null) {
            instance = new AppManager(application);
        }
        isInit = true;
        return instance;
    }

    public static Application getsApplication() {
        Application application = sApplication;
        if (application != null) {
            return application;
        }
        throw new IllegalArgumentException("Application is null");
    }

    public static AppManager getInstance() {
        if (isInit) {
            return instance;
        }
        throw new IllegalArgumentException("AppManage class not init");
    }

    private static Stack<Activity> getActivityStack() {
        return activityStack;
    }

    public static void addActivity(Activity activity) {
        if (activityStack == null) {
            activityStack = new Stack<>();
        }
        activityStack.add(activity);
    }

    public static void removeActivity(Activity activity) {
        if (activity != null) {
            activityStack.remove(activity);
        }
    }

    public static boolean isActivity() {
        Stack<Activity> stack = activityStack;
        if (stack != null) {
            return !stack.isEmpty();
        }
        return false;
    }

    public static Activity currentActivity() {
        return currentActivity;
    }

    public static void finishActivity() {
        finishActivity(activityStack.lastElement());
    }

    public static void finishActivity(Activity activity) {
        if (activity != null && !activity.isFinishing()) {
            activity.finish();
        }
    }

    public static void finishActivity(Class<?> cls) {
        Iterator<Activity> it = activityStack.iterator();
        while (it.hasNext()) {
            Activity next = it.next();
            if (next.getClass().equals(cls)) {
                finishActivity(next);
            }
        }
    }

    public static void finishAllActivity() {
        int size = activityStack.size();
        for (int i = 0; i < size; i++) {
            if (activityStack.get(i) != null) {
                finishActivity(activityStack.get(i));
            }
        }
        activityStack.clear();
    }

    public static Activity getActivity(Class<?> cls) {
        Stack<Activity> stack = activityStack;
        if (stack == null) {
            return null;
        }
        Iterator<Activity> it = stack.iterator();
        while (it.hasNext()) {
            Activity next = it.next();
            if (next.getClass().equals(cls)) {
                return next;
            }
        }
        return null;
    }

    public void cleanOther(Class<?> cls) {
        Stack<Activity> stack = activityStack;
        if (stack != null) {
            Iterator<Activity> it = stack.iterator();
            while (it.hasNext()) {
                Activity next = it.next();
                if (!next.getClass().equals(cls)) {
                    next.finish();
                }
            }
        }
    }

    public static boolean isAppForeground() {
        return actAccount != 0;
    }

    public static ActivityLifecycleImpl getActivityLifecycle() {
        return activityLifecycle;
    }

    public static Context getTopActivityOrApp() {
        if (!isAppForeground()) {
            return getsApplication();
        }
        Activity currentActivity2 = currentActivity();
        return currentActivity2 == null ? getsApplication() : currentActivity2;
    }

    public void addOnAppStatusChangedListener(OnAppStatusChangedListener onAppStatusChangedListener) {
        this.mStatusListeners.add(onAppStatusChangedListener);
    }

    public void removeOnAppStatusChangedListener(OnAppStatusChangedListener onAppStatusChangedListener) {
        this.mStatusListeners.remove(onAppStatusChangedListener);
    }

    public static class ActivityLifecycleImpl implements Application.ActivityLifecycleCallbacks {
        final Map<Activity, Set<OnActivityOnDestroyListener>> mDestroyedListenerMap = new HashMap();

        public void onActivityPaused(Activity activity) {
        }

        public void onActivitySaveInstanceState(Activity activity, Bundle bundle) {
        }

        public void onActivityCreated(Activity activity, Bundle bundle) {
            AppManager.addActivity(activity);
        }

        public void onActivityStarted(Activity activity) {
            Activity unused = AppManager.currentActivity = activity;
            if (AppManager.actAccount == 0) {
                postStatus(activity, true);
                boolean unused2 = AppManager.isForeground = true;
            }
            AppManager.access$108();
        }

        public void onActivityResumed(Activity activity) {
            Activity unused = AppManager.currentActivity = activity;
        }

        public void onActivityStopped(Activity activity) {
            AppManager.access$110();
            if (AppManager.actAccount == 0) {
                postStatus(activity, false);
                boolean unused = AppManager.isForeground = false;
            }
        }

        public void onActivityDestroyed(Activity activity) {
            consumeOnActivityDestroyedListener(activity);
            AppManager.removeActivity(activity);
        }

        public void consumeOnActivityDestroyedListener(Activity activity) {
            for (Map.Entry<Activity, Set<OnActivityOnDestroyListener>> entry : this.mDestroyedListenerMap.entrySet()) {
                if (entry.getKey() == activity) {
                    for (OnActivityOnDestroyListener onActivityOnDestroyListener : entry.getValue()) {
                        onActivityOnDestroyListener.onActivityDestroyed(activity);
                    }
                }
            }
        }

        private void postStatus(Activity activity, boolean z) {
            if (!AppManager.instance.mStatusListeners.isEmpty()) {
                for (OnAppStatusChangedListener onAppStatusChangedListener : AppManager.instance.mStatusListeners) {
                    if (z) {
                        onAppStatusChangedListener.onForeground(activity);
                    } else {
                        onAppStatusChangedListener.onBackground(activity);
                    }
                }
            }
        }

        public void addOnActivityDestroyedListener(Activity activity, OnActivityOnDestroyListener onActivityOnDestroyListener) {
            Set<OnActivityOnDestroyListener> set;
            if (activity != null && onActivityOnDestroyListener != null) {
                if (!this.mDestroyedListenerMap.containsKey(activity)) {
                    set = new HashSet<>();
                    this.mDestroyedListenerMap.put(activity, set);
                } else {
                    set = this.mDestroyedListenerMap.get(activity);
                    if (set.contains(onActivityOnDestroyListener)) {
                        return;
                    }
                }
                set.add(onActivityOnDestroyListener);
            }
        }

        public void removeOnActivityDestroyedListener(Activity activity) {
            if (activity != null) {
                this.mDestroyedListenerMap.remove(activity);
            }
        }
    }

    public static void AppExit() {
        try {
            finishAllActivity();
            Process.killProcess(Process.myPid());
        } catch (Exception e) {
            activityStack.clear();
            e.printStackTrace();
        }
    }

    public static boolean getIsForeground() {
        return isForeground;
    }

    public static boolean isDestroy(Activity activity) {
        if (activity == null || activity.isFinishing()) {
            return true;
        }
        return Build.VERSION.SDK_INT >= 17 && activity.isDestroyed();
    }
}
