package com.panda.basework.dialog;

import android.app.Activity;
import android.app.Dialog;
import android.graphics.Rect;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import com.panda.basework.R;
import com.panda.basework.utils.PixelUtil;

public abstract class BaseDialog extends Dialog implements IBaseDialog {
    private Activity activity;
    private View customView;
    public boolean isShow;
    private View rootView;

    public int getAnimStyle() {
        return 0;
    }

    /* access modifiers changed from: protected */
    public abstract String getDialogName();

    @Override // com.panda.basework.dialog.IBaseDialog
    public boolean isCancel() {
        return true;
    }

    @Override // com.panda.basework.dialog.IBaseDialog
    public boolean isCancelOutside() {
        return true;
    }

    @Override // com.panda.basework.dialog.IBaseDialog
    public boolean isFullScreen() {
        return false;
    }

    public BaseDialog(Activity activity2) {
        this(activity2, R.style.dialog_base);
    }

    public BaseDialog(Activity activity2, int i) {
        super(activity2, i);
        this.activity = activity2;
    }

    /* access modifiers changed from: protected */
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        init();
        initView();
        setContentView(this.rootView);
    }

    public void init() {
        int i;
        int i2;
        setOwnerActivity(this.activity);
        setCanceledOnTouchOutside(isCancelOutside());
        setCancelable(isCancel());
        View inflate = LayoutInflater.from(this.activity).inflate(initLayout(), (ViewGroup) null, false);
        this.rootView = inflate;
        ViewGroup viewGroup = (ViewGroup) inflate.findViewById(R.id.custom_view);
        ViewGroup viewGroup2 = (ViewGroup) this.rootView.findViewById(R.id.full_screen_layout);
        ViewGroup viewGroup3 = (ViewGroup) this.rootView.findViewById(R.id.normal_layout);
        if (getCustomLayout() != -1) {
            viewGroup3.setVisibility(8);
            viewGroup.setVisibility(8);
            viewGroup2.setVisibility(8);
            viewGroup.removeAllViews();
            viewGroup2.removeAllViews();
            this.customView = LayoutInflater.from(this.activity).inflate(getCustomLayout(), (ViewGroup) null, false);
            if (isFullScreen()) {
                viewGroup2.addView(this.customView, 0);
                viewGroup2.setVisibility(0);
            } else {
                viewGroup.addView(this.customView, 0);
                viewGroup.setVisibility(0);
            }
        }
        WindowManager.LayoutParams attributes = getWindow().getAttributes();
        if (getAnimStyle() != 0) {
            getWindow().setWindowAnimations(getAnimStyle());
        } else {
            getWindow().setWindowAnimations(R.style.nullStyle);
        }
        DisplayMetrics displayMetrics = new DisplayMetrics();
        this.activity.getWindowManager().getDefaultDisplay().getMetrics(displayMetrics);
        getWindow().findViewById(16908290).getTop();
        this.activity.getWindow().getDecorView().getWindowVisibleDisplayFrame(new Rect());
        if (!isFullScreen()) {
            this.rootView.measure(View.MeasureSpec.makeMeasureSpec(0, 0), View.MeasureSpec.makeMeasureSpec(0, 0));
            i = this.rootView.getMeasuredHeight();
            i2 = displayMetrics.widthPixels - PixelUtil.dip2px(50.0f);
        } else {
            i = displayMetrics.heightPixels;
            i2 = displayMetrics.widthPixels;
        }
        attributes.height = i;
        attributes.width = i2;
    }

    public void dismiss() {
        try {
            super.dismiss();
            this.isShow = false;
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: protected */
    public void onStart() {
        super.onStart();
    }

    /* access modifiers changed from: protected */
    public void onStop() {
        super.onStop();
    }

    public void show() {
        Activity activity2 = this.activity;
        if (activity2 == null || !activity2.isFinishing()) {
            try {
                super.show();
                this.isShow = true;
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public boolean dispatchKeyEvent(KeyEvent keyEvent) {
        return super.dispatchKeyEvent(keyEvent);
    }

    public void hideKeyboard() {
        View currentFocus = getCurrentFocus();
        if (currentFocus != null && getOwnerActivity() != null) {
            ((InputMethodManager) getOwnerActivity().getSystemService("input_method")).hideSoftInputFromWindow(currentFocus.getWindowToken(), 0);
        }
    }

    public View getRootView() {
        return this.rootView;
    }

    @Override // android.app.Dialog
    public <T extends View> T findViewById(int i) {
        return (T) this.rootView.findViewById(i);
    }

    public View getCustomView() {
        return this.customView;
    }

    @Override // com.panda.basework.dialog.IBaseDialog
    public int initLayout() {
        return R.layout.dialog_common_layout;
    }
}
