package cn.leancloud.cache;

import cn.leancloud.AVLogger;
import cn.leancloud.utils.LogUtil;
import java.io.BufferedInputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import java.util.concurrent.locks.ReentrantReadWriteLock;

public class PersistenceUtil {
    private static PersistenceUtil INSTANCE = new PersistenceUtil();
    public static final int MAX_FILE_BUF_SIZE = 2097152;
    private static final AVLogger gLogger = LogUtil.getLogger(PersistenceUtil.class);
    private ConcurrentMap<String, ReentrantReadWriteLock> fileLocks = new ConcurrentHashMap();

    private PersistenceUtil() {
    }

    public static PersistenceUtil sharedInstance() {
        return INSTANCE;
    }

    public ReentrantReadWriteLock getLock(String str) {
        ReentrantReadWriteLock reentrantReadWriteLock = this.fileLocks.get(str);
        if (reentrantReadWriteLock != null) {
            return reentrantReadWriteLock;
        }
        ReentrantReadWriteLock reentrantReadWriteLock2 = new ReentrantReadWriteLock();
        ReentrantReadWriteLock putIfAbsent = this.fileLocks.putIfAbsent(str, reentrantReadWriteLock2);
        return putIfAbsent != null ? putIfAbsent : reentrantReadWriteLock2;
    }

    public void removeLock(String str) {
        this.fileLocks.remove(str);
    }

    static void closeQuietly(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException unused) {
            }
        }
    }

    public boolean saveContentToFile(String str, File file) {
        if (file == null) {
            return false;
        }
        try {
            return saveContentToFile(str.getBytes("utf-8"), file);
        } catch (UnsupportedEncodingException unused) {
            return false;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x0061  */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x0083  */
    public boolean saveContentToFile(byte[] bArr, File file) {
        Throwable th;
        ReentrantReadWriteLock.WriteLock writeLock = getLock(file.getAbsolutePath()).writeLock();
        if (writeLock.tryLock()) {
            AVLogger aVLogger = gLogger;
            aVLogger.d("obtained writeLock for file: " + file.getAbsolutePath());
            FileOutputStream fileOutputStream = null;
            try {
                FileOutputStream fileOutputStream2 = new FileOutputStream(file, false);
                try {
                    fileOutputStream2.write(bArr);
                    fileOutputStream2.flush();
                    closeQuietly(fileOutputStream2);
                    writeLock.unlock();
                    aVLogger.d("release writeLock for file: " + file.getAbsolutePath());
                    return true;
                } catch (Exception unused) {
                    fileOutputStream = fileOutputStream2;
                    if (fileOutputStream != null) {
                        closeQuietly(fileOutputStream);
                    }
                    writeLock.unlock();
                    AVLogger aVLogger2 = gLogger;
                    aVLogger2.d("release writeLock for file: " + file.getAbsolutePath());
                    return false;
                } catch (Throwable th2) {
                    th = th2;
                    fileOutputStream = fileOutputStream2;
                    if (fileOutputStream != null) {
                        closeQuietly(fileOutputStream);
                    }
                    writeLock.unlock();
                    AVLogger aVLogger3 = gLogger;
                    aVLogger3.d("release writeLock for file: " + file.getAbsolutePath());
                    throw th;
                }
            } catch (Exception unused2) {
                if (fileOutputStream != null) {
                }
                writeLock.unlock();
                AVLogger aVLogger22 = gLogger;
                aVLogger22.d("release writeLock for file: " + file.getAbsolutePath());
                return false;
            } catch (Throwable th3) {
                th = th3;
                if (fileOutputStream != null) {
                }
                writeLock.unlock();
                AVLogger aVLogger32 = gLogger;
                aVLogger32.d("release writeLock for file: " + file.getAbsolutePath());
                throw th;
            }
        } else {
            AVLogger aVLogger4 = gLogger;
            aVLogger4.w("failed to lock writeLocker, skip save content to file:" + file.getAbsolutePath());
            return true;
        }
    }

    public String readContentFromFile(File file) {
        byte[] readContentBytesFromFile = readContentBytesFromFile(file);
        return (readContentBytesFromFile == null || readContentBytesFromFile.length < 1) ? "" : new String(readContentBytesFromFile);
    }

    public byte[] readContentBytesFromFile(File file) {
        BufferedInputStream bufferedInputStream;
        Throwable th;
        IOException e;
        if (file == null || !file.exists() || !file.isFile()) {
            return null;
        }
        ReentrantReadWriteLock.ReadLock readLock = getLock(file.getAbsolutePath()).readLock();
        if (readLock.tryLock()) {
            gLogger.d("obtained read lock for file: " + file.getAbsolutePath());
            try {
                int length = (int) file.length();
                byte[] bArr = new byte[length];
                bufferedInputStream = new BufferedInputStream(new FileInputStream(file), 8192);
                int i = 0;
                while (i < length) {
                    try {
                        int read = bufferedInputStream.read(bArr, i, length - i);
                        if (read > 0) {
                            i += read;
                        }
                    } catch (IOException e2) {
                        e = e2;
                        try {
                            AVLogger aVLogger = gLogger;
                            aVLogger.w(e);
                            closeQuietly(bufferedInputStream);
                            readLock.unlock();
                            aVLogger.d("release read lock for file: " + file.getAbsolutePath());
                            return new byte[0];
                        } catch (Throwable th2) {
                            th = th2;
                            closeQuietly(bufferedInputStream);
                            readLock.unlock();
                            gLogger.d("release read lock for file: " + file.getAbsolutePath());
                            throw th;
                        }
                    }
                }
                closeQuietly(bufferedInputStream);
                readLock.unlock();
                gLogger.d("release read lock for file: " + file.getAbsolutePath());
                return bArr;
            } catch (IOException e3) {
                bufferedInputStream = null;
                e = e3;
                AVLogger aVLogger2 = gLogger;
                aVLogger2.w(e);
                closeQuietly(bufferedInputStream);
                readLock.unlock();
                aVLogger2.d("release read lock for file: " + file.getAbsolutePath());
                return new byte[0];
            } catch (Throwable th3) {
                bufferedInputStream = null;
                th = th3;
                closeQuietly(bufferedInputStream);
                readLock.unlock();
                gLogger.d("release read lock for file: " + file.getAbsolutePath());
                throw th;
            }
        } else {
            gLogger.w("failed to lock readLocker, return empty result.");
            return new byte[0];
        }
    }

    public boolean deleteFile(String str) {
        return deleteFile(new File(str));
    }

    public boolean forceDeleteFile(File file) {
        if (file == null || !file.exists()) {
            return false;
        }
        return file.delete();
    }

    public boolean deleteFile(File file) {
        if (file == null || !file.exists()) {
            return false;
        }
        ReentrantReadWriteLock.WriteLock writeLock = getLock(file.getAbsolutePath()).writeLock();
        if (writeLock.tryLock()) {
            boolean delete = file.delete();
            writeLock.unlock();
            AVLogger aVLogger = gLogger;
            aVLogger.d("succeed to obtain writeLock, and delete file: " + file.getAbsolutePath() + ", ret: " + delete);
            return delete;
        }
        AVLogger aVLogger2 = gLogger;
        aVLogger2.w("failed to lock writeLocker, skip to delete file:" + file.getAbsolutePath());
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x0048  */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x004d  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0054  */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x0059  */
    public boolean saveFileToLocal(String str, File file) {
        Closeable closeable;
        Closeable closeable2;
        Throwable th;
        ReentrantReadWriteLock.WriteLock writeLock = getLock(str).writeLock();
        boolean z = false;
        if (writeLock.tryLock()) {
            InputStream inputStream = null;
            try {
                InputStream inputStreamFromFile = getInputStreamFromFile(file);
                try {
                    FileOutputStream outputStreamForFile = getOutputStreamForFile(new File(str), false);
                    byte[] bArr = new byte[2097152];
                    if (!(inputStreamFromFile == null || outputStreamForFile == null)) {
                        while (true) {
                            int read = inputStreamFromFile.read(bArr);
                            if (read == -1) {
                                break;
                            }
                            outputStreamForFile.write(bArr, 0, read);
                        }
                        z = true;
                    }
                    if (inputStreamFromFile != null) {
                        closeQuietly(inputStreamFromFile);
                    }
                    if (outputStreamForFile != null) {
                        closeQuietly(outputStreamForFile);
                    }
                } catch (Exception unused) {
                    closeable = null;
                    inputStream = inputStreamFromFile;
                    if (inputStream != null) {
                        closeQuietly(inputStream);
                    }
                    if (closeable != null) {
                        closeQuietly(closeable);
                    }
                    writeLock.unlock();
                    return z;
                } catch (Throwable th2) {
                    th = th2;
                    inputStream = inputStreamFromFile;
                    closeable2 = null;
                    if (inputStream != null) {
                        closeQuietly(inputStream);
                    }
                    if (closeable2 != null) {
                        closeQuietly(closeable2);
                    }
                    throw th;
                }
            } catch (Exception unused2) {
                closeable = null;
                if (inputStream != null) {
                }
                if (closeable != null) {
                }
                writeLock.unlock();
                return z;
            } catch (Throwable th3) {
                th = th3;
                closeable2 = null;
                if (inputStream != null) {
                }
                if (closeable2 != null) {
                }
                throw th;
            }
            writeLock.unlock();
        } else {
            gLogger.w("failed to lock writeLocker, skip save content to file:" + str);
        }
        return z;
    }

    public static FileOutputStream getOutputStreamForFile(File file, boolean z) throws IOException {
        if (file == null) {
            return null;
        }
        return new FileOutputStream(file, z);
    }

    public static InputStream getInputStreamFromFile(File file) throws IOException {
        if (file != null && file.exists() && file.isFile()) {
            return new BufferedInputStream(new FileInputStream(file), 8192);
        }
        return null;
    }

    public static List<File> listFiles(String str) {
        File[] listFiles;
        ArrayList arrayList = new ArrayList();
        File file = new File(str);
        if (file.exists() && file.isDirectory() && (listFiles = file.listFiles()) != null) {
            for (File file2 : listFiles) {
                if (file2.isFile()) {
                    arrayList.add(file2);
                }
            }
        }
        return arrayList;
    }

    public void clearDir(String str, long j) {
        File[] listFiles;
        File file = new File(str);
        if (file.exists() && file.isDirectory() && (listFiles = file.listFiles()) != null) {
            for (File file2 : listFiles) {
                if (file2.isFile()) {
                    if (file2.lastModified() >= j) {
                        gLogger.d("skip cache file: " + file2.getAbsolutePath());
                    } else if (deleteFile(file2)) {
                        gLogger.d("succeed to delete file: " + file2.getAbsolutePath());
                    } else {
                        gLogger.d("failed to delete file: " + file2.getAbsolutePath());
                    }
                } else if (file2.isDirectory()) {
                    clearDir(file2.getAbsolutePath(), j);
                }
            }
        }
    }
}
