package cn.leancloud.upload;

import cn.leancloud.AVException;
import cn.leancloud.AVLogger;
import cn.leancloud.cache.PersistenceUtil;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class FileDownloader {
    private static final int READ_BUF_SIZE = 8192;
    private static final AVLogger gLogger = LogUtil.getLogger(FileDownloader.class);

    public AVException execute(String str, File file) {
        if (StringUtil.isEmpty(str)) {
            return new AVException(new IllegalArgumentException("url is null"));
        }
        if (file.exists()) {
            return new AVException(new FileNotFoundException("local file is not existed."));
        }
        return downloadFileFromNetwork(str, file);
    }

    private OkHttpClient getHttpClient() {
        return new OkHttpClient.Builder().connectTimeout(15, TimeUnit.SECONDS).readTimeout(10, TimeUnit.SECONDS).writeTimeout(10, TimeUnit.SECONDS).build();
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(9:10|11|(1:13)|14|15|16|17|18|50) */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:16:0x005d */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x007e A[SYNTHETIC, Splitter:B:32:0x007e] */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x008d A[SYNTHETIC, Splitter:B:40:0x008d] */
    private AVException downloadFileFromNetwork(String str, File file) {
        Throwable th;
        Exception e;
        Request.Builder builder = new Request.Builder();
        builder.url(str);
        try {
            Response execute = getHttpClient().newCall(builder.build()).execute();
            int code = execute.code();
            InputStream byteStream = execute.body().byteStream();
            if (code / 100 != 2 || byteStream == null) {
                AVException aVException = new AVException(code, "status code is invalid");
                gLogger.w(aVException);
                return aVException;
            }
            byte[] bArr = new byte[8192];
            ReentrantReadWriteLock.WriteLock writeLock = PersistenceUtil.sharedInstance().getLock(file.getAbsolutePath()).writeLock();
            FileOutputStream fileOutputStream = null;
            if (writeLock.tryLock()) {
                try {
                    FileOutputStream fileOutputStream2 = new FileOutputStream(file, false);
                    try {
                        for (int read = byteStream.read(bArr); read > 0; read = byteStream.read(bArr)) {
                            fileOutputStream2.write(bArr, 0, read);
                        }
                        byteStream.close();
                        fileOutputStream2.close();
                        writeLock.unlock();
                        return null;
                    } catch (Exception e2) {
                        e = e2;
                        fileOutputStream = fileOutputStream2;
                        try {
                            gLogger.w(e);
                            AVException aVException2 = new AVException(e);
                            try {
                                byteStream.close();
                            } catch (IOException unused) {
                            }
                            if (fileOutputStream != null) {
                            }
                            writeLock.unlock();
                            return aVException2;
                        } catch (Throwable th2) {
                            th = th2;
                            try {
                                byteStream.close();
                            } catch (IOException unused2) {
                            }
                            if (fileOutputStream != null) {
                            }
                            writeLock.unlock();
                            throw th;
                        }
                    } catch (Throwable th3) {
                        th = th3;
                        fileOutputStream = fileOutputStream2;
                        byteStream.close();
                        if (fileOutputStream != null) {
                            try {
                                fileOutputStream.close();
                            } catch (IOException unused3) {
                            }
                        }
                        writeLock.unlock();
                        throw th;
                    }
                } catch (Exception e3) {
                    e = e3;
                    gLogger.w(e);
                    AVException aVException22 = new AVException(e);
                    byteStream.close();
                    if (fileOutputStream != null) {
                        try {
                            fileOutputStream.close();
                        } catch (IOException unused4) {
                        }
                    }
                    writeLock.unlock();
                    return aVException22;
                }
            } else {
                gLogger.w("failed to lock writeLocker, skip to save network streaming to local cache.");
                return null;
            }
        } catch (IOException e4) {
            return new AVException(e4);
        }
    }
}
